@@ -31,8 +31,7 @@ from trollimage.xrimage import XRImage
 
 from satpy._compat import ArrayLike
 from satpy._config import get_config_path
-
-from ..utils import find_in_ancillary
+from satpy.utils import find_in_ancillary
 
 LOG = logging.getLogger(__name__)
 
@@ -57,8 +56,8 @@ def exclude_alpha(func):
 
     @wraps(func)
     def wrapper(data, **kwargs):
-        bands = data.coords['bands'].values
-        exclude = ['A'] if 'A' in bands else []
+        bands = data.coords["bands"].values
+        exclude = ["A"] if "A" in bands else []
         band_data = data.sel(bands=[b for b in bands
                                     if b not in exclude])
         band_data = func(band_data, **kwargs)
@@ -67,7 +66,7 @@ def exclude_alpha(func):
         attrs.update(band_data.attrs)
         # combine the new data with the excluded data
         new_data = xr.concat([band_data, data.sel(bands=exclude)],
-                             dim='bands')
+                             dim="bands")
         data.data = new_data.sel(bands=bands).data
         data.attrs = attrs
         return data
@@ -92,12 +91,12 @@ def on_separate_bands(func):
     def wrapper(data, **kwargs):
         attrs = data.attrs
         data_arrs = []
-        for idx, band in enumerate(data.coords['bands'].values):
+        for idx, band in enumerate(data.coords["bands"].values):
             band_data = func(data.sel(bands=[band]), index=idx, **kwargs)
             data_arrs.append(band_data)
             # we assume that the func can add attrs
             attrs.update(band_data.attrs)
-        data.data = xr.concat(data_arrs, dim='bands').data
+        data.data = xr.concat(data_arrs, dim="bands").data
         data.attrs = attrs
         return data
 
@@ -132,7 +131,7 @@ def using_map_blocks(func):
     return on_dask_array(wrapper)
 
 
-def piecewise_linear_stretch(
+def piecewise_linear_stretch(  # noqa: D417
         img: XRImage,
         xp: ArrayLike,
         fp: ArrayLike,
@@ -230,7 +229,7 @@ def _cira_stretch(band_data):
     return band_data
 
 
-def reinhard_to_srgb(img, saturation=1.25, white=100, **kwargs):
+def reinhard_to_srgb(img, saturation=1.25, white=100, **kwargs):  # noqa: D417
     """Stretch method based on the Reinhard algorithm, using luminance.
 
     Args:
@@ -248,9 +247,9 @@ def reinhard_to_srgb(img, saturation=1.25, white=100, **kwargs):
         white /= 100
 
         # extract color components
-        r = rgb.sel(bands='R').data
-        g = rgb.sel(bands='G').data
-        b = rgb.sel(bands='B').data
+        r = rgb.sel(bands="R").data
+        g = rgb.sel(bands="G").data
+        b = rgb.sel(bands="B").data
 
         # saturate
         luma = _compute_luminance_from_rgb(r, g, b)
@@ -280,7 +279,7 @@ def _srgb_gamma(arr):
 
 def lookup(img, **kwargs):
     """Assign values to channels based on a table."""
-    luts = np.array(kwargs['luts'], dtype=np.float32) / 255.0
+    luts = np.array(kwargs["luts"], dtype=np.float32) / 255.0
     return _lookup_table(img.data, luts=luts)
 
 
@@ -294,7 +293,7 @@ def _lookup_table(band_data, luts=None, index=-1):
     return lut[band_data]
 
 
-def colorize(img, **kwargs):
+def colorize(img, **kwargs):  # noqa: D417
     """Colorize the given image.
 
     Args:
@@ -352,7 +351,7 @@ def _merge_colormaps(kwargs, img=None):
     from trollimage.colormap import Colormap
     full_cmap = None
 
-    palette = kwargs['palettes']
+    palette = kwargs["palettes"]
     if isinstance(palette, Colormap):
         full_cmap = palette
     else:
@@ -366,7 +365,7 @@ def _merge_colormaps(kwargs, img=None):
     return full_cmap
 
 
-def create_colormap(palette, img=None):
+def create_colormap(palette, img=None):  # noqa: D417
     """Create colormap of the given numpy file, color vector, or colormap.
 
     Args:
@@ -457,11 +456,11 @@ def create_colormap(palette, img=None):
     information.
 
     """
-    fname = palette.get('filename', None)
-    colors = palette.get('colors', None)
+    fname = palette.get("filename", None)
+    colors = palette.get("colors", None)
     dataset = palette.get("dataset", None)
     # are colors between 0-255 or 0-1
-    color_scale = palette.get('color_scale', 255)
+    color_scale = palette.get("color_scale", 255)
     if fname:
         if not os.path.exists(fname):
             fname = get_config_path(fname)
@@ -477,9 +476,9 @@ def create_colormap(palette, img=None):
 
     if palette.get("reverse", False):
         cmap.reverse()
-    if 'min_value' in palette and 'max_value' in palette:
+    if "min_value" in palette and "max_value" in palette:
         cmap.set_range(palette["min_value"], palette["max_value"])
-    elif 'min_value' in palette or 'max_value' in palette:
+    elif "min_value" in palette or "max_value" in palette:
         raise ValueError("Both 'min_value' and 'max_value' must be specified (or neither)")
 
     return cmap
@@ -498,12 +497,12 @@ def _create_colormap_from_dataset(img, dataset, color_scale):
 
 def three_d_effect(img, **kwargs):
     """Create 3D effect using convolution."""
-    w = kwargs.get('weight', 1)
+    w = kwargs.get("weight", 1)
     LOG.debug("Applying 3D effect with weight %.2f", w)
     kernel = np.array([[-w, 0, w],
                        [-w, 1, w],
                        [-w, 0, w]])
-    mode = kwargs.get('convolve_mode', 'same')
+    mode = kwargs.get("convolve_mode", "same")
     return _three_d_effect(img.data, kernel=kernel, mode=mode)
 
 
@@ -526,7 +525,7 @@ def _three_d_effect_delayed(band_data, kernel, mode):
     return new_data.reshape((1, band_data.shape[0], band_data.shape[1]))
 
 
-def btemp_threshold(img, min_in, max_in, threshold, threshold_out=None, **kwargs):
+def btemp_threshold(img, min_in, max_in, threshold, threshold_out=None, **kwargs):  # noqa: D417
     """Scale data linearly in two separate regions.
 
     This enhancement scales the input data linearly by splitting the data
@@ -582,7 +581,7 @@ def jma_true_color_reproduction(img):
     https://www.jma.go.jp/jma/jma-eng/satellite/introduction/TCR.html
     """
     _jma_true_color_reproduction(img.data,
-                                 platform=img.data.attrs['platform_name'])
+                                 platform=img.data.attrs["platform_name"])
 
 
 @exclude_alpha
@@ -597,29 +596,29 @@ def _jma_true_color_reproduction(img_data, platform=None):
 
     """
     # Conversion matrix dictionaries specifying sensor and platform.
-    ccm_dict = {'himawari-8': np.array([[1.1629, 0.1539, -0.2175],
+    ccm_dict = {"himawari-8": np.array([[1.1629, 0.1539, -0.2175],
                                         [-0.0252, 0.8725, 0.1300],
                                         [-0.0204, -0.1100, 1.0633]]),
 
-                'himawari-9': np.array([[1.1619, 0.1542, -0.2168],
+                "himawari-9": np.array([[1.1619, 0.1542, -0.2168],
                                         [-0.0271, 0.8749, 0.1295],
                                         [-0.0202, -0.1103, 1.0634]]),
 
-                'goes-16': np.array([[1.1425, 0.1819, -0.2250],
+                "goes-16": np.array([[1.1425, 0.1819, -0.2250],
                                      [-0.0951, 0.9363, 0.1360],
                                      [-0.0113, -0.1179, 1.0621]]),
-                'goes-17': np.array([[1.1437, 0.1818, -0.2262],
+                "goes-17": np.array([[1.1437, 0.1818, -0.2262],
                                      [-0.0952, 0.9354, 0.1371],
                                      [-0.0113, -0.1178, 1.0620]]),
-                'goes-18': np.array([[1.1629, 0.1539, -0.2175],
+                "goes-18": np.array([[1.1629, 0.1539, -0.2175],
                                      [-0.0252, 0.8725, 0.1300],
                                      [-0.0204, -0.1100, 1.0633]]),
 
-                'mtg-i1': np.array([[0.9007, 0.2086, -0.0100],
+                "mtg-i1": np.array([[0.9007, 0.2086, -0.0100],
                                     [-0.0475, 1.0662, -0.0414],
                                     [-0.0123, -0.1342, 1.0794]]),
 
-                'geo-kompsat-2a': np.array([[1.1661, 0.1489, -0.2157],
+                "geo-kompsat-2a": np.array([[1.1661, 0.1489, -0.2157],
                                             [-0.0255, 0.8745, 0.1282],
                                             [-0.0205, -0.1103, 1.0637]]),
                 }
