@@ -54,24 +54,24 @@ logger = logging.getLogger(__name__)
 
 AVHRR_CHANNEL_NAMES = ["1", "2", "3a", "3b", "4", "5"]
 
-AVHRR_ANGLE_NAMES = ['sensor_zenith_angle',
-                     'solar_zenith_angle',
-                     'sun_sensor_azimuth_difference_angle']
+AVHRR_ANGLE_NAMES = ["sensor_zenith_angle",
+                     "solar_zenith_angle",
+                     "sun_sensor_azimuth_difference_angle"]
 
-AVHRR_PLATFORM_IDS2NAMES = {4: 'NOAA-15',
-                            2: 'NOAA-16',
-                            6: 'NOAA-17',
-                            7: 'NOAA-18',
-                            8: 'NOAA-19',
-                            11: 'Metop-B',
-                            12: 'Metop-A',
-                            13: 'Metop-C',
-                            14: 'Metop simulator'}
+AVHRR_PLATFORM_IDS2NAMES = {4: "NOAA-15",
+                            2: "NOAA-16",
+                            6: "NOAA-17",
+                            7: "NOAA-18",
+                            8: "NOAA-19",
+                            11: "Metop-B",
+                            12: "Metop-A",
+                            13: "Metop-C",
+                            14: "Metop simulator"}
 
 
 def create_xarray(arr):
     """Create an `xarray.DataArray`."""
-    res = xr.DataArray(arr, dims=['y', 'x'])
+    res = xr.DataArray(arr, dims=["y", "x"])
     return res
 
 
@@ -102,30 +102,30 @@ class AAPPL1BaseFileHandler(BaseFileHandler):
     @property
     def start_time(self):
         """Get the time of the first observation."""
-        return datetime(self._data['scnlinyr'][0], 1, 1) + timedelta(
-            days=int(self._data['scnlindy'][0]) - 1,
-            milliseconds=int(self._data['scnlintime'][0]))
+        return datetime(self._data["scnlinyr"][0], 1, 1) + timedelta(
+            days=int(self._data["scnlindy"][0]) - 1,
+            milliseconds=int(self._data["scnlintime"][0]))
 
     @property
     def end_time(self):
         """Get the time of the final observation."""
-        return datetime(self._data['scnlinyr'][-1], 1, 1) + timedelta(
-            days=int(self._data['scnlindy'][-1]) - 1,
-            milliseconds=int(self._data['scnlintime'][-1]))
+        return datetime(self._data["scnlinyr"][-1], 1, 1) + timedelta(
+            days=int(self._data["scnlindy"][-1]) - 1,
+            milliseconds=int(self._data["scnlintime"][-1]))
 
     def _update_dataset_attributes(self, dataset, key, info):
-        dataset.attrs.update({'platform_name': self.platform_name,
-                              'sensor': self.sensor})
+        dataset.attrs.update({"platform_name": self.platform_name,
+                              "sensor": self.sensor})
         dataset.attrs.update(key.to_dict())
-        for meta_key in ('standard_name', 'units'):
+        for meta_key in ("standard_name", "units"):
             if meta_key in info:
                 dataset.attrs.setdefault(meta_key, info[meta_key])
 
     def _get_platform_name(self, platform_names_lookup):
         """Get the platform name from the file header."""
-        self.platform_name = platform_names_lookup.get(self._header['satid'][0], None)
+        self.platform_name = platform_names_lookup.get(self._header["satid"][0], None)
         if self.platform_name is None:
-            raise ValueError("Unsupported platform ID: %d" % self.header['satid'])
+            raise ValueError("Unsupported platform ID: %d" % self.header["satid"])
 
     def read(self):
         """Read the data."""
@@ -143,17 +143,17 @@ class AAPPL1BaseFileHandler(BaseFileHandler):
 
     def get_dataset(self, key, info):
         """Get a dataset from the file."""
-        if key['name'] in self._channel_names:
+        if key["name"] in self._channel_names:
             dataset = self._calibrate_active_channel_data(key)
             if dataset is None:
                 return None
-        elif key['name'] in ['longitude', 'latitude']:
-            dataset = self.navigate(key['name'])
+        elif key["name"] in ["longitude", "latitude"]:
+            dataset = self.navigate(key["name"])
             dataset.attrs = info
-        elif key['name'] in self._angle_names:
-            dataset = self.get_angles(key['name'])
+        elif key["name"] in self._angle_names:
+            dataset = self.get_angles(key["name"])
         else:
-            raise ValueError("Not a supported dataset: %s", key['name'])
+            raise ValueError("Not a supported dataset: %s", key["name"])
 
         self._update_dataset_attributes(dataset, key, info)
         return dataset
@@ -168,7 +168,7 @@ class AVHRRAAPPL1BFile(AAPPL1BaseFileHandler):
                                                filetype_info)
 
         self.channels = {i: None for i in AVHRR_CHANNEL_NAMES}
-        self.units = {i: 'counts' for i in AVHRR_CHANNEL_NAMES}
+        self.units = {i: "counts" for i in AVHRR_CHANNEL_NAMES}
 
         self._is3b = None
         self._is3a = None
@@ -181,7 +181,7 @@ class AVHRRAAPPL1BFile(AAPPL1BaseFileHandler):
         self.active_channels = self._get_active_channels()
 
         self._get_platform_name(AVHRR_PLATFORM_IDS2NAMES)
-        self.sensor = 'avhrr-3'
+        self.sensor = "avhrr-3"
 
         self._get_all_interpolated_angles = functools.lru_cache(maxsize=10)(
             self._get_all_interpolated_angles_uncached
@@ -202,25 +202,25 @@ class AVHRRAAPPL1BFile(AAPPL1BaseFileHandler):
 
     def _calibrate_active_channel_data(self, key):
         """Calibrate active channel data only."""
-        if self.active_channels[key['name']]:
+        if self.active_channels[key["name"]]:
             return self.calibrate(key)
         return None
 
     def _get_channel_binary_status_from_header(self):
-        status = self._header['inststat1'].item()
-        change_line = self._header['statchrecnb']
+        status = self._header["inststat1"].item()
+        change_line = self._header["statchrecnb"]
         if change_line > 0:
-            status |= self._header['inststat2'].item()
+            status |= self._header["inststat2"].item()
         return status
 
     @staticmethod
     def _convert_binary_channel_status_to_activation_dict(status):
-        bits_channels = ((13, '1'),
-                         (12, '2'),
-                         (11, '3a'),
-                         (10, '3b'),
-                         (9, '4'),
-                         (8, '5'))
+        bits_channels = ((13, "1"),
+                         (12, "2"),
+                         (11, "3a"),
+                         (10, "3b"),
+                         (9, "4"),
+                         (8, "5"))
         activated = dict()
         for bit, channel_name in bits_channels:
             activated[channel_name] = bool(status >> bit & 1)
@@ -229,8 +229,8 @@ class AVHRRAAPPL1BFile(AAPPL1BaseFileHandler):
     def available_datasets(self, configured_datasets=None):
         """Get the available datasets."""
         for _, mda in configured_datasets:
-            if mda['name'] in self._channel_names:
-                yield self.active_channels[mda['name']], mda
+            if mda["name"] in self._channel_names:
+                yield self.active_channels[mda["name"]], mda
             else:
                 yield True, mda
 
@@ -285,9 +285,9 @@ class AVHRRAAPPL1BFile(AAPPL1BaseFileHandler):
     def navigate(self, coordinate_id):
         """Get the longitudes and latitudes of the scene."""
         lons, lats = self._get_all_interpolated_coordinates()
-        if coordinate_id == 'longitude':
+        if coordinate_id == "longitude":
             return create_xarray(lons)
-        if coordinate_id == 'latitude':
+        if coordinate_id == "latitude":
             return create_xarray(lats)
 
         raise KeyError("Coordinate {} unknown.".format(coordinate_id))
@@ -309,49 +309,49 @@ class AVHRRAAPPL1BFile(AAPPL1BaseFileHandler):
         if calib_coeffs is None:
             calib_coeffs = {}
 
-        units = {'reflectance': '%',
-                 'brightness_temperature': 'K',
-                 'counts': '',
-                 'radiance': 'W*m-2*sr-1*cm ?'}
+        units = {"reflectance": "%",
+                 "brightness_temperature": "K",
+                 "counts": "",
+                 "radiance": "W*m-2*sr-1*cm ?"}
 
-        if dataset_id['name'] in ("3a", "3b") and self._is3b is None:
+        if dataset_id["name"] in ("3a", "3b") and self._is3b is None:
             # Is it 3a or 3b:
             line_chunks = get_aapp_chunks((self._data.shape[0], 2048))[0]
-            self._is3a = da.bitwise_and(da.from_array(self._data['scnlinbit'],
+            self._is3a = da.bitwise_and(da.from_array(self._data["scnlinbit"],
                                                       chunks=line_chunks), 3) == 0
-            self._is3b = da.bitwise_and(da.from_array(self._data['scnlinbit'],
+            self._is3b = da.bitwise_and(da.from_array(self._data["scnlinbit"],
                                                       chunks=line_chunks), 3) == 1
 
         try:
-            vis_idx = ['1', '2', '3a'].index(dataset_id['name'])
+            vis_idx = ["1", "2", "3a"].index(dataset_id["name"])
             ir_idx = None
         except ValueError:
             vis_idx = None
-            ir_idx = ['3b', '4', '5'].index(dataset_id['name'])
+            ir_idx = ["3b", "4", "5"].index(dataset_id["name"])
 
         mask = True
         if vis_idx is not None:
-            coeffs = calib_coeffs.get('ch' + dataset_id['name'])
-            if dataset_id['name'] == '3a':
+            coeffs = calib_coeffs.get("ch" + dataset_id["name"])
+            if dataset_id["name"] == "3a":
                 mask = self._is3a[:, None]
             ds = create_xarray(
                 _vis_calibrate(self._data,
                                vis_idx,
-                               dataset_id['calibration'],
+                               dataset_id["calibration"],
                                pre_launch_coeffs,
                                coeffs,
                                mask=mask))
         else:
-            if dataset_id['name'] == '3b':
+            if dataset_id["name"] == "3b":
                 mask = self._is3b[:, None]
             ds = create_xarray(
                 _ir_calibrate(self._header,
                               self._data,
                               ir_idx,
-                              dataset_id['calibration'],
+                              dataset_id["calibration"],
                               mask=mask))
 
-        ds.attrs['units'] = units[dataset_id['calibration']]
+        ds.attrs["units"] = units[dataset_id["calibration"]]
         ds.attrs.update(dataset_id._asdict())
         return ds
 
@@ -545,8 +545,8 @@ def _vis_calibrate(data,
     """
     # Calibration count to albedo, the calibration is performed separately for
     # two value ranges.
-    if calib_type not in ['counts', 'radiance', 'reflectance']:
-        raise ValueError('Calibration ' + calib_type + ' unknown!')
+    if calib_type not in ["counts", "radiance", "reflectance"]:
+        raise ValueError("Calibration " + calib_type + " unknown!")
 
     channel_data = data["hrpt"][:, :, chn]
     chunks = get_aapp_chunks(channel_data.shape)
@@ -554,12 +554,12 @@ def _vis_calibrate(data,
     channel = da.from_array(channel_data, chunks=chunks)
     mask &= channel != 0
 
-    if calib_type == 'counts':
+    if calib_type == "counts":
         return channel
 
     channel = channel.astype(CHANNEL_DTYPE)
 
-    if calib_type == 'radiance':
+    if calib_type == "radiance":
         logger.info("Radiances are not yet supported for " +
                     "the VIS/NIR channels!")
 
@@ -630,9 +630,9 @@ def _ir_calibrate(header, data, irchn, calib_type, mask=True):
     mask &= count != 0
     count = count.astype(CHANNEL_DTYPE)
 
-    k1_ = da.from_array(data['calir'][:, irchn, 0, 0], chunks=line_chunks) / 1.0e9
-    k2_ = da.from_array(data['calir'][:, irchn, 0, 1], chunks=line_chunks) / 1.0e6
-    k3_ = da.from_array(data['calir'][:, irchn, 0, 2], chunks=line_chunks) / 1.0e6
+    k1_ = da.from_array(data["calir"][:, irchn, 0, 0], chunks=line_chunks) / 1.0e9
+    k2_ = da.from_array(data["calir"][:, irchn, 0, 1], chunks=line_chunks) / 1.0e6
+    k3_ = da.from_array(data["calir"][:, irchn, 0, 2], chunks=line_chunks) / 1.0e6
 
     # Count to radiance conversion:
     rad = k1_[:, None] * count * count + k2_[:, None] * count + k3_[:, None]
@@ -645,14 +645,14 @@ def _ir_calibrate(header, data, irchn, calib_type, mask=True):
         return da.where(mask, rad, np.nan)
 
     # Central wavenumber:
-    cwnum = header['radtempcnv'][0, irchn, 0]
+    cwnum = header["radtempcnv"][0, irchn, 0]
     if irchn == 0:
         cwnum = cwnum / 1.0e2
     else:
         cwnum = cwnum / 1.0e3
 
-    bandcor_2 = header['radtempcnv'][0, irchn, 1] / 1e5
-    bandcor_3 = header['radtempcnv'][0, irchn, 2] / 1e6
+    bandcor_2 = header["radtempcnv"][0, irchn, 1] / 1e5
+    bandcor_3 = header["radtempcnv"][0, irchn, 2] / 1e6
 
     ir_const_1 = 1.1910659e-5
     ir_const_2 = 1.438833
