@@ -40,34 +40,34 @@ from satpy.readers.hrit_base import (
     time_cds_short,
 )
 
-logger = logging.getLogger('hrit_electrol')
+logger = logging.getLogger("hrit_electrol")
 
 
 # goms implementation:
-key_header = np.dtype([('key_number', 'u1'),
-                       ('seed', '>f8')])
+key_header = np.dtype([("key_number", "u1"),
+                       ("seed", ">f8")])
 
-segment_identification = np.dtype([('GP_SC_ID', '>i2'),
-                                   ('spectral_channel_id', '>i1'),
-                                   ('segment_sequence_number', '>u2'),
-                                   ('planned_start_segment_number', '>u2'),
-                                   ('planned_end_segment_number', '>u2'),
-                                   ('data_field_representation', '>i1')])
+segment_identification = np.dtype([("GP_SC_ID", ">i2"),
+                                   ("spectral_channel_id", ">i1"),
+                                   ("segment_sequence_number", ">u2"),
+                                   ("planned_start_segment_number", ">u2"),
+                                   ("planned_end_segment_number", ">u2"),
+                                   ("data_field_representation", ">i1")])
 
-image_segment_line_quality = np.dtype([('line_number_in_grid', '>i4'),
-                                       ('line_mean_acquisition',
-                                        [('days', '>u2'),
-                                         ('milliseconds', '>u4')]),
-                                       ('line_validity', 'u1'),
-                                       ('line_radiometric_quality', 'u1'),
-                                       ('line_geometric_quality', 'u1')])
+image_segment_line_quality = np.dtype([("line_number_in_grid", ">i4"),
+                                       ("line_mean_acquisition",
+                                        [("days", ">u2"),
+                                         ("milliseconds", ">u4")]),
+                                       ("line_validity", "u1"),
+                                       ("line_radiometric_quality", "u1"),
+                                       ("line_geometric_quality", "u1")])
 
 goms_variable_length_headers = {
-    image_segment_line_quality: 'image_segment_line_quality'}
+    image_segment_line_quality: "image_segment_line_quality"}
 
-goms_text_headers = {image_data_function: 'image_data_function',
-                     annotation_header: 'annotation_header',
-                     ancillary_text: 'ancillary_text'}
+goms_text_headers = {image_data_function: "image_data_function",
+                     annotation_header: "annotation_header",
+                     ancillary_text: "ancillary_text"}
 
 goms_hdr_map = base_hdr_map.copy()
 goms_hdr_map.update({7: key_header,
@@ -76,28 +76,28 @@ goms_hdr_map.update({7: key_header,
                      })
 
 
-orbit_coef = np.dtype([('StartTime', time_cds_short),
-                       ('EndTime', time_cds_short),
-                       ('X', '>f8', (8, )),
-                       ('Y', '>f8', (8, )),
-                       ('Z', '>f8', (8, )),
-                       ('VX', '>f8', (8, )),
-                       ('VY', '>f8', (8, )),
-                       ('VZ', '>f8', (8, ))])
+orbit_coef = np.dtype([("StartTime", time_cds_short),
+                       ("EndTime", time_cds_short),
+                       ("X", ">f8", (8, )),
+                       ("Y", ">f8", (8, )),
+                       ("Z", ">f8", (8, )),
+                       ("VX", ">f8", (8, )),
+                       ("VY", ">f8", (8, )),
+                       ("VZ", ">f8", (8, ))])
 
-attitude_coef = np.dtype([('StartTime', time_cds_short),
-                          ('EndTime', time_cds_short),
-                          ('XofSpinAxis', '>f8', (8, )),
-                          ('YofSpinAxis', '>f8', (8, )),
-                          ('ZofSpinAxis', '>f8', (8, ))])
+attitude_coef = np.dtype([("StartTime", time_cds_short),
+                          ("EndTime", time_cds_short),
+                          ("XofSpinAxis", ">f8", (8, )),
+                          ("YofSpinAxis", ">f8", (8, )),
+                          ("ZofSpinAxis", ">f8", (8, ))])
 
-cuc_time = np.dtype([('coarse', 'u1', (4, )),
-                     ('fine', 'u1', (3, ))])
+cuc_time = np.dtype([("coarse", "u1", (4, )),
+                     ("fine", "u1", (3, ))])
 
-time_cds_expanded = np.dtype([('days', '>u2'),
-                              ('milliseconds', '>u4'),
-                              ('microseconds', '>u2'),
-                              ('nanoseconds', '>u2')])
+time_cds_expanded = np.dtype([("days", ">u2"),
+                              ("milliseconds", ">u4"),
+                              ("microseconds", ">u2"),
+                              ("nanoseconds", ">u2")])
 
 
 satellite_status = np.dtype([("TagType", "<u4"),
@@ -115,9 +115,9 @@ image_acquisition = np.dtype([("TagType", "<u4"),
                               ("Cel", "<f8")])
 
 
-prologue = np.dtype([('SatelliteStatus', satellite_status),
-                     ('ImageAcquisition', image_acquisition, (10, )),
-                     ('ImageCalibration', "<i4", (10, 1024))])
+prologue = np.dtype([("SatelliteStatus", satellite_status),
+                     ("ImageAcquisition", image_acquisition, (10, )),
+                     ("ImageCalibration", "<i4", (10, 1024))])
 
 
 def recarray2dict(arr):
@@ -152,7 +152,7 @@ class HRITGOMSPrologueFileHandler(HRITFileHandler):
     def read_prologue(self):
         """Read the prologue metadata."""
         with open(self.filename, "rb") as fp_:
-            fp_.seek(self.mda['total_header_length'])
+            fp_.seek(self.mda["total_header_length"])
             data = np.fromfile(fp_, dtype=prologue, count=1)[0]
 
             self.prologue.update(recarray2dict(data))
@@ -217,8 +217,8 @@ geometric_processing = np.dtype([("TagType", "<u4"),
                                  ("ApriorAccuracy", "<f8"),
                                  ("RelativeAccuracy", "<f8", (2, ))])
 
-epilogue = np.dtype([('RadiometricProcessing', radiometric_processing, (10, )),
-                     ('GeometricProcessing', geometric_processing, (10, ))])
+epilogue = np.dtype([("RadiometricProcessing", radiometric_processing, (10, )),
+                     ("GeometricProcessing", geometric_processing, (10, ))])
 # FIXME: Add rest of the epilogue
 
 
@@ -238,7 +238,7 @@ class HRITGOMSEpilogueFileHandler(HRITFileHandler):
     def read_epilogue(self):
         """Read the prologue metadata."""
         with open(self.filename, "rb") as fp_:
-            fp_.seek(self.mda['total_header_length'])
+            fp_.seek(self.mda["total_header_length"])
             data = np.fromfile(fp_, dtype=epilogue, count=1)[0]
 
             self.epilogue.update(recarray2dict(data))
@@ -268,31 +268,31 @@ class HRITGOMSFileHandler(HRITFileHandler):
                                                    goms_text_headers))
         self.prologue = prologue.prologue
         self.epilogue = epilogue.epilogue
-        self.chid = self.mda['spectral_channel_id']
-        sublon = self.epilogue['GeometricProcessing']['TGeomNormInfo']['SubLon']
+        self.chid = self.mda["spectral_channel_id"]
+        sublon = self.epilogue["GeometricProcessing"]["TGeomNormInfo"]["SubLon"]
         sublon = sublon[self.chid]
-        self.mda['projection_parameters']['SSP_longitude'] = np.rad2deg(sublon)
-        self.mda['orbital_parameters']['satellite_nominal_longitude'] = np.rad2deg(
-            self.prologue['SatelliteStatus']['NominalLongitude'])
-        satellite_id = self.prologue['SatelliteStatus']['SatelliteID']
+        self.mda["projection_parameters"]["SSP_longitude"] = np.rad2deg(sublon)
+        self.mda["orbital_parameters"]["satellite_nominal_longitude"] = np.rad2deg(
+            self.prologue["SatelliteStatus"]["NominalLongitude"])
+        satellite_id = self.prologue["SatelliteStatus"]["SatelliteID"]
         self.platform_name = SPACECRAFTS[satellite_id]
 
     def get_dataset(self, key, info):
         """Get the data  from the files."""
         res = super(HRITGOMSFileHandler, self).get_dataset(key, info)
 
-        res = self.calibrate(res, key['calibration'])
-        res.attrs['units'] = info['units']
-        res.attrs['standard_name'] = info['standard_name']
-        res.attrs['wavelength'] = info['wavelength']
-        res.attrs['platform_name'] = self.platform_name
-        res.attrs['sensor'] = 'msu-gs'
-        res.attrs['orbital_parameters'] = {
-            'satellite_nominal_longitude': self.mda['orbital_parameters']['satellite_nominal_longitude'],
-            'satellite_nominal_latitude': 0.,
-            'projection_longitude': self.mda['projection_parameters']['SSP_longitude'],
-            'projection_latitude': 0.,
-            'projection_altitude': 35785831.00
+        res = self.calibrate(res, key["calibration"])
+        res.attrs["units"] = info["units"]
+        res.attrs["standard_name"] = info["standard_name"]
+        res.attrs["wavelength"] = info["wavelength"]
+        res.attrs["platform_name"] = self.platform_name
+        res.attrs["sensor"] = "msu-gs"
+        res.attrs["orbital_parameters"] = {
+            "satellite_nominal_longitude": self.mda["orbital_parameters"]["satellite_nominal_longitude"],
+            "satellite_nominal_latitude": 0.,
+            "projection_longitude": self.mda["projection_parameters"]["SSP_longitude"],
+            "projection_latitude": 0.,
+            "projection_altitude": 35785831.00
         }
 
         return res
@@ -300,16 +300,16 @@ class HRITGOMSFileHandler(HRITFileHandler):
     def calibrate(self, data, calibration):
         """Calibrate the data."""
         tic = datetime.now()
-        if calibration == 'counts':
+        if calibration == "counts":
             res = data
-        elif calibration in ['radiance', 'brightness_temperature']:
+        elif calibration in ["radiance", "brightness_temperature"]:
             res = self._calibrate(data)
         else:
             raise NotImplementedError("Don't know how to calibrate to " +
                                       str(calibration))
 
-        res.attrs['standard_name'] = calibration
-        res.attrs['calibration'] = calibration
+        res.attrs["standard_name"] = calibration
+        res.attrs["calibration"] = calibration
 
         logger.debug("Calibration time " + str(datetime.now() - tic))
         return res
@@ -320,7 +320,7 @@ class HRITGOMSFileHandler(HRITFileHandler):
 
     def _calibrate(self, data):
         """Visible/IR channel calibration."""
-        lut = self.prologue['ImageCalibration'][self.chid]
+        lut = self.prologue["ImageCalibration"][self.chid]
         if abs(lut).max() > 16777216:
             lut = lut.astype(np.float64)
         else:
@@ -337,26 +337,26 @@ class HRITGOMSFileHandler(HRITFileHandler):
     def get_area_def(self, dsid):
         """Get the area definition of the band."""
         pdict = {}
-        pdict['cfac'] = np.int32(self.mda['cfac'])
-        pdict['lfac'] = np.int32(self.mda['lfac'])
-        pdict['coff'] = np.float32(self.mda['coff'])
-        pdict['loff'] = np.float32(self.mda['loff'])
+        pdict["cfac"] = np.int32(self.mda["cfac"])
+        pdict["lfac"] = np.int32(self.mda["lfac"])
+        pdict["coff"] = np.float32(self.mda["coff"])
+        pdict["loff"] = np.float32(self.mda["loff"])
 
-        pdict['a'] = 6378169.00
-        pdict['b'] = 6356583.80
-        pdict['h'] = 35785831.00
-        pdict['scandir'] = 'N2S'
+        pdict["a"] = 6378169.00
+        pdict["b"] = 6356583.80
+        pdict["h"] = 35785831.00
+        pdict["scandir"] = "N2S"
 
-        pdict['ssp_lon'] = self.mda['projection_parameters']['SSP_longitude']
+        pdict["ssp_lon"] = self.mda["projection_parameters"]["SSP_longitude"]
 
-        pdict['nlines'] = int(self.mda['number_of_lines'])
-        pdict['ncols'] = int(self.mda['number_of_columns'])
+        pdict["nlines"] = int(self.mda["number_of_lines"])
+        pdict["ncols"] = int(self.mda["number_of_columns"])
 
-        pdict['loff'] = pdict['nlines'] - pdict['loff']
+        pdict["loff"] = pdict["nlines"] - pdict["loff"]
 
-        pdict['a_name'] = 'geosgoms'
-        pdict['a_desc'] = 'Electro-L/GOMS channel area'
-        pdict['p_id'] = 'goms'
+        pdict["a_name"] = "geosgoms"
+        pdict["a_desc"] = "Electro-L/GOMS channel area"
+        pdict["p_id"] = "goms"
 
         area_extent = get_area_extent(pdict)
         area = get_area_definition(pdict, area_extent)
