@@ -68,8 +68,8 @@ geolocation calculations.
 
 
 The reading routine supports channel data in counts, radiances, and (depending
-on channel) brightness temperatures or reflectances. The brightness temperature and reflectance calculation is based on the formulas indicated in
-`PUG`_.
+on channel) brightness temperatures or reflectances. The brightness temperature and reflectance calculation is based on
+the formulas indicated in `PUG`_.
 Radiance datasets are returned in units of radiance per unit wavenumber (mW m-2 sr-1 (cm-1)-1). Radiances can be
 converted to units of radiance per unit wavelength (W m-2 um-1 sr-1) by multiplying with the
 `radiance_unit_conversion_coefficient` dataset attribute.
@@ -131,26 +131,26 @@ logger = logging.getLogger(__name__)
 # dict containing all available auxiliary data parameters to be read using the index map. Keys are the
 # parameter name and values are the paths to the variable inside the netcdf
 AUX_DATA = {
-    'subsatellite_latitude': 'state/platform/subsatellite_latitude',
-    'subsatellite_longitude': 'state/platform/subsatellite_longitude',
-    'platform_altitude': 'state/platform/platform_altitude',
-    'subsolar_latitude': 'state/celestial/subsolar_latitude',
-    'subsolar_longitude': 'state/celestial/subsolar_longitude',
-    'earth_sun_distance': 'state/celestial/earth_sun_distance',
-    'sun_satellite_distance': 'state/celestial/sun_satellite_distance',
-    'time': 'time',
-    'swath_number': 'data/swath_number',
-    'swath_direction': 'data/swath_direction',
+    "subsatellite_latitude": "state/platform/subsatellite_latitude",
+    "subsatellite_longitude": "state/platform/subsatellite_longitude",
+    "platform_altitude": "state/platform/platform_altitude",
+    "subsolar_latitude": "state/celestial/subsolar_latitude",
+    "subsolar_longitude": "state/celestial/subsolar_longitude",
+    "earth_sun_distance": "state/celestial/earth_sun_distance",
+    "sun_satellite_distance": "state/celestial/sun_satellite_distance",
+    "time": "time",
+    "swath_number": "data/swath_number",
+    "swath_direction": "data/swath_direction",
 }
 
-HIGH_RES_GRID_INFO = {'fci_l1c_hrfi': {'grid_type': '500m',
-                                       'grid_width': 22272},
-                      'fci_l1c_fdhsi': {'grid_type': '1km',
-                                        'grid_width': 11136}}
-LOW_RES_GRID_INFO = {'fci_l1c_hrfi': {'grid_type': '1km',
-                                      'grid_width': 11136},
-                     'fci_l1c_fdhsi': {'grid_type': '2km',
-                                       'grid_width': 5568}}
+HIGH_RES_GRID_INFO = {"fci_l1c_hrfi": {"grid_type": "500m",
+                                       "grid_width": 22272},
+                      "fci_l1c_fdhsi": {"grid_type": "1km",
+                                        "grid_width": 11136}}
+LOW_RES_GRID_INFO = {"fci_l1c_hrfi": {"grid_type": "1km",
+                                      "grid_width": 11136},
+                     "fci_l1c_fdhsi": {"grid_type": "2km",
+                                       "grid_width": 5568}}
 
 
 def _get_aux_data_name_from_dsname(dsname):
@@ -206,9 +206,9 @@ class FCIL1cNCFileHandler(NetCDF4FsspecFileHandler):
                          filetype_info,
                          cache_var_size=0,
                          cache_handle=True)
-        logger.debug('Reading: {}'.format(self.filename))
-        logger.debug('Start: {}'.format(self.start_time))
-        logger.debug('End: {}'.format(self.end_time))
+        logger.debug("Reading: {}".format(self.filename))
+        logger.debug("Start: {}".format(self.start_time))
+        logger.debug("End: {}".format(self.end_time))
 
         self._cache = {}
 
@@ -218,7 +218,7 @@ class FCIL1cNCFileHandler(NetCDF4FsspecFileHandler):
 
         As RSS is not yet implemeted and error will be raised if RSS are to be read
         """
-        if not self.filename_info['coverage'] == 'FD':
+        if not self.filename_info["coverage"] == "FD":
             raise NotImplementedError(f"coverage for {self.filename_info['coverage']} not supported by this reader")
             return 2.5
         return 10
@@ -227,7 +227,7 @@ class FCIL1cNCFileHandler(NetCDF4FsspecFileHandler):
     def nominal_start_time(self):
         """Get nominal start time."""
         rc_date = self.observation_start_time.replace(hour=0, minute=0, second=0, microsecond=0)
-        return rc_date + timedelta(minutes=(self.filename_info['repeat_cycle_in_day']-1)*self.rc_period_min)
+        return rc_date + timedelta(minutes=(self.filename_info["repeat_cycle_in_day"]-1)*self.rc_period_min)
 
     @property
     def nominal_end_time(self):
@@ -237,12 +237,12 @@ class FCIL1cNCFileHandler(NetCDF4FsspecFileHandler):
     @property
     def observation_start_time(self):
         """Get observation start time."""
-        return self.filename_info['start_time']
+        return self.filename_info["start_time"]
 
     @property
     def observation_end_time(self):
         """Get observation end time."""
-        return self.filename_info['end_time']
+        return self.filename_info["end_time"]
 
     @property
     def start_time(self):
@@ -256,9 +256,9 @@ class FCIL1cNCFileHandler(NetCDF4FsspecFileHandler):
 
     def get_channel_measured_group_path(self, channel):
         """Get the channel's measured group path."""
-        if self.filetype_info['file_type'] == 'fci_l1c_hrfi':
-            channel += '_hr'
-        measured_group_path = 'data/{}/measured'.format(channel)
+        if self.filetype_info["file_type"] == "fci_l1c_hrfi":
+            channel += "_hr"
+        measured_group_path = "data/{}/measured".format(channel)
 
         return measured_group_path
 
@@ -273,25 +273,25 @@ class FCIL1cNCFileHandler(NetCDF4FsspecFileHandler):
         Note: in the FCI terminology, a segment is actually called "chunk". To avoid confusion with the dask concept
         of chunk, and to be consistent with SEVIRI, we opt to use the word segment.
         """
-        vis_06_measured_path = self.get_channel_measured_group_path('vis_06')
-        ir_105_measured_path = self.get_channel_measured_group_path('ir_105')
+        vis_06_measured_path = self.get_channel_measured_group_path("vis_06")
+        ir_105_measured_path = self.get_channel_measured_group_path("ir_105")
 
-        file_type = self.filetype_info['file_type']
+        file_type = self.filetype_info["file_type"]
 
         segment_position_info = {
-            HIGH_RES_GRID_INFO[file_type]['grid_type']: {
-                'start_position_row': self.get_and_cache_npxr(vis_06_measured_path + '/start_position_row').item(),
-                'end_position_row': self.get_and_cache_npxr(vis_06_measured_path + '/end_position_row').item(),
-                'segment_height': self.get_and_cache_npxr(vis_06_measured_path + '/end_position_row').item() -
-                self.get_and_cache_npxr(vis_06_measured_path + '/start_position_row').item() + 1,
-                'grid_width': HIGH_RES_GRID_INFO[file_type]['grid_width']
+            HIGH_RES_GRID_INFO[file_type]["grid_type"]: {
+                "start_position_row": self.get_and_cache_npxr(vis_06_measured_path + "/start_position_row").item(),
+                "end_position_row": self.get_and_cache_npxr(vis_06_measured_path + "/end_position_row").item(),
+                "segment_height": self.get_and_cache_npxr(vis_06_measured_path + "/end_position_row").item() -
+                self.get_and_cache_npxr(vis_06_measured_path + "/start_position_row").item() + 1,
+                "grid_width": HIGH_RES_GRID_INFO[file_type]["grid_width"]
             },
-            LOW_RES_GRID_INFO[file_type]['grid_type']: {
-                'start_position_row': self.get_and_cache_npxr(ir_105_measured_path + '/start_position_row').item(),
-                'end_position_row': self.get_and_cache_npxr(ir_105_measured_path + '/end_position_row').item(),
-                'segment_height': self.get_and_cache_npxr(ir_105_measured_path + '/end_position_row').item() -
-                self.get_and_cache_npxr(ir_105_measured_path + '/start_position_row').item() + 1,
-                'grid_width': LOW_RES_GRID_INFO[file_type]['grid_width']
+            LOW_RES_GRID_INFO[file_type]["grid_type"]: {
+                "start_position_row": self.get_and_cache_npxr(ir_105_measured_path + "/start_position_row").item(),
+                "end_position_row": self.get_and_cache_npxr(ir_105_measured_path + "/end_position_row").item(),
+                "segment_height": self.get_and_cache_npxr(ir_105_measured_path + "/end_position_row").item() -
+                self.get_and_cache_npxr(ir_105_measured_path + "/start_position_row").item() + 1,
+                "grid_width": LOW_RES_GRID_INFO[file_type]["grid_width"]
             }
         }
 
@@ -299,14 +299,14 @@ class FCIL1cNCFileHandler(NetCDF4FsspecFileHandler):
 
     def get_dataset(self, key, info=None):
         """Load a dataset."""
-        logger.debug('Reading {} from {}'.format(key['name'], self.filename))
-        if "pixel_quality" in key['name']:
-            return self._get_dataset_quality(key['name'])
-        elif "index_map" in key['name']:
-            return self._get_dataset_index_map(key['name'])
-        elif _get_aux_data_name_from_dsname(key['name']) is not None:
-            return self._get_dataset_aux_data(key['name'])
-        elif any(lb in key['name'] for lb in {"vis_", "ir_", "nir_", "wv_"}):
+        logger.debug("Reading {} from {}".format(key["name"], self.filename))
+        if "pixel_quality" in key["name"]:
+            return self._get_dataset_quality(key["name"])
+        elif "index_map" in key["name"]:
+            return self._get_dataset_index_map(key["name"])
+        elif _get_aux_data_name_from_dsname(key["name"]) is not None:
+            return self._get_dataset_aux_data(key["name"])
+        elif any(lb in key["name"] for lb in {"vis_", "ir_", "nir_", "wv_"}):
             return self._get_dataset_measurand(key, info=info)
         else:
             raise ValueError("Unknown dataset key, not a channel, quality or auxiliary data: "
@@ -321,7 +321,7 @@ class FCIL1cNCFileHandler(NetCDF4FsspecFileHandler):
         """
         # Get the dataset
         # Get metadata for given dataset
-        measured = self.get_channel_measured_group_path(key['name'])
+        measured = self.get_channel_measured_group_path(key["name"])
         data = self[measured + "/effective_radiance"]
 
         attrs = dict(data.attrs).copy()
@@ -330,15 +330,14 @@ class FCIL1cNCFileHandler(NetCDF4FsspecFileHandler):
 
         fv = attrs.pop(
             "FillValue",
-            default_fillvals.get(data.dtype.str[1:], np.nan))
-        vr = attrs.get("valid_range", [-np.inf, np.inf])
-        if key['calibration'] == "counts":
+            default_fillvals.get(data.dtype.str[1:], np.float32(np.nan)))
+        vr = attrs.get("valid_range", [np.float32(-np.inf), np.float32(np.inf)])
+        if key["calibration"] == "counts":
             attrs["_FillValue"] = fv
-            nfv = fv
+            nfv = data.dtype.type(fv)
         else:
-            nfv = np.nan
-        data = data.where(data >= vr[0], nfv)
-        data = data.where(data <= vr[1], nfv)
+            nfv = np.float32(np.nan)
+        data = data.where((data >= vr[0]) & (data <= vr[1]), nfv)
 
         res = self.calibrate(data, key)
 
@@ -357,7 +356,7 @@ class FCIL1cNCFileHandler(NetCDF4FsspecFileHandler):
         # https://github.com/pytroll/satpy/issues/1171.
         if "pixel_quality" in attrs["ancillary_variables"]:
             attrs["ancillary_variables"] = attrs["ancillary_variables"].replace(
-                "pixel_quality", key['name'] + "_pixel_quality")
+                "pixel_quality", key["name"] + "_pixel_quality")
         else:
             raise ValueError(
                 "Unexpected value for attribute ancillary_variables, "
@@ -373,20 +372,20 @@ class FCIL1cNCFileHandler(NetCDF4FsspecFileHandler):
             self["attr/platform"], self["attr/platform"])
 
         # remove unpacking parameters for calibrated data
-        if key['calibration'] in ['brightness_temperature', 'reflectance']:
+        if key["calibration"] in ["brightness_temperature", "reflectance"]:
             res.attrs.pop("add_offset")
             res.attrs.pop("warm_add_offset")
             res.attrs.pop("scale_factor")
             res.attrs.pop("warm_scale_factor")
 
         # remove attributes from original file which don't apply anymore
-        res.attrs.pop('long_name')
+        res.attrs.pop("long_name")
         # Add time_parameter attributes
-        res.attrs['time_parameters'] = {
-            'nominal_start_time': self.nominal_start_time,
-            'nominal_end_time': self.nominal_end_time,
-            'observation_start_time': self.observation_start_time,
-            'observation_end_time': self.observation_end_time,
+        res.attrs["time_parameters"] = {
+            "nominal_start_time": self.nominal_start_time,
+            "nominal_end_time": self.nominal_end_time,
+            "observation_start_time": self.observation_start_time,
+            "observation_end_time": self.observation_end_time,
             }
         res.attrs.update(self.orbital_param)
 
@@ -395,9 +394,9 @@ class FCIL1cNCFileHandler(NetCDF4FsspecFileHandler):
     @cached_property
     def orbital_param(self):
         """Compute the orbital parameters for the current segment."""
-        actual_subsat_lon = float(np.nanmean(self._get_aux_data_lut_vector('subsatellite_longitude')))
-        actual_subsat_lat = float(np.nanmean(self._get_aux_data_lut_vector('subsatellite_latitude')))
-        actual_sat_alt = float(np.nanmean(self._get_aux_data_lut_vector('platform_altitude')))
+        actual_subsat_lon = float(np.nanmean(self._get_aux_data_lut_vector("subsatellite_longitude")))
+        actual_subsat_lat = float(np.nanmean(self._get_aux_data_lut_vector("subsatellite_latitude")))
+        actual_sat_alt = float(np.nanmean(self._get_aux_data_lut_vector("platform_altitude")))
         nominal_and_proj_subsat_lon = float(
             self.get_and_cache_npxr("data/mtg_geos_projection/attr/longitude_of_projection_origin"))
         nominal_and_proj_subsat_lat = 0
@@ -405,16 +404,16 @@ class FCIL1cNCFileHandler(NetCDF4FsspecFileHandler):
             self.get_and_cache_npxr("data/mtg_geos_projection/attr/perspective_point_height"))
 
         orb_param_dict = {
-            'orbital_parameters': {
-                'satellite_actual_longitude': actual_subsat_lon,
-                'satellite_actual_latitude': actual_subsat_lat,
-                'satellite_actual_altitude': actual_sat_alt,
-                'satellite_nominal_longitude': nominal_and_proj_subsat_lon,
-                'satellite_nominal_latitude': nominal_and_proj_subsat_lat,
-                'satellite_nominal_altitude': nominal_and_proj_sat_alt,
-                'projection_longitude': nominal_and_proj_subsat_lon,
-                'projection_latitude': nominal_and_proj_subsat_lat,
-                'projection_altitude': nominal_and_proj_sat_alt,
+            "orbital_parameters": {
+                "satellite_actual_longitude": actual_subsat_lon,
+                "satellite_actual_latitude": actual_subsat_lat,
+                "satellite_actual_altitude": actual_sat_alt,
+                "satellite_nominal_longitude": nominal_and_proj_subsat_lon,
+                "satellite_nominal_latitude": nominal_and_proj_subsat_lat,
+                "satellite_nominal_altitude": nominal_and_proj_sat_alt,
+                "projection_longitude": nominal_and_proj_subsat_lon,
+                "projection_latitude": nominal_and_proj_subsat_lat,
+                "projection_altitude": nominal_and_proj_sat_alt,
             }}
 
         return orb_param_dict
@@ -432,7 +431,7 @@ class FCIL1cNCFileHandler(NetCDF4FsspecFileHandler):
         dv_path = grp_path + "/index_map"
         data = self[dv_path]
 
-        data = data.where(data != data.attrs.get('_FillValue', 65535))
+        data = data.where(data != data.attrs.get("_FillValue", 65535))
         return data
 
     def _get_aux_data_lut_vector(self, aux_data_name):
@@ -446,14 +445,14 @@ class FCIL1cNCFileHandler(NetCDF4FsspecFileHandler):
 
     @staticmethod
     def _getitem(block, lut):
-        return lut[block.astype('uint16')]
+        return lut[block.astype("uint16")]
 
     def _get_dataset_aux_data(self, dsname):
         """Get the auxiliary data arrays using the index map."""
         # get index map
         index_map = self._get_dataset_index_map(_get_channel_name_from_dsname(dsname))
         # subtract minimum of index variable (index_offset)
-        index_map -= np.min(self.get_and_cache_npxr('index'))
+        index_map -= np.min(self.get_and_cache_npxr("index"))
 
         # get lut values from 1-d vector variable
         lut = self._get_aux_data_lut_vector(_get_aux_data_name_from_dsname(dsname))
@@ -472,14 +471,14 @@ class FCIL1cNCFileHandler(NetCDF4FsspecFileHandler):
         # if a user requests a pixel quality or index map before the channel data, the
         # yaml-reader will ask the area extent of the pixel quality/index map field,
         # which will ultimately end up here
-        channel_name = _get_channel_name_from_dsname(key['name'])
+        channel_name = _get_channel_name_from_dsname(key["name"])
         # Get metadata for given dataset
         measured = self.get_channel_measured_group_path(channel_name)
         # Get start/end line and column of loaded swath.
         nlines, ncols = self[measured + "/effective_radiance/shape"]
 
-        logger.debug('Channel {} resolution: {}'.format(channel_name, ncols))
-        logger.debug('Row/Cols: {} / {}'.format(nlines, ncols))
+        logger.debug("Channel {} resolution: {}".format(channel_name, ncols))
+        logger.debug("Row/Cols: {} / {}".format(nlines, ncols))
 
         # Calculate full globe line extent
         h = float(self.get_and_cache_npxr("data/mtg_geos_projection/attr/perspective_point_height"))
@@ -489,16 +488,16 @@ class FCIL1cNCFileHandler(NetCDF4FsspecFileHandler):
             coord_radian = self.get_and_cache_npxr(measured + "/{:s}".format(coord))
 
             # TODO remove this check when old versions of IDPF test data (<v4) are deprecated.
-            if coord == "x" and coord_radian.attrs['scale_factor'] > 0:
-                coord_radian.attrs['scale_factor'] *= -1
+            if coord == "x" and coord_radian.attrs["scale_factor"] > 0:
+                coord_radian.attrs["scale_factor"] *= -1
 
             # TODO remove this check when old versions of IDPF test data (<v5) are deprecated.
-            if type(coord_radian.attrs['scale_factor']) is np.float32:
-                coord_radian.attrs['scale_factor'] = coord_radian.attrs['scale_factor'].astype('float64')
-            if type(coord_radian.attrs['add_offset']) is np.float32:
-                coord_radian.attrs['add_offset'] = coord_radian.attrs['add_offset'].astype('float64')
+            if type(coord_radian.attrs["scale_factor"]) is np.float32:
+                coord_radian.attrs["scale_factor"] = coord_radian.attrs["scale_factor"].astype("float64")
+            if type(coord_radian.attrs["add_offset"]) is np.float32:
+                coord_radian.attrs["add_offset"] = coord_radian.attrs["add_offset"].astype("float64")
 
-            coord_radian_num = coord_radian[:] * coord_radian.attrs['scale_factor'] + coord_radian.attrs['add_offset']
+            coord_radian_num = coord_radian[:] * coord_radian.attrs["scale_factor"] + coord_radian.attrs["add_offset"]
 
             # FCI defines pixels by centroids (see PUG), while pyresample
             # defines corners as lower left corner of lower left pixel, upper right corner of upper right pixel
@@ -512,9 +511,9 @@ class FCIL1cNCFileHandler(NetCDF4FsspecFileHandler):
             # The values of y go from negative (South) to positive (North) and the scale factor of y is positive.
 
             # South-West corner (x positive, y negative)
-            first_coord_radian = coord_radian_num[0] - coord_radian.attrs['scale_factor'] / 2
+            first_coord_radian = coord_radian_num[0] - coord_radian.attrs["scale_factor"] / 2
             # North-East corner (x negative, y positive)
-            last_coord_radian = coord_radian_num[-1] + coord_radian.attrs['scale_factor'] / 2
+            last_coord_radian = coord_radian_num[-1] + coord_radian.attrs["scale_factor"] / 2
 
             # convert to arc length in m
             first_coord = first_coord_radian * h  # arc length in m
@@ -546,8 +545,8 @@ class FCIL1cNCFileHandler(NetCDF4FsspecFileHandler):
         """Calculate on-fly area definition for a dataset in geos-projection."""
         # assumption: channels with same resolution should have same area
         # cache results to improve performance
-        if key['resolution'] in self._cache:
-            return self._cache[key['resolution']]
+        if key["resolution"] in self._cache:
+            return self._cache[key["resolution"]]
 
         a = float(self.get_and_cache_npxr("data/mtg_geos_projection/attr/semi_major_axis"))
         h = float(self.get_and_cache_npxr("data/mtg_geos_projection/attr/perspective_point_height"))
@@ -556,46 +555,46 @@ class FCIL1cNCFileHandler(NetCDF4FsspecFileHandler):
         sweep = str(self.get_and_cache_npxr("data/mtg_geos_projection/attr/sweep_angle_axis"))
 
         area_extent, nlines, ncols = self.calc_area_extent(key)
-        logger.debug('Calculated area extent: {}'
-                     .format(''.join(str(area_extent))))
+        logger.debug("Calculated area extent: {}"
+                     .format("".join(str(area_extent))))
 
         # use a (semi-major axis) and rf (reverse flattening) to define ellipsoid as recommended by EUM (see PUG)
-        proj_dict = {'a': a,
-                     'lon_0': lon_0,
-                     'h': h,
+        proj_dict = {"a": a,
+                     "lon_0": lon_0,
+                     "h": h,
                      "rf": rf,
-                     'proj': 'geos',
-                     'units': 'm',
+                     "proj": "geos",
+                     "units": "m",
                      "sweep": sweep}
 
-        area_naming_input_dict = {'platform_name': 'mtg',
-                                  'instrument_name': 'fci',
-                                  'resolution': int(key['resolution'])
+        area_naming_input_dict = {"platform_name": "mtg",
+                                  "instrument_name": "fci",
+                                  "resolution": int(key["resolution"])
                                   }
         area_naming = get_geos_area_naming({**area_naming_input_dict,
-                                            **get_service_mode('fci', lon_0)})
+                                            **get_service_mode("fci", lon_0)})
 
         area = geometry.AreaDefinition(
-            area_naming['area_id'],
-            area_naming['description'],
+            area_naming["area_id"],
+            area_naming["description"],
             "",
             proj_dict,
             ncols,
             nlines,
             area_extent)
 
-        self._cache[key['resolution']] = area
+        self._cache[key["resolution"]] = area
         return area
 
     def calibrate(self, data, key):
         """Calibrate data."""
-        if key['calibration'] in ['brightness_temperature', 'reflectance', 'radiance']:
+        if key["calibration"] in ["brightness_temperature", "reflectance", "radiance"]:
             data = self.calibrate_counts_to_physical_quantity(data, key)
-        elif key['calibration'] != "counts":
+        elif key["calibration"] != "counts":
             logger.error(
                 "Received unknown calibration key.  Expected "
                 "'brightness_temperature', 'reflectance', 'radiance' or 'counts', got "
-                + key['calibration'] + ".")
+                + key["calibration"] + ".")
 
         return data
 
@@ -605,16 +604,16 @@ class FCIL1cNCFileHandler(NetCDF4FsspecFileHandler):
 
         data = self.calibrate_counts_to_rad(data, key)
 
-        if key['calibration'] == 'brightness_temperature':
+        if key["calibration"] == "brightness_temperature":
             data = self.calibrate_rad_to_bt(data, key)
-        elif key['calibration'] == 'reflectance':
+        elif key["calibration"] == "reflectance":
             data = self.calibrate_rad_to_refl(data, key)
 
         return data
 
     def calibrate_counts_to_rad(self, data, key):
         """Calibrate counts to radiances."""
-        if key['name'] == 'ir_38':
+        if key["name"] == "ir_38":
             data = xr.where(((2 ** 12 - 1 < data) & (data <= 2 ** 13 - 1)),
                             (data * data.attrs.get("warm_scale_factor", 1) +
                              data.attrs.get("warm_add_offset", 0)),
@@ -625,24 +624,23 @@ class FCIL1cNCFileHandler(NetCDF4FsspecFileHandler):
             data = (data * data.attrs.get("scale_factor", 1) +
                     data.attrs.get("add_offset", 0))
 
-        measured = self.get_channel_measured_group_path(key['name'])
-        data.attrs.update({'radiance_unit_conversion_coefficient':
-                          self.get_and_cache_npxr(measured + '/radiance_unit_conversion_coefficient')})
+        measured = self.get_channel_measured_group_path(key["name"])
+        data.attrs.update({"radiance_unit_conversion_coefficient":
+                          self.get_and_cache_npxr(measured + "/radiance_unit_conversion_coefficient")})
         return data
 
     def calibrate_rad_to_bt(self, radiance, key):
         """IR channel calibration."""
         # using the method from PUG section Converting from Effective Radiance to Brightness Temperature for IR Channels
+        measured = self.get_channel_measured_group_path(key["name"])
 
-        measured = self.get_channel_measured_group_path(key['name'])
+        vc = self.get_and_cache_npxr(measured + "/radiance_to_bt_conversion_coefficient_wavenumber").astype(np.float32)
 
-        vc = self.get_and_cache_npxr(measured + "/radiance_to_bt_conversion_coefficient_wavenumber")
+        a = self.get_and_cache_npxr(measured + "/radiance_to_bt_conversion_coefficient_a").astype(np.float32)
+        b = self.get_and_cache_npxr(measured + "/radiance_to_bt_conversion_coefficient_b").astype(np.float32)
 
-        a = self.get_and_cache_npxr(measured + "/radiance_to_bt_conversion_coefficient_a")
-        b = self.get_and_cache_npxr(measured + "/radiance_to_bt_conversion_coefficient_b")
-
-        c1 = self.get_and_cache_npxr(measured + "/radiance_to_bt_conversion_constant_c1")
-        c2 = self.get_and_cache_npxr(measured + "/radiance_to_bt_conversion_constant_c2")
+        c1 = self.get_and_cache_npxr(measured + "/radiance_to_bt_conversion_constant_c1").astype(np.float32)
+        c2 = self.get_and_cache_npxr(measured + "/radiance_to_bt_conversion_constant_c2").astype(np.float32)
 
         for v in (vc, a, b, c1, c2):
             if v == v.attrs.get("FillValue",
@@ -653,38 +651,39 @@ class FCIL1cNCFileHandler(NetCDF4FsspecFileHandler):
                         v.attrs.get("long_name",
                                     "at least one necessary coefficient"),
                         measured))
-                return radiance * np.nan
+                return radiance * np.float32(np.nan)
 
         nom = c2 * vc
-        denom = a * np.log(1 + (c1 * vc ** 3) / radiance)
+        denom = a * np.log(1 + (c1 * vc ** np.float32(3.)) / radiance)
 
         res = nom / denom - b / a
+
         return res
 
     def calibrate_rad_to_refl(self, radiance, key):
         """VIS channel calibration."""
-        measured = self.get_channel_measured_group_path(key['name'])
+        measured = self.get_channel_measured_group_path(key["name"])
 
-        cesi = self.get_and_cache_npxr(measured + "/channel_effective_solar_irradiance")
+        cesi = self.get_and_cache_npxr(measured + "/channel_effective_solar_irradiance").astype(np.float32)
 
         if cesi == cesi.attrs.get(
                 "FillValue", default_fillvals.get(cesi.dtype.str[1:])):
             logger.error(
                 "channel effective solar irradiance set to fill value, "
                 "cannot produce reflectance for {:s}.".format(measured))
-            return radiance * np.nan
+            return radiance * np.float32(np.nan)
 
         sun_earth_distance = np.mean(
             self.get_and_cache_npxr("state/celestial/earth_sun_distance")) / 149597870.7  # [AU]
 
         # TODO remove this check when old versions of IDPF test data (<v5) are deprecated.
         if sun_earth_distance < 0.9 or sun_earth_distance > 1.1:
-            logger.info('The variable state/celestial/earth_sun_distance contains unexpected values'
-                        '(mean value is {} AU). Defaulting to 1 AU for reflectance calculation.'
-                        ''.format(sun_earth_distance))
+            logger.info("The variable state/celestial/earth_sun_distance contains unexpected values"
+                        "(mean value is {} AU). Defaulting to 1 AU for reflectance calculation."
+                        "".format(sun_earth_distance))
             sun_earth_distance = 1
 
-        res = 100 * radiance * np.pi * sun_earth_distance ** 2 / cesi
+        res = 100 * radiance * np.float32(np.pi) * np.float32(sun_earth_distance) ** np.float32(2) / cesi
         return res
 
 
