@@ -22,6 +22,7 @@ import numpy as np
 import xarray as xr
 from pyresample import geometry
 
+from satpy._compat import cached_property
 from satpy.readers._geos_area import get_geos_area_naming, make_ext
 from satpy.readers.eum_base import get_service_mode
 from satpy.readers.file_handlers import BaseFileHandler
@@ -153,6 +154,7 @@ class FciL2NCFileHandler(FciL2CommonFunctions, BaseFileHandler):
         self._projection = self.nc["mtg_geos_projection"]
         self.multi_dims = {"maximum_number_of_layers": "layer", "number_of_vis_channels": "vis_channel_id"}
 
+
     def get_area_def(self, key):
         """Return the area definition."""
         try:
@@ -401,3 +403,59 @@ class FciL2NCSegmentFileHandler(FciL2CommonFunctions, BaseFileHandler):
         area_extent = tuple([ll_x, ll_y, ur_x, ur_y])
 
         return area_extent
+
+class FciL2NCAMVFileHandler(FciL2CommonFunctions, BaseFileHandler):
+    """Reader class for FCI L2 AMV products in NetCDF4 format."""
+    def __init__(self, filename, filename_info, filetype_info):
+        """Open the NetCDF file with xarray and prepare for dataset reading."""
+        super().__init__(filename, filename_info, filetype_info)
+
+    @cached_property
+    def nc(self):
+        """Read the file."""
+        return xr.open_dataset(
+            self.filename,
+            decode_cf=True,
+            mask_and_scale=True,
+            chunks={
+                "number_of_images": CHUNK_SIZE,
+                "number_of_winds": CHUNK_SIZE
+            }
+        )
+
+    def _get_global_attributes(self):
+        """Create a dictionary of global attributes to be added to all datasets.
+
+        Returns:
+            dict: A dictionary of global attributes.
+                filename: name of the product file
+                spacecraft_name: name of the spacecraft
+                sensor: name of sensor
+                platform_name: name of the platform
+
+        """
+        attributes = {
+            "filename": self.filename,
+            "spacecraft_name": self.spacecraft_name,
+            "sensor": self.sensor_name,
+            "platform_name": self.spacecraft_name,
+            "channel":self.filename_info["channel"]
+        }
+        return attributes
+
+    def get_dataset(self, dataset_id, dataset_info):
+        """Get dataset using the file_key in dataset_info."""
+        var_key = dataset_info["file_key"]
+        logger.debug("Reading in file to get dataset with key %s.", var_key)
+
+        try:
+            variable = self.nc[var_key]
+        except KeyError:
+            logger.warning("Could not find key %s in NetCDF file, no valid Dataset created", var_key)
+            return None
+
+        # Manage the attributes of the dataset
+        variable.attrs.update(dataset_info)
+        variable.attrs.update(self._get_global_attributes())
+
+        return variable
