@@ -31,6 +31,7 @@ import dask.array as da
 import numpy as np
 import xarray as xr
 
+from satpy._compat import ArrayLike
 from satpy.readers._geos_area import get_area_definition, get_area_extent, get_geos_area_naming
 from satpy.readers.eum_base import recarray2dict, time_cds_short
 from satpy.readers.hrit_base import (
@@ -46,7 +47,7 @@ class CalibrationError(Exception):
     """Dummy error-class."""
 
 
-logger = logging.getLogger('hrit_goes')
+logger = logging.getLogger("hrit_goes")
 
 # Geometric constants [meters]
 EQUATOR_RADIUS = 6378169.00
@@ -54,30 +55,30 @@ POLE_RADIUS = 6356583.80
 ALTITUDE = 35785831.00
 
 # goes implementation:
-key_header = np.dtype([('key_number', 'u1'),
-                       ('seed', '>f8')])
+key_header = np.dtype([("key_number", "u1"),
+                       ("seed", ">f8")])
 
-segment_identification = np.dtype([('GP_SC_ID', '>i2'),
-                                   ('spectral_channel_id', '>i1'),
-                                   ('segment_sequence_number', '>u2'),
-                                   ('planned_start_segment_number', '>u2'),
-                                   ('planned_end_segment_number', '>u2'),
-                                   ('data_field_representation', '>i1')])
+segment_identification = np.dtype([("GP_SC_ID", ">i2"),
+                                   ("spectral_channel_id", ">i1"),
+                                   ("segment_sequence_number", ">u2"),
+                                   ("planned_start_segment_number", ">u2"),
+                                   ("planned_end_segment_number", ">u2"),
+                                   ("data_field_representation", ">i1")])
 
-image_segment_line_quality = np.dtype([('line_number_in_grid', '>i4'),
-                                       ('line_mean_acquisition',
-                                        [('days', '>u2'),
-                                         ('milliseconds', '>u4')]),
-                                       ('line_validity', 'u1'),
-                                       ('line_radiometric_quality', 'u1'),
-                                       ('line_geometric_quality', 'u1')])
+image_segment_line_quality = np.dtype([("line_number_in_grid", ">i4"),
+                                       ("line_mean_acquisition",
+                                        [("days", ">u2"),
+                                         ("milliseconds", ">u4")]),
+                                       ("line_validity", "u1"),
+                                       ("line_radiometric_quality", "u1"),
+                                       ("line_geometric_quality", "u1")])
 
 goms_variable_length_headers = {
-    image_segment_line_quality: 'image_segment_line_quality'}
+    image_segment_line_quality: "image_segment_line_quality"}
 
-goms_text_headers = {image_data_function: 'image_data_function',
-                     annotation_header: 'annotation_header',
-                     ancillary_text: 'ancillary_text'}
+goms_text_headers = {image_data_function: "image_data_function",
+                     annotation_header: "annotation_header",
+                     ancillary_text: "ancillary_text"}
 
 goes_hdr_map = base_hdr_map.copy()
 goes_hdr_map.update({7: key_header,
@@ -86,59 +87,69 @@ goes_hdr_map.update({7: key_header,
                      })
 
 
-orbit_coef = np.dtype([('StartTime', time_cds_short),
-                       ('EndTime', time_cds_short),
-                       ('X', '>f8', (8, )),
-                       ('Y', '>f8', (8, )),
-                       ('Z', '>f8', (8, )),
-                       ('VX', '>f8', (8, )),
-                       ('VY', '>f8', (8, )),
-                       ('VZ', '>f8', (8, ))])
+orbit_coef = np.dtype([("StartTime", time_cds_short),
+                       ("EndTime", time_cds_short),
+                       ("X", ">f8", (8, )),
+                       ("Y", ">f8", (8, )),
+                       ("Z", ">f8", (8, )),
+                       ("VX", ">f8", (8, )),
+                       ("VY", ">f8", (8, )),
+                       ("VZ", ">f8", (8, ))])
 
-attitude_coef = np.dtype([('StartTime', time_cds_short),
-                          ('EndTime', time_cds_short),
-                          ('XofSpinAxis', '>f8', (8, )),
-                          ('YofSpinAxis', '>f8', (8, )),
-                          ('ZofSpinAxis', '>f8', (8, ))])
+attitude_coef = np.dtype([("StartTime", time_cds_short),
+                          ("EndTime", time_cds_short),
+                          ("XofSpinAxis", ">f8", (8, )),
+                          ("YofSpinAxis", ">f8", (8, )),
+                          ("ZofSpinAxis", ">f8", (8, ))])
 
-cuc_time = np.dtype([('coarse', 'u1', (4, )),
-                     ('fine', 'u1', (3, ))])
+cuc_time = np.dtype([("coarse", "u1", (4, )),
+                     ("fine", "u1", (3, ))])
 
 
-sgs_time = np.dtype([('century', 'u1'),
-                     ('year', 'u1'),
-                     ('doy1', 'u1'),
-                     ('doy_hours', 'u1'),
-                     ('hours_mins', 'u1'),
-                     ('mins_secs', 'u1'),
-                     ('secs_msecs', 'u1'),
-                     ('msecs', 'u1')])
+sgs_time = np.dtype([("century", "u1"),
+                     ("year", "u1"),
+                     ("doy1", "u1"),
+                     ("doy_hours", "u1"),
+                     ("hours_mins", "u1"),
+                     ("mins_secs", "u1"),
+                     ("secs_msecs", "u1"),
+                     ("msecs", "u1")])
 
 
-def make_sgs_time(sgs_time_array):
+def make_sgs_time(sgs_time_array: ArrayLike) -> datetime:
     """Make sgs time."""
-    year = ((sgs_time_array['century'] >> 4) * 1000 +
-            (sgs_time_array['century'] & 15) * 100 +
-            (sgs_time_array['year'] >> 4) * 10 +
-            (sgs_time_array['year'] & 15))
-    doy = ((sgs_time_array['doy1'] >> 4) * 100 +
-           (sgs_time_array['doy1'] & 15) * 10 +
-           (sgs_time_array['doy_hours'] >> 4))
-    hours = ((sgs_time_array['doy_hours'] & 15) * 10 +
-             (sgs_time_array['hours_mins'] >> 4))
-    mins = ((sgs_time_array['hours_mins'] & 15) * 10 +
-            (sgs_time_array['mins_secs'] >> 4))
-    secs = ((sgs_time_array['mins_secs'] & 15) * 10 +
-            (sgs_time_array['secs_msecs'] >> 4))
-    msecs = ((sgs_time_array['secs_msecs'] & 15) * 100 +
-             (sgs_time_array['msecs'] >> 4) * 10 +
-             (sgs_time_array['msecs'] & 15))
-    return (datetime(int(year), 1, 1) +
-            timedelta(days=int(doy - 1),
-                      hours=int(hours),
-                      minutes=int(mins),
-                      seconds=int(secs),
-                      milliseconds=int(msecs)))
+    epoch_year = _epoch_year_from_sgs_time(sgs_time_array)
+    doy_offset = _epoch_doy_offset_from_sgs_time(sgs_time_array)
+    return epoch_year + doy_offset
+
+
+def _epoch_year_from_sgs_time(sgs_time_array: ArrayLike) -> datetime:
+    century = sgs_time_array["century"].astype(np.int64)
+    year = sgs_time_array["year"].astype(np.int64)
+    year = ((century >> 4) * 1000 + (century & 15) * 100 + (year >> 4) * 10 + (year & 15))
+    return datetime(int(year), 1, 1)
+
+
+def _epoch_doy_offset_from_sgs_time(sgs_time_array: ArrayLike) -> timedelta:
+    doy1 = sgs_time_array["doy1"].astype(np.int64)
+    doy_hours = sgs_time_array["doy_hours"].astype(np.int64)
+    hours_mins = sgs_time_array["hours_mins"].astype(np.int64)
+    mins_secs = sgs_time_array["mins_secs"].astype(np.int64)
+    secs_msecs = sgs_time_array["secs_msecs"].astype(np.int64)
+    msecs = sgs_time_array["msecs"].astype(np.int64)
+
+    doy = ((doy1 >> 4) * 100 + (doy1 & 15) * 10 + (doy_hours >> 4))
+    hours = ((doy_hours & 15) * 10 + (hours_mins >> 4))
+    mins = ((hours_mins & 15) * 10 + (mins_secs >> 4))
+    secs = ((mins_secs & 15) * 10 + (secs_msecs >> 4))
+    msecs = ((secs_msecs & 15) * 100 + (msecs >> 4) * 10 + (msecs & 15))
+    return timedelta(
+        days=int(doy - 1),
+        hours=int(hours),
+        minutes=int(mins),
+        seconds=int(secs),
+        milliseconds=int(msecs)
+    )
 
 
 satellite_status = np.dtype([("TagType", "<u4"),
@@ -156,7 +167,7 @@ image_acquisition = np.dtype([("TagType", "<u4"),
                               ("Cel", "<f8")])
 
 
-gvar_float = '>i4'
+gvar_float = ">i4"
 
 
 def make_gvar_float(float_val):
@@ -211,18 +222,18 @@ prologue = np.dtype([
     ("TIVIT", sgs_time),
     ("TCLMT", sgs_time),
     ("TIONA", sgs_time),
-    ("RelativeScanCount", '>u2'),
-    ("AbsoluteScanCount", '>u2'),
-    ("NorthernmostScanLine", '>u2'),
-    ("WesternmostPixel", '>u2'),
-    ("EasternmostPixel", '>u2'),
-    ("NorthernmostFrameLine", '>u2'),
-    ("SouthernmostFrameLine", '>u2'),
-    ("0Pixel", '>u2'),
-    ("0ScanLine", '>u2'),
-    ("0Scan", '>u2'),
-    ("SubSatScan", '>u2'),
-    ("SubSatPixel", '>u2'),
+    ("RelativeScanCount", ">u2"),
+    ("AbsoluteScanCount", ">u2"),
+    ("NorthernmostScanLine", ">u2"),
+    ("WesternmostPixel", ">u2"),
+    ("EasternmostPixel", ">u2"),
+    ("NorthernmostFrameLine", ">u2"),
+    ("SouthernmostFrameLine", ">u2"),
+    ("0Pixel", ">u2"),
+    ("0ScanLine", ">u2"),
+    ("0Scan", ">u2"),
+    ("SubSatScan", ">u2"),
+    ("SubSatPixel", ">u2"),
     ("SubSatLatitude", gvar_float),
     ("SubSatLongitude", gvar_float),
     ("Junk4", "u1", 96),  # move to "word" 295
@@ -250,7 +261,7 @@ class HRITGOESPrologueFileHandler(HRITFileHandler):
     def read_prologue(self):
         """Read the prologue metadata."""
         with open(self.filename, "rb") as fp_:
-            fp_.seek(self.mda['total_header_length'])
+            fp_.seek(self.mda["total_header_length"])
             data = np.fromfile(fp_, dtype=prologue, count=1)
             self.prologue.update(recarray2dict(data))
 
@@ -258,16 +269,16 @@ class HRITGOESPrologueFileHandler(HRITFileHandler):
 
     def process_prologue(self):
         """Reprocess prologue to correct types."""
-        for key in ['TCurr', 'TCHED', 'TCTRL', 'TLHED', 'TLTRL', 'TIPFS',
-                    'TINFS', 'TISPC', 'TIECL', 'TIBBC', 'TISTR', 'TLRAN',
-                    'TIIRT', 'TIVIT', 'TCLMT', 'TIONA']:
+        for key in ["TCurr", "TCHED", "TCTRL", "TLHED", "TLTRL", "TIPFS",
+                    "TINFS", "TISPC", "TIECL", "TIBBC", "TISTR", "TLRAN",
+                    "TIIRT", "TIVIT", "TCLMT", "TIONA"]:
             try:
                 self.prologue[key] = make_sgs_time(self.prologue[key])
             except ValueError:
                 self.prologue.pop(key, None)
                 logger.debug("Invalid data for %s", key)
 
-        for key in ['SubSatLatitude', "SubSatLongitude", "ReferenceLongitude",
+        for key in ["SubSatLatitude", "SubSatLongitude", "ReferenceLongitude",
                     "ReferenceDistance", "ReferenceLatitude"]:
             self.prologue[key] = make_gvar_float(self.prologue[key])
 
@@ -352,7 +363,7 @@ SPACECRAFTS = {
     14: "GOES-14",
     15: "GOES-15"}
 
-SENSOR_NAME = 'goes_imager'
+SENSOR_NAME = "goes_imager"
 
 
 class HRITGOESFileHandler(HRITFileHandler):
@@ -367,12 +378,12 @@ class HRITGOESFileHandler(HRITFileHandler):
                                                    goms_variable_length_headers,
                                                    goms_text_headers))
         self.prologue = prologue.prologue
-        self.chid = self.mda['spectral_channel_id']
+        self.chid = self.mda["spectral_channel_id"]
 
-        sublon = self.prologue['SubSatLongitude']
-        self.mda['projection_parameters']['SSP_longitude'] = sublon
+        sublon = self.prologue["SubSatLongitude"]
+        self.mda["projection_parameters"]["SSP_longitude"] = sublon
 
-        satellite_id = self.prologue['SatelliteID']
+        satellite_id = self.prologue["SatelliteID"]
         self.platform_name = SPACECRAFTS[satellite_id]
 
     def get_dataset(self, key, info):
@@ -380,17 +391,17 @@ class HRITGOESFileHandler(HRITFileHandler):
         logger.debug("Getting raw data")
         res = super(HRITGOESFileHandler, self).get_dataset(key, info)
 
-        self.mda['calibration_parameters'] = self._get_calibration_params()
+        self.mda["calibration_parameters"] = self._get_calibration_params()
 
-        res = self.calibrate(res, key['calibration'])
+        res = self.calibrate(res, key["calibration"])
         new_attrs = info.copy()
         new_attrs.update(res.attrs)
         res.attrs = new_attrs
-        res.attrs['platform_name'] = self.platform_name
-        res.attrs['sensor'] = SENSOR_NAME
-        res.attrs['orbital_parameters'] = {'projection_longitude': self.mda['projection_parameters']['SSP_longitude'],
-                                           'projection_latitude': 0.0,
-                                           'projection_altitude': ALTITUDE}
+        res.attrs["platform_name"] = self.platform_name
+        res.attrs["sensor"] = SENSOR_NAME
+        res.attrs["orbital_parameters"] = {"projection_longitude": self.mda["projection_parameters"]["SSP_longitude"],
+                                           "projection_latitude": 0.0,
+                                           "projection_altitude": ALTITUDE}
         return res
 
     def _get_calibration_params(self):
@@ -398,9 +409,9 @@ class HRITGOESFileHandler(HRITFileHandler):
         params = {}
         idx_table = []
         val_table = []
-        for elt in self.mda['image_data_function'].split(b'\r\n'):
+        for elt in self.mda["image_data_function"].split(b"\r\n"):
             try:
-                key, val = elt.split(b':=')
+                key, val = elt.split(b":=")
                 try:
                     idx_table.append(int(key))
                     val_table.append(float(val))
@@ -408,19 +419,19 @@ class HRITGOESFileHandler(HRITFileHandler):
                     params[key] = val
             except ValueError:
                 pass
-        params['indices'] = np.array(idx_table)
-        params['values'] = np.array(val_table, dtype=np.float32)
+        params["indices"] = np.array(idx_table)
+        params["values"] = np.array(val_table, dtype=np.float32)
         return params
 
     def calibrate(self, data, calibration):
         """Calibrate the data."""
         logger.debug("Calibration")
         tic = datetime.now()
-        if calibration == 'counts':
+        if calibration == "counts":
             return data
-        if calibration == 'reflectance':
+        if calibration == "reflectance":
             res = self._calibrate(data)
-        elif calibration == 'brightness_temperature':
+        elif calibration == "brightness_temperature":
             res = self._calibrate(data)
         else:
             raise NotImplementedError("Don't know how to calibrate to " +
@@ -431,17 +442,17 @@ class HRITGOESFileHandler(HRITFileHandler):
 
     def _calibrate(self, data):
         """Calibrate *data*."""
-        idx = self.mda['calibration_parameters']['indices']
-        val = self.mda['calibration_parameters']['values']
+        idx = self.mda["calibration_parameters"]["indices"]
+        val = self.mda["calibration_parameters"]["values"]
         data.data = da.where(data.data == 0, np.nan, data.data)
         ddata = data.data.map_blocks(np.interp, idx, val, dtype=val.dtype)
         res = xr.DataArray(ddata,
                            dims=data.dims, attrs=data.attrs,
                            coords=data.coords)
         res = res.clip(min=0)
-        units = {b'percent': '%', b'degree Kelvin': 'K'}
-        unit = self.mda['calibration_parameters'][b'_UNIT']
-        res.attrs['units'] = units.get(unit, unit)
+        units = {b"percent": "%", b"degree Kelvin": "K"}
+        unit = self.mda["calibration_parameters"][b"_UNIT"]
+        res.attrs["units"] = units.get(unit, unit)
         return res
 
     def get_area_def(self, dataset_id):
@@ -453,32 +464,32 @@ class HRITGOESFileHandler(HRITFileHandler):
         return area
 
     def _get_proj_dict(self, dataset_id):
-        loff = np.float32(self.mda['loff'])
-        nlines = np.int32(self.mda['number_of_lines'])
+        loff = np.float32(self.mda["loff"])
+        nlines = np.int32(self.mda["number_of_lines"])
         loff = nlines - loff
         name_dict = get_geos_area_naming({
-            'platform_name': self.platform_name,
-            'instrument_name': SENSOR_NAME,
+            "platform_name": self.platform_name,
+            "instrument_name": SENSOR_NAME,
             # Partial scans are padded to full disk
-            'service_name': 'FD',
-            'service_desc': 'Full Disk',
-            'resolution': dataset_id['resolution']
+            "service_name": "FD",
+            "service_desc": "Full Disk",
+            "resolution": dataset_id["resolution"]
         })
         return {
-            'a': EQUATOR_RADIUS,
-            'b': POLE_RADIUS,
-            'ssp_lon': float(self.prologue['SubSatLongitude']),
-            'h': ALTITUDE,
-            'proj': 'geos',
-            'units': 'm',
-            'a_name': name_dict['area_id'],
-            'a_desc': name_dict['description'],
-            'p_id': '',
-            'nlines': nlines,
-            'ncols': np.int32(self.mda['number_of_columns']),
-            'cfac': np.int32(self.mda['cfac']),
-            'lfac': np.int32(self.mda['lfac']),
-            'coff': np.float32(self.mda['coff']),
-            'loff': loff,
-            'scandir': 'N2S'
+            "a": EQUATOR_RADIUS,
+            "b": POLE_RADIUS,
+            "ssp_lon": float(self.prologue["SubSatLongitude"]),
+            "h": ALTITUDE,
+            "proj": "geos",
+            "units": "m",
+            "a_name": name_dict["area_id"],
+            "a_desc": name_dict["description"],
+            "p_id": "",
+            "nlines": nlines,
+            "ncols": np.int32(self.mda["number_of_columns"]),
+            "cfac": np.int32(self.mda["cfac"]),
+            "lfac": np.int32(self.mda["lfac"]),
+            "coff": np.float32(self.mda["coff"]),
+            "loff": loff,
+            "scandir": "N2S"
         }
