@@ -48,41 +48,41 @@ from satpy.readers.eum_base import time_cds_short
 from satpy.readers.file_handlers import BaseFileHandler
 from satpy.readers.seviri_base import dec10216
 
-logger = logging.getLogger('hrit_base')
+logger = logging.getLogger("hrit_base")
 
-common_hdr = np.dtype([('hdr_id', 'u1'),
-                       ('record_length', '>u2')])
+common_hdr = np.dtype([("hdr_id", "u1"),
+                       ("record_length", ">u2")])
 
-primary_header = np.dtype([('file_type', 'u1'),
-                           ('total_header_length', '>u4'),
-                           ('data_field_length', '>u8')])
+primary_header = np.dtype([("file_type", "u1"),
+                           ("total_header_length", ">u4"),
+                           ("data_field_length", ">u8")])
 
-image_structure = np.dtype([('number_of_bits_per_pixel', 'u1'),
-                            ('number_of_columns', '>u2'),
-                            ('number_of_lines', '>u2'),
-                            ('compression_flag_for_data', 'u1')])
+image_structure = np.dtype([("number_of_bits_per_pixel", "u1"),
+                            ("number_of_columns", ">u2"),
+                            ("number_of_lines", ">u2"),
+                            ("compression_flag_for_data", "u1")])
 
-image_navigation = np.dtype([('projection_name', 'S32'),
-                             ('cfac', '>i4'),
-                             ('lfac', '>i4'),
-                             ('coff', '>i4'),
-                             ('loff', '>i4')])
+image_navigation = np.dtype([("projection_name", "S32"),
+                             ("cfac", ">i4"),
+                             ("lfac", ">i4"),
+                             ("coff", ">i4"),
+                             ("loff", ">i4")])
 
-image_data_function = np.dtype([('function', '|S1')])
+image_data_function = np.dtype([("function", "|S1")])
 
-annotation_header = np.dtype([('annotation', '|S1')])
+annotation_header = np.dtype([("annotation", "|S1")])
 
-timestamp_record = np.dtype([('cds_p_field', 'u1'),
-                             ('timestamp', time_cds_short)])
+timestamp_record = np.dtype([("cds_p_field", "u1"),
+                             ("timestamp", time_cds_short)])
 
-ancillary_text = np.dtype([('ancillary', '|S1')])
+ancillary_text = np.dtype([("ancillary", "|S1")])
 
-key_header = np.dtype([('key', '|S1')])
+key_header = np.dtype([("key", "|S1")])
 
-base_text_headers = {image_data_function: 'image_data_function',
-                     annotation_header: 'annotation_header',
-                     ancillary_text: 'ancillary_text',
-                     key_header: 'key_header'}
+base_text_headers = {image_data_function: "image_data_function",
+                     annotation_header: "annotation_header",
+                     ancillary_text: "ancillary_text",
+                     key_header: "key_header"}
 
 base_hdr_map = {0: primary_header,
                 1: image_structure,
@@ -97,7 +97,7 @@ base_hdr_map = {0: primary_header,
 
 def get_xritdecompress_cmd():
     """Find a valid binary for the xRITDecompress command."""
-    cmd = os.environ.get('XRIT_DECOMPRESS_PATH', None)
+    cmd = os.environ.get("XRIT_DECOMPRESS_PATH", None)
     if not cmd:
         raise IOError("XRIT_DECOMPRESS_PATH is not defined (complete path to xRITDecompress)")
 
@@ -112,20 +112,20 @@ def get_xritdecompress_cmd():
 
 def get_xritdecompress_outfile(stdout):
     """Analyse the output of the xRITDecompress command call and return the file."""
-    outfile = b''
+    outfile = b""
     for line in stdout:
         try:
-            k, v = [x.strip() for x in line.split(b':', 1)]
+            k, v = [x.strip() for x in line.split(b":", 1)]
         except ValueError:
             break
-        if k == b'Decompressed file':
+        if k == b"Decompressed file":
             outfile = v
             break
 
     return outfile
 
 
-def decompress(infile, outdir='.'):
+def decompress(infile, outdir="."):
     """Decompress an XRIT data file and return the path to the decompressed file.
 
     It expect to find Eumetsat's xRITDecompress through the environment variable
@@ -149,7 +149,7 @@ def decompress(infile, outdir='.'):
     if not outfile:
         raise IOError("xrit_decompress '%s', failed, no output file is generated" % infile)
 
-    return os.path.join(outdir, outfile.decode('utf-8'))
+    return os.path.join(outdir, outfile.decode("utf-8"))
 
 
 def get_header_id(fp):
@@ -175,20 +175,20 @@ class HRITFileHandler(BaseFileHandler):
         self.mda = {}
         self.hdr_info = hdr_info
         self._get_hd(self.hdr_info)
-        self._start_time = filename_info['start_time']
+        self._start_time = filename_info["start_time"]
         self._end_time = self._start_time + timedelta(minutes=15)
 
     def _get_hd(self, hdr_info):
         """Open the file, read and get the basic file header info and set the mda dictionary."""
         hdr_map, variable_length_headers, text_headers = hdr_info
 
-        with utils.generic_open(self.filename, mode='rb') as fp:
+        with utils.generic_open(self.filename, mode="rb") as fp:
             total_header_length = 16
             while fp.tell() < total_header_length:
                 hdr_id = get_header_id(fp)
-                the_type = hdr_map[hdr_id['hdr_id']]
+                the_type = hdr_map[hdr_id["hdr_id"]]
                 if the_type in variable_length_headers:
-                    field_length = int((hdr_id['record_length'] - 3) /
+                    field_length = int((hdr_id["record_length"] - 3) /
                                        the_type.itemsize)
                     current_hdr = get_header_content(fp, the_type, field_length)
                     key = variable_length_headers[the_type]
@@ -199,7 +199,7 @@ class HRITFileHandler(BaseFileHandler):
                     else:
                         self.mda[key] = current_hdr
                 elif the_type in text_headers:
-                    field_length = int((hdr_id['record_length'] - 3) /
+                    field_length = int((hdr_id["record_length"] - 3) /
                                        the_type.itemsize)
                     char = list(the_type.fields.values())[0][0].char
                     new_type = np.dtype(char + str(field_length))
@@ -210,16 +210,16 @@ class HRITFileHandler(BaseFileHandler):
                     self.mda.update(
                         dict(zip(current_hdr.dtype.names, current_hdr)))
 
-                total_header_length = self.mda['total_header_length']
+                total_header_length = self.mda["total_header_length"]
 
-        self.mda.setdefault('number_of_bits_per_pixel', 10)
+        self.mda.setdefault("number_of_bits_per_pixel", 10)
 
-        self.mda['projection_parameters'] = {'a': 6378169.00,
-                                             'b': 6356583.80,
-                                             'h': 35785831.00,
+        self.mda["projection_parameters"] = {"a": 6378169.00,
+                                             "b": 6356583.80,
+                                             "h": 35785831.00,
                                              # FIXME: find a reasonable SSP
-                                             'SSP_longitude': 0.0}
-        self.mda['orbital_parameters'] = {}
+                                             "SSP_longitude": 0.0}
+        self.mda["orbital_parameters"] = {}
 
     @property
     def observation_start_time(self):
@@ -247,7 +247,7 @@ class HRITFileHandler(BaseFileHandler):
         data = self.read_band(key, info)
 
         # Convert to xarray
-        xdata = xr.DataArray(data, dims=['y', 'x'])
+        xdata = xr.DataArray(data, dims=["y", "x"])
 
         return xdata
 
@@ -282,34 +282,34 @@ class HRITFileHandler(BaseFileHandler):
 
     def get_area_def(self, dsid):
         """Get the area definition of the band."""
-        cfac = np.int32(self.mda['cfac'])
-        lfac = np.int32(self.mda['lfac'])
-        coff = np.float32(self.mda['coff'])
-        loff = np.float32(self.mda['loff'])
+        cfac = np.int32(self.mda["cfac"])
+        lfac = np.int32(self.mda["lfac"])
+        coff = np.float32(self.mda["coff"])
+        loff = np.float32(self.mda["loff"])
 
-        a = self.mda['projection_parameters']['a']
-        b = self.mda['projection_parameters']['b']
-        h = self.mda['projection_parameters']['h']
-        lon_0 = self.mda['projection_parameters']['SSP_longitude']
-        nlines = int(self.mda['number_of_lines'])
-        ncols = int(self.mda['number_of_columns'])
+        a = self.mda["projection_parameters"]["a"]
+        b = self.mda["projection_parameters"]["b"]
+        h = self.mda["projection_parameters"]["h"]
+        lon_0 = self.mda["projection_parameters"]["SSP_longitude"]
+        nlines = int(self.mda["number_of_lines"])
+        ncols = int(self.mda["number_of_columns"])
 
         area_extent = self.get_area_extent((nlines, ncols),
                                            (loff, coff),
                                            (lfac, cfac),
                                            h)
 
-        proj_dict = {'a': float(a),
-                     'b': float(b),
-                     'lon_0': float(lon_0),
-                     'h': float(h),
-                     'proj': 'geos',
-                     'units': 'm'}
+        proj_dict = {"a": float(a),
+                     "b": float(b),
+                     "lon_0": float(lon_0),
+                     "h": float(h),
+                     "proj": "geos",
+                     "units": "m"}
 
         area = geometry.AreaDefinition(
-            'some_area_name',
+            "some_area_name",
             "On-the-fly area",
-            'geosmsg',
+            "geosmsg",
             proj_dict,
             ncols,
             nlines,
@@ -326,14 +326,14 @@ class HRITFileHandler(BaseFileHandler):
                                dtype=output_dtype)
 
     def _get_output_info(self):
-        bpp = self.mda['number_of_bits_per_pixel']
+        bpp = self.mda["number_of_bits_per_pixel"]
         if bpp in [10, 16]:
             output_dtype = np.uint16
         elif bpp == 8:
             output_dtype = np.uint8
         else:
             raise ValueError(f"Unexpected number of bits per pixel: {bpp}")
-        output_shape = (self.mda['number_of_lines'], self.mda['number_of_columns'])
+        output_shape = (self.mda["number_of_lines"], self.mda["number_of_columns"])
         return output_dtype, output_shape
 
 
@@ -361,12 +361,12 @@ class HRITSegment:
         """Set up the segment."""
         self.filename = filename
         self.mda = mda
-        self.lines = mda['number_of_lines']
-        self.cols = mda['number_of_columns']
-        self.bpp = mda['number_of_bits_per_pixel']
-        self.compressed = mda['compression_flag_for_data'] == 1
-        self.offset = mda['total_header_length']
-        self.zipped = os.fspath(filename).endswith('.bz2')
+        self.lines = mda["number_of_lines"]
+        self.cols = mda["number_of_columns"]
+        self.bpp = mda["number_of_bits_per_pixel"]
+        self.compressed = mda["compression_flag_for_data"] == 1
+        self.offset = mda["total_header_length"]
+        self.zipped = os.fspath(filename).endswith(".bz2")
 
     def read_data(self):
         """Read the data."""
@@ -410,7 +410,7 @@ class HRITSegment:
         total_bits = int(self.lines) * int(self.cols) * int(self.bpp)
         input_shape = int(np.ceil(total_bits / 8.))
         if self.bpp == 16:
-            input_dtype = '>u2'
+            input_dtype = ">u2"
             input_shape //= 2
         elif self.bpp in [8, 10]:
             input_dtype = np.uint8
