@@ -48,21 +48,21 @@ logger = logging.getLogger(__name__)
 
 AVHRR_CHANNEL_NAMES = ("1", "2", "3a", "3b", "4", "5")
 
-dtype = np.dtype([('frame_sync', '>u2', (6, )),
-                  ('id', [('id', '>u2'),
-                          ('spare', '>u2')]),
-                  ('timecode', '>u2', (4, )),
-                  ('telemetry', [("ramp_calibration", '>u2', (5, )),
-                                 ("PRT", '>u2', (3, )),
-                                 ("ch3_patch_temp", '>u2'),
-                                 ("spare", '>u2'), ]),
-                  ('back_scan', '>u2', (10, 3)),
-                  ('space_data', '>u2', (10, 5)),
-                  ('sync', '>u2'),
-                  ('TIP_data', '>u2', (520, )),
-                  ('spare', '>u2', (127, )),
-                  ('image_data', '>u2', (2048, 5)),
-                  ('aux_sync', '>u2', (100, ))])
+dtype = np.dtype([("frame_sync", ">u2", (6, )),
+                  ("id", [("id", ">u2"),
+                          ("spare", ">u2")]),
+                  ("timecode", ">u2", (4, )),
+                  ("telemetry", [("ramp_calibration", ">u2", (5, )),
+                                 ("PRT", ">u2", (3, )),
+                                 ("ch3_patch_temp", ">u2"),
+                                 ("spare", ">u2"), ]),
+                  ("back_scan", ">u2", (10, 3)),
+                  ("space_data", ">u2", (10, 5)),
+                  ("sync", ">u2"),
+                  ("TIP_data", ">u2", (520, )),
+                  ("spare", ">u2", (127, )),
+                  ("image_data", ">u2", (2048, 5)),
+                  ("aux_sync", ">u2", (100, ))])
 
 
 def time_seconds(tc_array, year):
@@ -78,9 +78,9 @@ def time_seconds(tc_array, year):
     word = tc_array[:, 3]
     msecs += word & 1023
     return (np.datetime64(
-        str(year) + '-01-01T00:00:00Z', 's') +
-        msecs[:].astype('timedelta64[ms]') +
-        (day - 1)[:].astype('timedelta64[D]'))
+        str(year) + "-01-01T00:00:00Z", "s") +
+        msecs[:].astype("timedelta64[ms]") +
+        (day - 1)[:].astype("timedelta64[D]"))
 
 
 def bfield(array, bit):
@@ -111,13 +111,13 @@ def geo_interpolate(lons32km, lats32km):
 
 def _get_channel_index(key):
     """Get the avhrr channel index."""
-    avhrr_channel_index = {'1': 0,
-                           '2': 1,
-                           '3a': 2,
-                           '3b': 2,
-                           '4': 3,
-                           '5': 4}
-    index = avhrr_channel_index[key['name']]
+    avhrr_channel_index = {"1": 0,
+                           "2": 1,
+                           "3a": 2,
+                           "3b": 2,
+                           "4": 3,
+                           "5": 4}
+    index = avhrr_channel_index[key["name"]]
     return index
 
 
@@ -128,9 +128,9 @@ class HRPTFile(BaseFileHandler):
         """Init the file handler."""
         super(HRPTFile, self).__init__(filename, filename_info, filetype_info)
         self.channels = {i: None for i in AVHRR_CHANNEL_NAMES}
-        self.units = {i: 'counts' for i in AVHRR_CHANNEL_NAMES}
+        self.units = {i: "counts" for i in AVHRR_CHANNEL_NAMES}
 
-        self.year = filename_info.get('start_time', datetime.utcnow()).year
+        self.year = filename_info.get("start_time", datetime.utcnow()).year
 
     @cached_property
     def times(self):
@@ -151,7 +151,7 @@ class HRPTFile(BaseFileHandler):
         """Read the file."""
         with open(self.filename, "rb") as fp_:
             data = np.memmap(fp_, dtype=dtype, mode="r")
-        if np.all(np.median(data['frame_sync'], axis=0) > 1024):
+        if np.all(np.median(data["frame_sync"], axis=0) > 1024):
             data = self._data.newbyteorder()
         return data
 
@@ -163,32 +163,32 @@ class HRPTFile(BaseFileHandler):
     def get_dataset(self, key, info):
         """Get the dataset."""
         attrs = info.copy()
-        attrs['platform_name'] = self.platform_name
+        attrs["platform_name"] = self.platform_name
 
-        if key['name'] in ['latitude', 'longitude']:
+        if key["name"] in ["latitude", "longitude"]:
             data = self._get_navigation_data(key)
         else:
             data = self._get_channel_data(key)
 
-        result = xr.DataArray(data, dims=['y', 'x'], attrs=attrs)
+        result = xr.DataArray(data, dims=["y", "x"], attrs=attrs)
         mask = self._get_ch3_mask_or_true(key)
         return result.where(mask)
 
     def _get_channel_data(self, key):
         """Get channel data."""
         data = da.from_array(self._data["image_data"][:, :, _get_channel_index(key)], chunks=self._chunks)
-        if key['calibration'] != 'counts':
-            if key['name'] in ['1', '2', '3a']:
+        if key["calibration"] != "counts":
+            if key["name"] in ["1", "2", "3a"]:
                 data = self.calibrate_solar_channel(data, key)
 
-            if key['name'] in ['3b', '4', '5']:
+            if key["name"] in ["3b", "4", "5"]:
                 data = self.calibrate_thermal_channel(data, key)
         return data
 
     def _get_navigation_data(self, key):
         """Get navigation data."""
         lons, lats = self.lons_lats
-        if key['name'] == 'latitude':
+        if key["name"] == "latitude":
             data = da.from_array(lats, chunks=self._chunks)
         else:
             data = da.from_array(lons, chunks=self._chunks)
@@ -196,9 +196,9 @@ class HRPTFile(BaseFileHandler):
 
     def _get_ch3_mask_or_true(self, key):
         mask = True
-        if key['name'] == '3a':
+        if key["name"] == "3a":
             mask = np.tile(np.logical_not(self._is3b), (2048, 1)).T
-        elif key['name'] == '3b':
+        elif key["name"] == "3b":
             mask = np.tile(self._is3b, (2048, 1)).T
         return mask
 
@@ -211,7 +211,7 @@ class HRPTFile(BaseFileHandler):
         from pygac.calibration import calibrate_thermal
         line_numbers = (
             np.round((self.times - self.times[-1]) /
-                     np.timedelta64(166666667, 'ns'))).astype(int)
+                     np.timedelta64(166666667, "ns"))).astype(int)
         line_numbers -= line_numbers[0]
         prt, ict, space = self.telemetry
         index = _get_channel_index(key)
@@ -224,8 +224,8 @@ class HRPTFile(BaseFileHandler):
         """Calibrate a solar channel."""
         from pygac.calibration import calibrate_solar
         julian_days = ((np.datetime64(self.start_time)
-                        - np.datetime64(str(self.year) + '-01-01T00:00:00Z'))
-                       / np.timedelta64(1, 'D'))
+                        - np.datetime64(str(self.year) + "-01-01T00:00:00Z"))
+                       / np.timedelta64(1, "D"))
         data = calibrate_solar(data, _get_channel_index(key), self.year, julian_days,
                                self.calibrator)
         return data
@@ -234,16 +234,16 @@ class HRPTFile(BaseFileHandler):
     def calibrator(self):
         """Create a calibrator for the data."""
         from pygac.calibration import Calibrator
-        pg_spacecraft = ''.join(self.platform_name.split()).lower()
+        pg_spacecraft = "".join(self.platform_name.split()).lower()
         return Calibrator(pg_spacecraft)
 
     @cached_property
     def telemetry(self):
         """Get the telemetry."""
         # This isn't converted to dask arrays as it does not work with pygac
-        prt = np.mean(self._data["telemetry"]['PRT'], axis=1)
-        ict = np.mean(self._data['back_scan'], axis=1)
-        space = np.mean(self._data['space_data'][:, :], axis=1)
+        prt = np.mean(self._data["telemetry"]["PRT"], axis=1)
+        ict = np.mean(self._data["back_scan"], axis=1)
+        space = np.mean(self._data["space_data"][:, :], axis=1)
 
         return prt, ict, space
 
