@@ -50,6 +50,10 @@ amsu = "amsu-mhs"
 PLATFORMS = {"n18": "NOAA-18",
              "n19": "NOAA-19",
              "np": "NOAA-19",
+             "n20": "NOAA-20",
+             "n21": "NOAA-21",
+             "n22": "NOAA-22",
+             "n23": "NOAA-23",
              "m2": "MetOp-A",
              "m1": "MetOp-B",
              "m3": "MetOp-C",
@@ -60,11 +64,14 @@ PLATFORMS = {"n18": "NOAA-18",
              "f17": "DMSP-F17",
              "f18": "DMSP-F18",
              "gpm": "GPM",
-             "n20": "NOAA-20",
              }
 SENSOR = {"n18": amsu,
           "n19": amsu,
           "n20": "atms",
+          "n21": "atms",
+          "n22": "atms",
+          "n23": "atms",
+          "n24": "atms",
           "np": amsu,
           "m1": amsu,
           "m2": amsu,
