@@ -37,7 +37,7 @@ class MSUGSAFileHandler(HDF5FileHandler):
     @property
     def start_time(self):
         """Time for timeslot scan start."""
-        dtstr = self['/attr/timestamp_without_timezone']
+        dtstr = self["/attr/timestamp_without_timezone"]
         return datetime.strptime(dtstr, "%Y-%m-%dT%H:%M:%S")
 
     @property
@@ -47,65 +47,65 @@ class MSUGSAFileHandler(HDF5FileHandler):
         There is no documentation but this appears to be
         height above surface in meters.
         """
-        return float(self['/attr/satellite_observation_point_height'])
+        return float(self["/attr/satellite_observation_point_height"])
 
     @property
     def satellite_latitude(self):
         """Satellite latitude at time of scan."""
-        return float(self['/attr/satellite_observation_point_latitude'])
+        return float(self["/attr/satellite_observation_point_latitude"])
 
     @property
     def satellite_longitude(self):
         """Satellite longitude at time of scan."""
-        return float(self['/attr/satellite_observation_point_longitude'])
+        return float(self["/attr/satellite_observation_point_longitude"])
 
     @property
     def sensor_name(self):
         """Sensor name is hardcoded."""
-        sensor = 'msu_gsa'
+        sensor = "msu_gsa"
         return sensor
 
     @property
     def platform_name(self):
         """Platform name is also hardcoded."""
-        platform = 'Arctica-M-N1'
+        platform = "Arctica-M-N1"
         return platform
 
     @staticmethod
     def _apply_scale_offset(in_data):
         """Apply the scale and offset to data."""
-        scl = in_data.attrs['scale']
-        off = in_data.attrs['offset']
+        scl = in_data.attrs["scale"]
+        off = in_data.attrs["offset"]
         return in_data * scl + off
 
     def get_dataset(self, dataset_id, ds_info):
         """Load data variable and metadata and calibrate if needed."""
-        file_key = ds_info.get('file_key', dataset_id['name'])
+        file_key = ds_info.get("file_key", dataset_id["name"])
         data = self[file_key]
         attrs = data.attrs.copy()  # avoid contaminating other band loading
         attrs.update(ds_info)
 
         # The fill value also needs to be applied
-        fill_val = attrs.pop('fill_value')
+        fill_val = attrs.pop("fill_value")
         data = data.where(data != fill_val, np.nan)
 
         # Data has a scale and offset that we must apply
         data = self._apply_scale_offset(data)
 
         # Data is given as radiance values, we must convert if we want reflectance
-        if dataset_id.get('calibration') == "reflectance":
-            solconst = float(attrs.pop('F_solar_constant'))
+        if dataset_id.get("calibration") == "reflectance":
+            solconst = float(attrs.pop("F_solar_constant"))
             data = np.pi * data / solconst
             # Satpy expects reflectance values in 0-100 range
             data = data * 100.
 
         data.attrs = attrs
         data.attrs.update({
-            'platform_name': self.platform_name,
-            'sensor': self.sensor_name,
-            'sat_altitude': self.satellite_altitude,
-            'sat_latitude': self.satellite_latitude,
-            'sat_longitude': self.satellite_longitude,
+            "platform_name": self.platform_name,
+            "sensor": self.sensor_name,
+            "sat_altitude": self.satellite_altitude,
+            "sat_latitude": self.satellite_latitude,
+            "sat_longitude": self.satellite_longitude,
         })
 
         return data
