@@ -103,7 +103,7 @@ class NetCDF4FileHandler(BaseFileHandler):
             file_handle = self._get_file_handle()
         except IOError:
             LOG.exception(
-                'Failed reading file %s. Possibly corrupted file', self.filename)
+                "Failed reading file %s. Possibly corrupted file", self.filename)
             raise
 
         self._set_file_handle_auto_maskandscale(file_handle, auto_maskandscale)
@@ -123,7 +123,7 @@ class NetCDF4FileHandler(BaseFileHandler):
             file_handle.close()
 
     def _get_file_handle(self):
-        return netCDF4.Dataset(self.filename, 'r')
+        return netCDF4.Dataset(self.filename, "r")
 
     @staticmethod
     def _set_file_handle_auto_maskandscale(file_handle, auto_maskandscale):
@@ -132,8 +132,8 @@ class NetCDF4FileHandler(BaseFileHandler):
 
     def _set_xarray_kwargs(self, xarray_kwargs, auto_maskandscale):
         self._xarray_kwargs = xarray_kwargs or {}
-        self._xarray_kwargs.setdefault('chunks', CHUNK_SIZE)
-        self._xarray_kwargs.setdefault('mask_and_scale', auto_maskandscale)
+        self._xarray_kwargs.setdefault("chunks", CHUNK_SIZE)
+        self._xarray_kwargs.setdefault("mask_and_scale", auto_maskandscale)
 
     def collect_metadata(self, name, obj):
         """Collect all file variables and attributes for the provided file object.
@@ -171,11 +171,11 @@ class NetCDF4FileHandler(BaseFileHandler):
     def _collect_listed_variables(self, file_handle, listed_variables):
         variable_name_replacements = self.filetype_info.get("variable_name_replacements")
         for itm in self._get_required_variable_names(listed_variables, variable_name_replacements):
-            parts = itm.split('/')
+            parts = itm.split("/")
             grp = file_handle
             for p in parts[:-1]:
                 if p == "attr":
-                    n = '/'.join(parts)
+                    n = "/".join(parts)
                     self.file_content[n] = self._get_attr_value(grp, parts[-1])
                     break
                 grp = grp[p]
@@ -188,7 +188,7 @@ class NetCDF4FileHandler(BaseFileHandler):
     def _get_required_variable_names(listed_variables, variable_name_replacements):
         variable_names = []
         for var in listed_variables:
-            if variable_name_replacements and '{' in var:
+            if variable_name_replacements and "{" in var:
                 _compose_replacement_names(variable_name_replacements, var, variable_names)
             else:
                 variable_names.append(var)
@@ -290,7 +290,7 @@ class NetCDF4FileHandler(BaseFileHandler):
         # these datasets are closed and inaccessible when the file is
         # closed, need to reopen
         # TODO: Handle HDF4 versus NetCDF3 versus NetCDF4
-        parts = key.rsplit('/', 1)
+        parts = key.rsplit("/", 1)
         if len(parts) == 2:
             group, key = parts
         else:
@@ -392,7 +392,7 @@ class NetCDF4FsspecFileHandler(NetCDF4FileHandler):
             import h5netcdf
             f_obj = open_file_or_filename(self.filename)
             self._use_h5netcdf = True
-            return h5netcdf.File(f_obj, 'r')
+            return h5netcdf.File(f_obj, "r")
 
     def __getitem__(self, key):
         """Get item for given key."""
