@@ -44,15 +44,15 @@ except ImportError:
         "Missing eccodes-python and/or eccodes C-library installation. Use conda to install eccodes")
 
 CHUNK_SIZE = get_legacy_chunk_size()
-logger = logging.getLogger('SeviriL2Bufr')
+logger = logging.getLogger("SeviriL2Bufr")
 
-data_center_dict = {55: {'ssp': 'E0415', 'name': '08'}, 56:  {'ssp': 'E0455', 'name': '09'},
-                    57: {'ssp': 'E0095', 'name': '10'}, 70: {'ssp': 'E0000', 'name': '11'}}
+data_center_dict = {55: {"ssp": "E0415", "name": "08"}, 56: {"ssp": "E0455", "name": "09"},
+                    57: {"ssp": "E0095", "name": "10"}, 70: {"ssp": "E0000", "name": "11"}}
 
-seg_size_dict = {'seviri_l2_bufr_asr': 16, 'seviri_l2_bufr_cla': 16,
-                 'seviri_l2_bufr_csr': 16, 'seviri_l2_bufr_gii': 3,
-                 'seviri_l2_bufr_thu': 16, 'seviri_l2_bufr_toz': 3,
-                 'seviri_l2_bufr_amv': 24}
+seg_size_dict = {"seviri_l2_bufr_asr": 16, "seviri_l2_bufr_cla": 16,
+                 "seviri_l2_bufr_csr": 16, "seviri_l2_bufr_gii": 3,
+                 "seviri_l2_bufr_thu": 16, "seviri_l2_bufr_toz": 3,
+                 "seviri_l2_bufr_amv": 24}
 
 
 class SeviriL2BufrFileHandler(BaseFileHandler):
@@ -83,39 +83,39 @@ class SeviriL2BufrFileHandler(BaseFileHandler):
     """
 
     def __init__(self, filename, filename_info, filetype_info, with_area_definition=False,
-                 rectification_longitude='default', **kwargs):
+                 rectification_longitude="default", **kwargs):
         """Initialise the file handler for SEVIRI L2 BUFR data."""
         super(SeviriL2BufrFileHandler, self).__init__(filename,
                                                       filename_info,
                                                       filetype_info)
 
-        if ('server' in filename_info):
+        if ("server" in filename_info):
             # EUMETSAT Offline Bufr product
             self.mpef_header = self._read_mpef_header()
         else:
             # Product was retrieved from the EUMETSAT Data Center
-            timeStr = self.get_attribute('typicalDate')+self.get_attribute('typicalTime')
+            timeStr = self.get_attribute("typicalDate")+self.get_attribute("typicalTime")
             buf_start_time = datetime.strptime(timeStr, "%Y%m%d%H%M%S")
-            sc_id = self.get_attribute('satelliteIdentifier')
+            sc_id = self.get_attribute("satelliteIdentifier")
             self.mpef_header = {}
-            self.mpef_header['NominalTime'] = buf_start_time
-            self.mpef_header['SpacecraftName'] = data_center_dict[sc_id]['name']
-            self.mpef_header['RectificationLongitude'] = data_center_dict[sc_id]['ssp']
+            self.mpef_header["NominalTime"] = buf_start_time
+            self.mpef_header["SpacecraftName"] = data_center_dict[sc_id]["name"]
+            self.mpef_header["RectificationLongitude"] = data_center_dict[sc_id]["ssp"]
 
-        if rectification_longitude != 'default':
-            self.mpef_header['RectificationLongitude'] = f'E{int(rectification_longitude * 10):04d}'
+        if rectification_longitude != "default":
+            self.mpef_header["RectificationLongitude"] = f"E{int(rectification_longitude * 10):04d}"
 
         self.with_adef = with_area_definition
-        if self.with_adef and filetype_info['file_type'] == 'seviri_l2_bufr_amv':
+        if self.with_adef and filetype_info["file_type"] == "seviri_l2_bufr_amv":
             logging.warning("AMV BUFR data cannot be loaded with an area definition. Setting self.with_def = False.")
             self.with_adef = False
 
-        self.seg_size = seg_size_dict[filetype_info['file_type']]
+        self.seg_size = seg_size_dict[filetype_info["file_type"]]
 
     @property
     def start_time(self):
         """Return the repeat cycle start time."""
-        return self.mpef_header['NominalTime']
+        return self.mpef_header["NominalTime"]
 
     @property
     def end_time(self):
@@ -125,13 +125,13 @@ class SeviriL2BufrFileHandler(BaseFileHandler):
     @property
     def platform_name(self):
         """Return spacecraft name."""
-        return 'MET{}'.format(self.mpef_header['SpacecraftName'])
+        return "MET{}".format(self.mpef_header["SpacecraftName"])
 
     @property
     def ssp_lon(self):
         """Return subsatellite point longitude."""
         # e.g. E0415
-        ssp_lon = self.mpef_header['RectificationLongitude']
+        ssp_lon = self.mpef_header["RectificationLongitude"]
         return float(ssp_lon[1:])/10.
 
     def get_area_def(self, key):
@@ -157,7 +157,7 @@ class SeviriL2BufrFileHandler(BaseFileHandler):
             bufr = ec.codes_bufr_new_from_file(fh)
             if bufr is None:
                 break
-            ec.codes_set(bufr, 'unpack', 1)
+            ec.codes_set(bufr, "unpack", 1)
             attr = ec.codes_get(bufr, key)
             ec.codes_release(bufr)
 
@@ -173,7 +173,7 @@ class SeviriL2BufrFileHandler(BaseFileHandler):
                 if bufr is None:
                     break
 
-                ec.codes_set(bufr, 'unpack', 1)
+                ec.codes_set(bufr, "unpack", 1)
 
                 # if is the first message initialise our final array
                 if (msgCount == 0):
@@ -199,18 +199,18 @@ class SeviriL2BufrFileHandler(BaseFileHandler):
         and create the dataset with or without an AreaDefinition.
 
         """
-        arr = self.get_array(dataset_info['key'])
+        arr = self.get_array(dataset_info["key"])
 
         if self.with_adef:
             xarr = self.get_dataset_with_area_def(arr, dataset_id)
             # coordinates are not relevant when returning data with an AreaDefinition
-            if 'coordinates' in dataset_info.keys():
-                del dataset_info['coordinates']
+            if "coordinates" in dataset_info.keys():
+                del dataset_info["coordinates"]
         else:
             xarr = xr.DataArray(arr, dims=["y"])
 
-        if 'fill_value' in dataset_info:
-            xarr = xarr.where(xarr != dataset_info['fill_value'])
+        if "fill_value" in dataset_info:
+            xarr = xarr.where(xarr != dataset_info["fill_value"])
 
         self._add_attributes(xarr, dataset_info)
 
@@ -218,8 +218,8 @@ class SeviriL2BufrFileHandler(BaseFileHandler):
 
     def get_dataset_with_area_def(self, arr, dataset_id):
         """Get dataset with an AreaDefinition."""
-        if dataset_id['name'] in ['latitude', 'longitude']:
-            self.__setattr__(dataset_id['name'], arr)
+        if dataset_id["name"] in ["latitude", "longitude"]:
+            self.__setattr__(dataset_id["name"], arr)
             xarr = xr.DataArray(arr, dims=["y"])
         else:
             lons_1d, lats_1d, data_1d = da.compute(self.longitude, self.latitude, arr)
@@ -231,13 +231,13 @@ class SeviriL2BufrFileHandler(BaseFileHandler):
             data_2d[:] = np.nan
             data_2d[irow.compressed(), icol.compressed()] = data_1d[~irow.mask]
 
-            xarr = xr.DataArray(da.from_array(data_2d, CHUNK_SIZE), dims=('y', 'x'))
+            xarr = xr.DataArray(da.from_array(data_2d, CHUNK_SIZE), dims=("y", "x"))
 
             ntotal = len(icol)
             nvalid = len(icol.compressed())
             if nvalid < ntotal:
-                logging.warning(f'{ntotal-nvalid} out of {ntotal} data points could not be put on '
-                                f'the grid {self._area_def.area_id}.')
+                logging.warning(f"{ntotal-nvalid} out of {ntotal} data points could not be put on "
+                                f"the grid {self._area_def.area_id}.")
 
         return xarr
 
@@ -248,31 +248,31 @@ class SeviriL2BufrFileHandler(BaseFileHandler):
             AreaDefinition: A pyresample AreaDefinition object containing the area definition.
 
         """
-        res = dataset_id['resolution']
+        res = dataset_id["resolution"]
 
-        area_naming_input_dict = {'platform_name': 'msg',
-                                  'instrument_name': 'seviri',
-                                  'resolution': res,
+        area_naming_input_dict = {"platform_name": "msg",
+                                  "instrument_name": "seviri",
+                                  "resolution": res,
                                   }
 
         area_naming = get_geos_area_naming({**area_naming_input_dict,
-                                            **get_service_mode('seviri', self.ssp_lon)})
+                                            **get_service_mode("seviri", self.ssp_lon)})
 
         # Datasets with a segment size of 3 pixels extend outside the original SEVIRI 3km grid (with 1238 x 1238
         # segments a 3 pixels). Hence, we need to use corresponding area defintions in areas.yaml
         if self.seg_size == 3:
-            area_naming['area_id'] += '_ext'
-            area_naming['description'] += ' (extended outside original 3km grid)'
+            area_naming["area_id"] += "_ext"
+            area_naming["description"] += " (extended outside original 3km grid)"
 
         # Construct AreaDefinition from standardized area definition in areas.yaml.
-        stand_area_def = get_area_def(area_naming['area_id'])
+        stand_area_def = get_area_def(area_naming["area_id"])
 
         return stand_area_def
 
     def _add_attributes(self, xarr, dataset_info):
         """Add dataset attributes to xarray."""
-        xarr.attrs['sensor'] = 'SEVIRI'
-        xarr.attrs['platform_name'] = self.platform_name
-        xarr.attrs['ssp_lon'] = self.ssp_lon
-        xarr.attrs['seg_size'] = self.seg_size
+        xarr.attrs["sensor"] = "SEVIRI"
+        xarr.attrs["platform_name"] = self.platform_name
+        xarr.attrs["ssp_lon"] = self.ssp_lon
+        xarr.attrs["seg_size"] = self.seg_size
         xarr.attrs.update(dataset_info)
