@@ -53,7 +53,7 @@ def np2str(value):
                     type `numpy.string_` or it is not a numpy array
 
     """
-    if hasattr(value, 'dtype') and \
+    if hasattr(value, "dtype") and \
             issubclass(value.dtype.type, (np.str_, np.bytes_, np.object_)) \
             and value.size == 1:
         value = value.item()
@@ -68,13 +68,13 @@ def np2str(value):
 
 def _get_geostationary_height(geos_area):
     params = geos_area.crs.coordinate_operation.params
-    h_param = [p for p in params if 'satellite height' in p.name.lower()][0]
+    h_param = [p for p in params if "satellite height" in p.name.lower()][0]
     return h_param.value
 
 
 def _get_geostationary_reference_longitude(geos_area):
     params = geos_area.crs.coordinate_operation.params
-    lon_0_params = [p for p in params if 'longitude of natural origin' in p.name.lower()]
+    lon_0_params = [p for p in params if "longitude of natural origin" in p.name.lower()]
     if not lon_0_params:
         return 0
     elif len(lon_0_params) != 1:
@@ -232,7 +232,7 @@ def _unzip_local_file(filename: str, prefix=None):
         Temporary filename path for decompressed file or None.
 
     """
-    if not os.fspath(filename).endswith('bz2'):
+    if not os.fspath(filename).endswith("bz2"):
         return None
     fdn, tmpfilepath = tempfile.mkstemp(prefix=prefix,
                                         dir=config["tmp_dir"])
@@ -248,19 +248,19 @@ def _unzip_local_file(filename: str, prefix=None):
 
 def _unzip_with_pbzip(filename, tmpfilepath, fdn):
     # try pbzip2
-    pbzip = which('pbzip2')
+    pbzip = which("pbzip2")
     if pbzip is None:
         return None
     # Run external pbzip2
-    n_thr = os.environ.get('OMP_NUM_THREADS')
+    n_thr = os.environ.get("OMP_NUM_THREADS")
     if n_thr:
         runner = [pbzip,
-                  '-dc',
-                  '-p'+str(n_thr),
+                  "-dc",
+                  "-p"+str(n_thr),
                   filename]
     else:
         runner = [pbzip,
-                  '-dc',
+                  "-dc",
                   filename]
     p = Popen(runner, stdout=PIPE, stderr=PIPE)  # nosec
     stdout = BytesIO(p.communicate()[0])
@@ -268,7 +268,7 @@ def _unzip_with_pbzip(filename, tmpfilepath, fdn):
     if status != 0:
         raise IOError("pbzip2 error '%s', failed, status=%d"
                       % (filename, status))
-    with closing(os.fdopen(fdn, 'wb')) as ofpt:
+    with closing(os.fdopen(fdn, "wb")) as ofpt:
         try:
             stdout.seek(0)
             shutil.copyfileobj(stdout, ofpt)
@@ -291,7 +291,7 @@ def _unzip_with_bz2(filename, tmpfilepath):
 
 
 def _write_uncompressed_file(content, fdn, filename, tmpfilepath):
-    with closing(os.fdopen(fdn, 'wb')) as ofpt:
+    with closing(os.fdopen(fdn, "wb")) as ofpt:
         try:
             ofpt.write(content)
         except IOError:
@@ -348,7 +348,7 @@ def generic_open(filename, *args, **kwargs):
 
     Returns a file-like object.
     """
-    if os.fspath(filename).endswith('.bz2'):
+    if os.fspath(filename).endswith(".bz2"):
         fp = bz2.open(filename, *args, **kwargs)
     else:
         try:
@@ -413,8 +413,8 @@ def get_user_calibration_factors(band_name, correction_dict):
     """Retrieve radiance correction factors from user-supplied dict."""
     if band_name in correction_dict:
         try:
-            slope = correction_dict[band_name]['slope']
-            offset = correction_dict[band_name]['offset']
+            slope = correction_dict[band_name]["slope"]
+            offset = correction_dict[band_name]["offset"]
         except KeyError:
             raise KeyError("Incorrect correction factor dictionary. You must "
                            "supply 'slope' and 'offset' keys.")
@@ -440,13 +440,13 @@ def get_array_date(scn_data, utc_date=None):
     """Get start time from a channel data array."""
     if utc_date is None:
         try:
-            utc_date = scn_data.attrs['start_time']
+            utc_date = scn_data.attrs["start_time"]
         except KeyError:
             try:
-                utc_date = scn_data.attrs['scheduled_time']
+                utc_date = scn_data.attrs["scheduled_time"]
             except KeyError:
-                raise KeyError('Scene has no start_time '
-                               'or scheduled_time attribute.')
+                raise KeyError("Scene has no start_time "
+                               "or scheduled_time attribute.")
     return utc_date
 
 
@@ -456,10 +456,10 @@ def apply_earthsun_distance_correction(reflectance, utc_date=None):
     utc_date = get_array_date(reflectance, utc_date)
     sun_earth_dist = sun_earth_distance_correction(utc_date)
 
-    reflectance.attrs['sun_earth_distance_correction_applied'] = True
-    reflectance.attrs['sun_earth_distance_correction_factor'] = sun_earth_dist
+    reflectance.attrs["sun_earth_distance_correction_applied"] = True
+    reflectance.attrs["sun_earth_distance_correction_factor"] = sun_earth_dist
     with xr.set_options(keep_attrs=True):
-        reflectance = reflectance * sun_earth_dist * sun_earth_dist
+        reflectance = reflectance * reflectance.dtype.type(sun_earth_dist * sun_earth_dist)
     return reflectance
 
 
@@ -469,8 +469,8 @@ def remove_earthsun_distance_correction(reflectance, utc_date=None):
     utc_date = get_array_date(reflectance, utc_date)
     sun_earth_dist = sun_earth_distance_correction(utc_date)
 
-    reflectance.attrs['sun_earth_distance_correction_applied'] = False
-    reflectance.attrs['sun_earth_distance_correction_factor'] = sun_earth_dist
+    reflectance.attrs["sun_earth_distance_correction_applied"] = False
+    reflectance.attrs["sun_earth_distance_correction_factor"] = sun_earth_dist
     with xr.set_options(keep_attrs=True):
-        reflectance = reflectance / (sun_earth_dist * sun_earth_dist)
+        reflectance = reflectance / reflectance.dtype.type(sun_earth_dist * sun_earth_dist)
     return reflectance
