@@ -70,12 +70,12 @@ class TestEnhancementStretch:
         crefl_data /= 5.605
         crefl_data[0, 0] = np.nan  # one bad value for testing
         crefl_data[0, 1] = 0.
-        self.ch1 = xr.DataArray(da.from_array(data, chunks=2), dims=('y', 'x'), attrs={'test': 'test'})
-        self.ch2 = xr.DataArray(da.from_array(crefl_data, chunks=2), dims=('y', 'x'), attrs={'test': 'test'})
+        self.ch1 = xr.DataArray(da.from_array(data, chunks=2), dims=("y", "x"), attrs={"test": "test"})
+        self.ch2 = xr.DataArray(da.from_array(crefl_data, chunks=2), dims=("y", "x"), attrs={"test": "test"})
         rgb_data = np.stack([data, data, data])
         self.rgb = xr.DataArray(da.from_array(rgb_data, chunks=(3, 2, 2)),
-                                dims=('bands', 'y', 'x'),
-                                coords={'bands': ['R', 'G', 'B']})
+                                dims=("bands", "y", "x"),
+                                coords={"bands": ["R", "G", "B"]})
 
     @pytest.mark.parametrize(
         ("decorator", "exp_call_cls"),
@@ -208,20 +208,20 @@ class TestEnhancementStretch:
 
         create_colormap_mock = mock.Mock(wraps=create_colormap)
         cmap1 = Colormap((1, (1., 1., 1.)))
-        kwargs = {'palettes': cmap1}
+        kwargs = {"palettes": cmap1}
 
-        with mock.patch('satpy.enhancements.create_colormap', create_colormap_mock):
+        with mock.patch("satpy.enhancements.create_colormap", create_colormap_mock):
             res = mcp(kwargs)
         assert res is cmap1
         create_colormap_mock.assert_not_called()
         create_colormap_mock.reset_mock()
         ret_map.reset_mock()
 
-        cmap1 = {'colors': 'blues', 'min_value': 0,
-                 'max_value': 1}
-        kwargs = {'palettes': [cmap1]}
-        with mock.patch('satpy.enhancements.create_colormap', create_colormap_mock), \
-                mock.patch('trollimage.colormap.blues', ret_map):
+        cmap1 = {"colors": "blues", "min_value": 0,
+                 "max_value": 1}
+        kwargs = {"palettes": [cmap1]}
+        with mock.patch("satpy.enhancements.create_colormap", create_colormap_mock), \
+                mock.patch("trollimage.colormap.blues", ret_map):
             _ = mcp(kwargs)
         create_colormap_mock.assert_called_once()
         ret_map.reverse.assert_not_called()
@@ -229,18 +229,18 @@ class TestEnhancementStretch:
         create_colormap_mock.reset_mock()
         ret_map.reset_mock()
 
-        cmap2 = {'colors': 'blues', 'min_value': 2,
-                 'max_value': 3, 'reverse': True}
-        kwargs = {'palettes': [cmap2]}
-        with mock.patch('trollimage.colormap.blues', ret_map):
+        cmap2 = {"colors": "blues", "min_value": 2,
+                 "max_value": 3, "reverse": True}
+        kwargs = {"palettes": [cmap2]}
+        with mock.patch("trollimage.colormap.blues", ret_map):
             _ = mcp(kwargs)
         ret_map.reverse.assert_called_once()
         ret_map.set_range.assert_called_with(2, 3)
         create_colormap_mock.reset_mock()
         ret_map.reset_mock()
 
-        kwargs = {'palettes': [cmap1, cmap2]}
-        with mock.patch('trollimage.colormap.blues', ret_map):
+        kwargs = {"palettes": [cmap1, cmap2]}
+        with mock.patch("trollimage.colormap.blues", ret_map):
             _ = mcp(kwargs)
         ret_map.__add__.assert_called_once()
 
@@ -342,7 +342,7 @@ class TestColormapLoading:
         with closed_named_temp_file(suffix=".npy") as cmap_filename:
             cmap_data = _generate_cmap_test_data(None, "VRGB")
             np.save(cmap_filename, cmap_data)
-            cmap = create_colormap({'filename': cmap_filename, 'colormap_mode': "RGBA"})
+            cmap = create_colormap({"filename": cmap_filename, "colormap_mode": "RGBA"})
             assert cmap.colors.shape[0] == 4
             assert cmap.colors.shape[1] == 4  # RGBA
             np.testing.assert_equal(cmap.colors[0], [128 / 255., 1.0, 0, 0])
@@ -365,15 +365,15 @@ class TestColormapLoading:
             cmap_data = _generate_cmap_test_data(None, real_mode)
             _write_cmap_to_file(cmap_filename, cmap_data)
             # Force colormap_mode VRGBA to RGBA and we should see an exception
-            with pytest.raises(ValueError):
-                create_colormap({'filename': cmap_filename, 'colormap_mode': forced_mode})
+            with pytest.raises(ValueError, match="Unexpected colormap shape for mode .*"):
+                create_colormap({"filename": cmap_filename, "colormap_mode": forced_mode})
 
     def test_cmap_from_file_bad_shape(self):
         """Test that unknown array shape causes an error."""
         from satpy.enhancements import create_colormap
 
         # create the colormap file on disk
-        with closed_named_temp_file(suffix='.npy') as cmap_filename:
+        with closed_named_temp_file(suffix=".npy") as cmap_filename:
             np.save(cmap_filename, np.array([
                 [0],
                 [64],
@@ -381,8 +381,8 @@ class TestColormapLoading:
                 [255],
             ]))
 
-            with pytest.raises(ValueError):
-                create_colormap({'filename': cmap_filename})
+            with pytest.raises(ValueError, match="Unexpected colormap shape for mode 'None'"):
+                create_colormap({"filename": cmap_filename})
 
     def test_cmap_from_config_path(self, tmp_path):
         """Test loading a colormap relative to a config path."""
@@ -396,7 +396,7 @@ class TestColormapLoading:
         np.save(cmap_filename, cmap_data)
         with satpy.config.set(config_path=[tmp_path]):
             rel_cmap_filename = os.path.join("colormaps", "my_colormap.npy")
-            cmap = create_colormap({'filename': rel_cmap_filename, 'colormap_mode': "RGBA"})
+            cmap = create_colormap({"filename": rel_cmap_filename, "colormap_mode": "RGBA"})
             assert cmap.colors.shape[0] == 4
             assert cmap.colors.shape[1] == 4  # RGBA
             np.testing.assert_equal(cmap.colors[0], [128 / 255., 1.0, 0, 0])
@@ -407,7 +407,7 @@ class TestColormapLoading:
     def test_cmap_from_trollimage(self):
         """Test that colormaps in trollimage can be loaded."""
         from satpy.enhancements import create_colormap
-        cmap = create_colormap({'colors': 'pubu'})
+        cmap = create_colormap({"colors": "pubu"})
         from trollimage.colormap import pubu
         np.testing.assert_equal(cmap.colors, pubu.colors)
         np.testing.assert_equal(cmap.values, pubu.values)
@@ -415,7 +415,7 @@ class TestColormapLoading:
     def test_cmap_no_colormap(self):
         """Test that being unable to create a colormap raises an error."""
         from satpy.enhancements import create_colormap
-        with pytest.raises(ValueError):
+        with pytest.raises(ValueError, match="Unknown colormap format: .*"):
             create_colormap({})
 
     def test_cmap_list(self):
@@ -428,14 +428,14 @@ class TestColormapLoading:
             [1, 1, 1],
         ]
         values = [2, 4, 6, 8]
-        cmap = create_colormap({'colors': colors, 'color_scale': 1})
+        cmap = create_colormap({"colors": colors, "color_scale": 1})
         assert cmap.colors.shape[0] == 4
         np.testing.assert_equal(cmap.colors[0], [0.0, 0.0, 1.0])
         assert cmap.values.shape[0] == 4
         assert cmap.values[0] == 0
         assert cmap.values[-1] == 1.0
 
-        cmap = create_colormap({'colors': colors, 'color_scale': 1, 'values': values})
+        cmap = create_colormap({"colors": colors, "color_scale": 1, "values": values})
         assert cmap.colors.shape[0] == 4
         np.testing.assert_equal(cmap.colors[0], [0.0, 0.0, 1.0])
         assert cmap.values.shape[0] == 4
@@ -451,7 +451,7 @@ def test_on_separate_bands():
                             coords=array.coords, dims=array.dims, attrs=array.attrs)
 
     separate_func = on_separate_bands(func)
-    arr = xr.DataArray(np.zeros((3, 10, 10)), dims=['bands', 'y', 'x'], coords={"bands": ["R", "G", "B"]})
+    arr = xr.DataArray(np.zeros((3, 10, 10)), dims=["bands", "y", "x"], coords={"bands": ["R", "G", "B"]})
     assert separate_func(arr).shape == arr.shape
     assert all(separate_func(arr, gain=1).values[:, 0, 0] == [0, 1, 2])
 
@@ -460,11 +460,11 @@ def test_using_map_blocks():
     """Test the `using_map_blocks` decorator."""
 
     def func(np_array, block_info=None):
-        value = block_info[0]['chunk-location'][-1]
+        value = block_info[0]["chunk-location"][-1]
         return np.ones(np_array.shape) * value
 
     map_blocked_func = using_map_blocks(func)
-    arr = xr.DataArray(da.zeros((3, 10, 10), dtype=int, chunks=5), dims=['bands', 'y', 'x'])
+    arr = xr.DataArray(da.zeros((3, 10, 10), dtype=int, chunks=5), dims=["bands", "y", "x"])
     res = map_blocked_func(arr)
     assert res.shape == arr.shape
     assert res[0, 0, 0].compute() != res[0, 9, 9].compute()
@@ -479,12 +479,12 @@ def test_on_dask_array():
         return dask_array
 
     dask_func = on_dask_array(func)
-    arr = xr.DataArray(da.zeros((3, 10, 10), dtype=int, chunks=5), dims=['bands', 'y', 'x'])
+    arr = xr.DataArray(da.zeros((3, 10, 10), dtype=int, chunks=5), dims=["bands", "y", "x"])
     res = dask_func(arr)
     assert res.shape == arr.shape
 
 
-@pytest.fixture
+@pytest.fixture()
 def fake_area():
     """Return a fake 2×2 area."""
     from pyresample.geometry import create_area_def
@@ -492,88 +492,87 @@ def fake_area():
 
 
 _nwcsaf_geo_props = {
-    'cma_geo': ("geo", "cma", None, 'cma_pal', None, 'cloudmask', 'CMA', "uint8"),
-    'cma_pps': ("pps", "cma", None, 'cma_pal', None, 'cloudmask', 'CMA', "uint8"),
-    'cma_extended_pps': ("pps", "cma_extended", None, 'cma_extended_pal', None,
-                         'cloudmask_extended', 'CMA', "uint8"),
-    'cmaprob_pps': ("pps", "cmaprob", None, 'cmaprob_pal', None, 'cloudmask_probability',
-                    'CMAPROB', "uint8"),
-    'ct_geo': ("geo", "ct", None, 'ct_pal', None, 'cloudtype', 'CT', "uint8"),
-    'ct_pps': ("pps", "ct", None, 'ct_pal', None, 'cloudtype', 'CT', "uint8"),
-    'ctth_alti_geo': ("geo", "ctth_alti", None, 'ctth_alti_pal', None, 'cloud_top_height',
-                      'CTTH', "float64"),
-    'ctth_alti_pps': ("pps", "ctth_alti", None, 'ctth_alti_pal', "ctth_status_flag",
-                      'cloud_top_height', 'CTTH', "float64"),
-    'ctth_pres_geo': ("geo", "ctth_pres", None, 'ctth_pres_pal', None, 'cloud_top_pressure',
-                      'CTTH', "float64"),
-    'ctth_pres_pps': ("pps", "ctth_pres", None, 'ctth_pres_pal', None, 'cloud_top_pressure',
-                      'CTTH', "float64"),
-    'ctth_tempe_geo': ("geo", "ctth_tempe", None, 'ctth_tempe_pal', None, 'cloud_top_temperature',
-                       'CTTH', "float64"),
-    'ctth_tempe_pps': ("pps", "ctth_tempe", None, 'ctth_tempe_pal', None, 'cloud_top_temperature',
-                       'CTTH', "float64"),
-    'cmic_phase_geo': ("geo", "cmic_phase", None, 'cmic_phase_pal', None, 'cloud_top_phase',
-                       'CMIC', "uint8"),
-    'cmic_phase_pps': ("pps", "cmic_phase", None, 'cmic_phase_pal', "cmic_status_flag", 'cloud_top_phase',
-                       'CMIC', "uint8"),
-    'cmic_reff_geo': ("geo", "cmic_reff", None, 'cmic_reff_pal', None, 'cloud_drop_effective_radius',
-                      'CMIC', "float64"),
-    'cmic_reff_pps': ("pps", "cmic_reff", "cmic_cre", 'cmic_cre_pal', "cmic_status_flag",
-                      'cloud_drop_effective_radius', 'CMIC', "float64"),
-    'cmic_cot_geo': ("geo", "cmic_cot", None, 'cmic_cot_pal', None, 'cloud_optical_thickness',
-                     'CMIC', "float64"),
-    'cmic_cot_pps': ("pps", "cmic_cot", None, 'cmic_cot_pal', None, 'cloud_optical_thickness',
-                     'CMIC', "float64"),
-    'cmic_cwp_pps': ("pps", "cmic_cwp", None, 'cmic_cwp_pal', None, 'cloud_water_path',
-                     'CMIC', "float64"),
-    'cmic_lwp_geo': ("geo", "cmic_lwp", None, 'cmic_lwp_pal', None, 'cloud_liquid_water_path',
-                     'CMIC', "float64"),
-    'cmic_lwp_pps': ("pps", "cmic_lwp", None, 'cmic_lwp_pal', None, 'liquid_water_path',
-                     'CMIC', "float64"),
-    'cmic_iwp_geo': ("geo", "cmic_iwp", None, 'cmic_iwp_pal', None, 'cloud_ice_water_path',
-                     'CMIC', "float64"),
-    'cmic_iwp_pps': ("pps", "cmic_iwp", None, 'cmic_iwp_pal', None, 'ice_water_path',
-                     'CMIC', "float64"),
-    'pc': ("geo", "pc", None, 'pc_pal', None, 'precipitation_probability', 'PC', "uint8"),
-    'crr': ("geo", "crr", None, 'crr_pal', None, 'convective_rain_rate', 'CRR', "uint8"),
-    'crr_accum': ("geo", "crr_accum", None, 'crr_pal', None,
-                  'convective_precipitation_hourly_accumulation', 'CRR', "uint8"),
-    'ishai_tpw': ("geo", "ishai_tpw", None, 'ishai_tpw_pal', None, 'total_precipitable_water',
-                  'iSHAI', "float64"),
-    'ishai_shw': ("geo", "ishai_shw", None, 'ishai_shw_pal', None, 'showalter_index',
-                  'iSHAI', "float64"),
-    'ishai_li': ("geo", "ishai_li", None, 'ishai_li_pal', None, 'lifted_index',
-                 'iSHAI', "float64"),
-    'ci_prob30': ("geo", "ci_prob30", None, 'ci_pal', None, 'convection_initiation_prob30',
-                  'CI', "float64"),
-    'ci_prob60': ("geo", "ci_prob60", None, 'ci_pal', None, 'convection_initiation_prob60',
-                  'CI', "float64"),
-    'ci_prob90': ("geo", "ci_prob90", None, 'ci_pal', None, 'convection_initiation_prob90',
-                  'CI', "float64"),
-    'asii_turb_trop_prob': ("geo", "asii_turb_trop_prob", None, 'asii_turb_prob_pal', None,
-                            'asii_prob', 'ASII-NG', "float64"),
-    'MapCellCatType': ("geo", "MapCellCatType", None, 'MapCellCatType_pal', None,
-                       'rdt_cell_type', 'RDT-CW', "uint8"),
+    "cma_geo": ("geo", "cma", None, "cma_pal", None, "cloudmask", "CMA", "uint8"),
+    "cma_pps": ("pps", "cma", None, "cma_pal", None, "cloudmask", "CMA", "uint8"),
+    "cma_extended_pps": ("pps", "cma_extended", None, "cma_extended_pal", None,
+                         "cloudmask_extended", "CMA", "uint8"),
+    "cmaprob_pps": ("pps", "cmaprob", None, "cmaprob_pal", None, "cloudmask_probability",
+                    "CMAPROB", "uint8"),
+    "ct_geo": ("geo", "ct", None, "ct_pal", None, "cloudtype", "CT", "uint8"),
+    "ct_pps": ("pps", "ct", None, "ct_pal", None, "cloudtype", "CT", "uint8"),
+    "ctth_alti_geo": ("geo", "ctth_alti", None, "ctth_alti_pal", None, "cloud_top_height",
+                      "CTTH", "float64"),
+    "ctth_alti_pps": ("pps", "ctth_alti", None, "ctth_alti_pal", "ctth_status_flag",
+                      "cloud_top_height", "CTTH", "float64"),
+    "ctth_pres_geo": ("geo", "ctth_pres", None, "ctth_pres_pal", None, "cloud_top_pressure",
+                      "CTTH", "float64"),
+    "ctth_pres_pps": ("pps", "ctth_pres", None, "ctth_pres_pal", None, "cloud_top_pressure",
+                      "CTTH", "float64"),
+    "ctth_tempe_geo": ("geo", "ctth_tempe", None, "ctth_tempe_pal", None, "cloud_top_temperature",
+                       "CTTH", "float64"),
+    "ctth_tempe_pps": ("pps", "ctth_tempe", None, "ctth_tempe_pal", None, "cloud_top_temperature",
+                       "CTTH", "float64"),
+    "cmic_phase_geo": ("geo", "cmic_phase", None, "cmic_phase_pal", None, "cloud_top_phase",
+                       "CMIC", "uint8"),
+    "cmic_phase_pps": ("pps", "cmic_phase", None, "cmic_phase_pal", "cmic_status_flag", "cloud_top_phase",
+                       "CMIC", "uint8"),
+    "cmic_reff_geo": ("geo", "cmic_reff", None, "cmic_reff_pal", None, "cloud_drop_effective_radius",
+                      "CMIC", "float64"),
+    "cmic_reff_pps": ("pps", "cmic_reff", "cmic_cre", "cmic_cre_pal", "cmic_status_flag",
+                      "cloud_drop_effective_radius", "CMIC", "float64"),
+    "cmic_cot_geo": ("geo", "cmic_cot", None, "cmic_cot_pal", None, "cloud_optical_thickness",
+                     "CMIC", "float64"),
+    "cmic_cot_pps": ("pps", "cmic_cot", None, "cmic_cot_pal", None, "cloud_optical_thickness",
+                     "CMIC", "float64"),
+    "cmic_cwp_pps": ("pps", "cmic_cwp", None, "cmic_cwp_pal", None, "cloud_water_path",
+                     "CMIC", "float64"),
+    "cmic_lwp_geo": ("geo", "cmic_lwp", None, "cmic_lwp_pal", None, "cloud_liquid_water_path",
+                     "CMIC", "float64"),
+    "cmic_lwp_pps": ("pps", "cmic_lwp", None, "cmic_lwp_pal", None, "liquid_water_path",
+                     "CMIC", "float64"),
+    "cmic_iwp_geo": ("geo", "cmic_iwp", None, "cmic_iwp_pal", None, "cloud_ice_water_path",
+                     "CMIC", "float64"),
+    "cmic_iwp_pps": ("pps", "cmic_iwp", None, "cmic_iwp_pal", None, "ice_water_path",
+                     "CMIC", "float64"),
+    "pc": ("geo", "pc", None, "pc_pal", None, "precipitation_probability", "PC", "uint8"),
+    "crr": ("geo", "crr", None, "crr_pal", None, "convective_rain_rate", "CRR", "uint8"),
+    "crr_accum": ("geo", "crr_accum", None, "crr_pal", None,
+                  "convective_precipitation_hourly_accumulation", "CRR", "uint8"),
+    "ishai_tpw": ("geo", "ishai_tpw", None, "ishai_tpw_pal", None, "total_precipitable_water",
+                  "iSHAI", "float64"),
+    "ishai_shw": ("geo", "ishai_shw", None, "ishai_shw_pal", None, "showalter_index",
+                  "iSHAI", "float64"),
+    "ishai_li": ("geo", "ishai_li", None, "ishai_li_pal", None, "lifted_index",
+                 "iSHAI", "float64"),
+    "ci_prob30": ("geo", "ci_prob30", None, "ci_pal", None, "convection_initiation_prob30",
+                  "CI", "float64"),
+    "ci_prob60": ("geo", "ci_prob60", None, "ci_pal", None, "convection_initiation_prob60",
+                  "CI", "float64"),
+    "ci_prob90": ("geo", "ci_prob90", None, "ci_pal", None, "convection_initiation_prob90",
+                  "CI", "float64"),
+    "asii_turb_trop_prob": ("geo", "asii_turb_trop_prob", None, "asii_turb_prob_pal", None,
+                            "asii_prob", "ASII-NG", "float64"),
+    "MapCellCatType": ("geo", "MapCellCatType", None, "MapCellCatType_pal", None,
+                       "rdt_cell_type", "RDT-CW", "uint8"),
 }
 
 
 @pytest.mark.parametrize(
     "data",
-    ['cma_geo', 'cma_pps', 'cma_extended_pps', 'cmaprob_pps', 'ct_geo',
-     'ct_pps', 'ctth_alti_geo', 'ctth_alti_pps', 'ctth_pres_geo',
-     'ctth_pres_pps', 'ctth_tempe_geo', 'ctth_tempe_pps',
-     'cmic_phase_geo', 'cmic_phase_pps', 'cmic_reff_geo',
-     'cmic_reff_pps', 'cmic_cot_geo', 'cmic_cot_pps', 'cmic_cwp_pps',
-     'cmic_lwp_geo', 'cmic_lwp_pps', 'cmic_iwp_geo', 'cmic_iwp_pps',
-     'pc', 'crr', 'crr_accum', 'ishai_tpw', 'ishai_shw', 'ishai_li',
-     'ci_prob30', 'ci_prob60', 'ci_prob90', 'asii_turb_trop_prob',
-     'MapCellCatType']
+    ["cma_geo", "cma_pps", "cma_extended_pps", "cmaprob_pps", "ct_geo",
+     "ct_pps", "ctth_alti_geo", "ctth_alti_pps", "ctth_pres_geo",
+     "ctth_pres_pps", "ctth_tempe_geo", "ctth_tempe_pps",
+     "cmic_phase_geo", "cmic_phase_pps", "cmic_reff_geo",
+     "cmic_reff_pps", "cmic_cot_geo", "cmic_cot_pps", "cmic_cwp_pps",
+     "cmic_lwp_geo", "cmic_lwp_pps", "cmic_iwp_geo", "cmic_iwp_pps",
+     "pc", "crr", "crr_accum", "ishai_tpw", "ishai_shw", "ishai_li",
+     "ci_prob30", "ci_prob60", "ci_prob90", "asii_turb_trop_prob",
+     "MapCellCatType"]
 )
 def test_nwcsaf_comps(fake_area, tmp_path, data):
     """Test loading NWCSAF composites."""
+    from satpy import Scene
     from satpy.writers import get_enhanced_image
-
-    from ... import Scene
     (flavour, dvname, altname, palettename, statusname, comp, filelabel, dtp) = _nwcsaf_geo_props[data]
     rng = (0, 100) if dtp == "uint8" else (-100, 1000)
     if flavour == "geo":
@@ -645,9 +644,9 @@ class TestTCREnhancement:
         """Create test data."""
         data = da.arange(-100, 1000, 110).reshape(2, 5)
         rgb_data = np.stack([data, data, data])
-        self.rgb = xr.DataArray(rgb_data, dims=('bands', 'y', 'x'),
-                                coords={'bands': ['R', 'G', 'B']},
-                                attrs={'platform_name': 'Himawari-8'})
+        self.rgb = xr.DataArray(rgb_data, dims=("bands", "y", "x"),
+                                coords={"bands": ["R", "G", "B"]},
+                                attrs={"platform_name": "Himawari-8"})
 
     def test_jma_true_color_reproduction(self):
         """Test the jma_true_color_reproduction enhancement."""
@@ -669,12 +668,12 @@ class TestTCREnhancement:
 
         np.testing.assert_almost_equal(img.data.compute(), expected)
 
-        self.rgb.attrs['platform_name'] = None
+        self.rgb.attrs["platform_name"] = None
         img = XRImage(self.rgb)
         with pytest.raises(ValueError, match="Missing platform name."):
             jma_true_color_reproduction(img)
 
-        self.rgb.attrs['platform_name'] = 'Fakesat'
+        self.rgb.attrs["platform_name"] = "Fakesat"
         img = XRImage(self.rgb)
         with pytest.raises(KeyError, match="No conversion matrix found for platform Fakesat"):
             jma_true_color_reproduction(img)
