@@ -25,31 +25,31 @@ from behave import given, then, use_step_matcher, when
 use_step_matcher("re")
 
 
-@given(u'data is available')
+@given(u"data is available")
 def step_impl_data_available(context):
     """Make data available."""
-    if not os.path.exists('/tmp/SVM02_npp_d20150311_t1122204_e1123446_b17451_c20150311113206961730_cspp_dev.h5'):
-        response = urlopen('https://zenodo.org/record/16355/files/'
-                           'SVM02_npp_d20150311_t1122204_e1123446_b17451_c20150311113206961730_cspp_dev.h5')
-        with open('/tmp/SVM02_npp_d20150311_t1122204_e1123446_b17451_c20150311113206961730_cspp_dev.h5',
+    if not os.path.exists("/tmp/SVM02_npp_d20150311_t1122204_e1123446_b17451_c20150311113206961730_cspp_dev.h5"):
+        response = urlopen("https://zenodo.org/record/16355/files/"
+                           "SVM02_npp_d20150311_t1122204_e1123446_b17451_c20150311113206961730_cspp_dev.h5")
+        with open("/tmp/SVM02_npp_d20150311_t1122204_e1123446_b17451_c20150311113206961730_cspp_dev.h5",
                   mode="w") as fp:
             fp.write(response.read())
-    if not os.path.exists('/tmp/GMTCO_npp_d20150311_t1122204_e1123446_b17451_c20150311113205873710_cspp_dev.h5'):
-        response = urlopen('https://zenodo.org/record/16355/files/'
-                           'GMTCO_npp_d20150311_t1122204_e1123446_b17451_c20150311113205873710_cspp_dev.h5')
-        with open('/tmp/GMTCO_npp_d20150311_t1122204_e1123446_b17451_c20150311113205873710_cspp_dev.h5',
+    if not os.path.exists("/tmp/GMTCO_npp_d20150311_t1122204_e1123446_b17451_c20150311113205873710_cspp_dev.h5"):
+        response = urlopen("https://zenodo.org/record/16355/files/"
+                           "GMTCO_npp_d20150311_t1122204_e1123446_b17451_c20150311113205873710_cspp_dev.h5")
+        with open("/tmp/GMTCO_npp_d20150311_t1122204_e1123446_b17451_c20150311113205873710_cspp_dev.h5",
                   mode="w") as fp:
             fp.write(response.read())
 
 
-@when(u'user loads the data without providing a config file')
+@when(u"user loads the data without providing a config file")
 def step_impl_user_loads_no_config(context):
     """Load the data without a config."""
     from datetime import datetime
 
     from satpy import Scene, find_files_and_readers
     os.chdir("/tmp/")
-    readers_files = find_files_and_readers(sensor='viirs',
+    readers_files = find_files_and_readers(sensor="viirs",
                                            start_time=datetime(2015, 3, 11, 11, 20),
                                            end_time=datetime(2015, 3, 11, 11, 26))
     scn = Scene(filenames=readers_files)
@@ -57,20 +57,20 @@ def step_impl_user_loads_no_config(context):
     context.scene = scn
 
 
-@then(u'the data is available in a scene object')
+@then(u"the data is available in a scene object")
 def step_impl_data_available_in_scene(context):
     """Check that the data is available in the scene."""
     assert context.scene["M02"] is not None
     assert context.scene.get("M01") is None
 
 
-@when(u'some items are not available')
+@when(u"some items are not available")
 def step_impl_items_not_available(context):
     """Load some data."""
     context.scene.load(["M01"])
 
 
-@when(u'user wants to know what data is available')
+@when(u"user wants to know what data is available")
 def step_impl_user_checks_availability(context):
     """Check availability."""
     from datetime import datetime
@@ -84,7 +84,7 @@ def step_impl_user_checks_availability(context):
     context.available_dataset_ids = scn.available_dataset_ids()
 
 
-@then(u'available datasets are returned')
+@then(u"available datasets are returned")
 def step_impl_available_datasets_are_returned(context):
     """Check that datasets are returned."""
     assert (len(context.available_dataset_ids) >= 5)
@@ -98,13 +98,13 @@ def step_impl_datasets_with_same_name(context):
     from satpy import Scene
     from satpy.tests.utils import make_dataid
     scn = Scene()
-    scn[make_dataid(name='ds1', calibration='radiance')] = DataArray([[1, 2], [3, 4]])
-    scn[make_dataid(name='ds1', resolution=500, calibration='reflectance')] = DataArray([[5, 6], [7, 8]])
-    scn[make_dataid(name='ds1', resolution=250, calibration='reflectance')] = DataArray([[5, 6], [7, 8]])
-    scn[make_dataid(name='ds1', resolution=1000, calibration='reflectance')] = DataArray([[5, 6], [7, 8]])
-    scn[make_dataid(name='ds1', resolution=500, calibration='radiance', modifiers=('mod1',))] = \
+    scn[make_dataid(name="ds1", calibration="radiance")] = DataArray([[1, 2], [3, 4]])
+    scn[make_dataid(name="ds1", resolution=500, calibration="reflectance")] = DataArray([[5, 6], [7, 8]])
+    scn[make_dataid(name="ds1", resolution=250, calibration="reflectance")] = DataArray([[5, 6], [7, 8]])
+    scn[make_dataid(name="ds1", resolution=1000, calibration="reflectance")] = DataArray([[5, 6], [7, 8]])
+    scn[make_dataid(name="ds1", resolution=500, calibration="radiance", modifiers=("mod1",))] = \
         DataArray([[5, 6], [7, 8]])
-    ds_id = make_dataid(name='ds1', resolution=1000, calibration='radiance', modifiers=('mod1', 'mod2'))
+    ds_id = make_dataid(name="ds1", resolution=1000, calibration="radiance", modifiers=("mod1", "mod2"))
     scn[ds_id] = DataArray([[5, 6], [7, 8]])
     context.scene = scn
 
@@ -112,10 +112,10 @@ def step_impl_datasets_with_same_name(context):
 @when("a dataset is retrieved by name")
 def step_impl_dataset_retrieved_by_name(context):
     """Use the Scene's getitem method to get a dataset."""
-    context.returned_dataset = context.scene['ds1']
+    context.returned_dataset = context.scene["ds1"]
 
 
 @then("the least modified version of the dataset is returned")
 def step_impl_least_modified_dataset_returned(context):
     """Check that the dataset should be one of the least modified datasets."""
-    assert len(context.returned_dataset.attrs['modifiers']) == 0
+    assert len(context.returned_dataset.attrs["modifiers"]) == 0
