@@ -28,6 +28,8 @@ import unittest
 from datetime import datetime
 from unittest import mock
 
+import pytest
+
 from satpy.tests.multiscene_tests.test_utils import (
     _create_test_area,
     _create_test_dataset,
@@ -50,7 +52,7 @@ class TestMultiSceneSave(unittest.TestCase):
         except OSError:
             pass
 
-    @mock.patch('satpy.multiscene._multiscene.get_enhanced_image', _fake_get_enhanced_image)
+    @mock.patch("satpy.multiscene._multiscene.get_enhanced_image", _fake_get_enhanced_image)
     def test_save_mp4_distributed(self):
         """Save a series of fake scenes to an mp4 video."""
         from satpy import MultiScene
@@ -58,61 +60,61 @@ class TestMultiSceneSave(unittest.TestCase):
         scenes = _create_test_scenes(area=area)
 
         # Add a dataset to only one of the Scenes
-        scenes[1]['ds3'] = _create_test_dataset('ds3')
+        scenes[1]["ds3"] = _create_test_dataset("ds3")
         # Add a start and end time
-        for ds_id in ['ds1', 'ds2', 'ds3']:
-            scenes[1][ds_id].attrs['start_time'] = datetime(2018, 1, 2)
-            scenes[1][ds_id].attrs['end_time'] = datetime(2018, 1, 2, 12)
-            if ds_id == 'ds3':
+        for ds_id in ["ds1", "ds2", "ds3"]:
+            scenes[1][ds_id].attrs["start_time"] = datetime(2018, 1, 2)
+            scenes[1][ds_id].attrs["end_time"] = datetime(2018, 1, 2, 12)
+            if ds_id == "ds3":
                 continue
-            scenes[0][ds_id].attrs['start_time'] = datetime(2018, 1, 1)
-            scenes[0][ds_id].attrs['end_time'] = datetime(2018, 1, 1, 12)
+            scenes[0][ds_id].attrs["start_time"] = datetime(2018, 1, 1)
+            scenes[0][ds_id].attrs["end_time"] = datetime(2018, 1, 1, 12)
 
         mscn = MultiScene(scenes)
         fn = os.path.join(
             self.base_dir,
-            'test_save_mp4_{name}_{start_time:%Y%m%d_%H}_{end_time:%Y%m%d_%H}.mp4')
+            "test_save_mp4_{name}_{start_time:%Y%m%d_%H}_{end_time:%Y%m%d_%H}.mp4")
         writer_mock = mock.MagicMock()
         client_mock = mock.MagicMock()
         client_mock.compute.side_effect = lambda x: tuple(v.compute() for v in x)
         client_mock.gather.side_effect = lambda x: x
-        with mock.patch('satpy.multiscene._multiscene.imageio.get_writer') as get_writer:
+        with mock.patch("satpy.multiscene._multiscene.imageio.get_writer") as get_writer:
             get_writer.return_value = writer_mock
             # force order of datasets by specifying them
-            mscn.save_animation(fn, client=client_mock, datasets=['ds1', 'ds2', 'ds3'])
+            mscn.save_animation(fn, client=client_mock, datasets=["ds1", "ds2", "ds3"])
 
         # 2 saves for the first scene + 1 black frame
         # 3 for the second scene
-        self.assertEqual(writer_mock.append_data.call_count, 3 + 3)
+        assert writer_mock.append_data.call_count == 3 + 3
         filenames = [os.path.basename(args[0][0]) for args in get_writer.call_args_list]
-        self.assertEqual(filenames[0], 'test_save_mp4_ds1_20180101_00_20180102_12.mp4')
-        self.assertEqual(filenames[1], 'test_save_mp4_ds2_20180101_00_20180102_12.mp4')
-        self.assertEqual(filenames[2], 'test_save_mp4_ds3_20180102_00_20180102_12.mp4')
+        assert filenames[0] == "test_save_mp4_ds1_20180101_00_20180102_12.mp4"
+        assert filenames[1] == "test_save_mp4_ds2_20180101_00_20180102_12.mp4"
+        assert filenames[2] == "test_save_mp4_ds3_20180102_00_20180102_12.mp4"
 
         # Test no distributed client found
         mscn = MultiScene(scenes)
         fn = os.path.join(
             self.base_dir,
-            'test_save_mp4_{name}_{start_time:%Y%m%d_%H}_{end_time:%Y%m%d_%H}.mp4')
+            "test_save_mp4_{name}_{start_time:%Y%m%d_%H}_{end_time:%Y%m%d_%H}.mp4")
         writer_mock = mock.MagicMock()
         client_mock = mock.MagicMock()
         client_mock.compute.side_effect = lambda x: tuple(v.compute() for v in x)
         client_mock.gather.side_effect = lambda x: x
-        with mock.patch('satpy.multiscene._multiscene.imageio.get_writer') as get_writer, \
-                mock.patch('satpy.multiscene._multiscene.get_client', mock.Mock(side_effect=ValueError("No client"))):
+        with mock.patch("satpy.multiscene._multiscene.imageio.get_writer") as get_writer, \
+                mock.patch("satpy.multiscene._multiscene.get_client", mock.Mock(side_effect=ValueError("No client"))):
             get_writer.return_value = writer_mock
             # force order of datasets by specifying them
-            mscn.save_animation(fn, datasets=['ds1', 'ds2', 'ds3'])
+            mscn.save_animation(fn, datasets=["ds1", "ds2", "ds3"])
 
         # 2 saves for the first scene + 1 black frame
         # 3 for the second scene
-        self.assertEqual(writer_mock.append_data.call_count, 3 + 3)
+        assert writer_mock.append_data.call_count == 3 + 3
         filenames = [os.path.basename(args[0][0]) for args in get_writer.call_args_list]
-        self.assertEqual(filenames[0], 'test_save_mp4_ds1_20180101_00_20180102_12.mp4')
-        self.assertEqual(filenames[1], 'test_save_mp4_ds2_20180101_00_20180102_12.mp4')
-        self.assertEqual(filenames[2], 'test_save_mp4_ds3_20180102_00_20180102_12.mp4')
+        assert filenames[0] == "test_save_mp4_ds1_20180101_00_20180102_12.mp4"
+        assert filenames[1] == "test_save_mp4_ds2_20180101_00_20180102_12.mp4"
+        assert filenames[2] == "test_save_mp4_ds3_20180102_00_20180102_12.mp4"
 
-    @mock.patch('satpy.multiscene._multiscene.get_enhanced_image', _fake_get_enhanced_image)
+    @mock.patch("satpy.multiscene._multiscene.get_enhanced_image", _fake_get_enhanced_image)
     def test_save_mp4_no_distributed(self):
         """Save a series of fake scenes to an mp4 video when distributed isn't available."""
         from satpy import MultiScene
@@ -120,39 +122,39 @@ class TestMultiSceneSave(unittest.TestCase):
         scenes = _create_test_scenes(area=area)
 
         # Add a dataset to only one of the Scenes
-        scenes[1]['ds3'] = _create_test_dataset('ds3')
+        scenes[1]["ds3"] = _create_test_dataset("ds3")
         # Add a start and end time
-        for ds_id in ['ds1', 'ds2', 'ds3']:
-            scenes[1][ds_id].attrs['start_time'] = datetime(2018, 1, 2)
-            scenes[1][ds_id].attrs['end_time'] = datetime(2018, 1, 2, 12)
-            if ds_id == 'ds3':
+        for ds_id in ["ds1", "ds2", "ds3"]:
+            scenes[1][ds_id].attrs["start_time"] = datetime(2018, 1, 2)
+            scenes[1][ds_id].attrs["end_time"] = datetime(2018, 1, 2, 12)
+            if ds_id == "ds3":
                 continue
-            scenes[0][ds_id].attrs['start_time'] = datetime(2018, 1, 1)
-            scenes[0][ds_id].attrs['end_time'] = datetime(2018, 1, 1, 12)
+            scenes[0][ds_id].attrs["start_time"] = datetime(2018, 1, 1)
+            scenes[0][ds_id].attrs["end_time"] = datetime(2018, 1, 1, 12)
 
         mscn = MultiScene(scenes)
         fn = os.path.join(
             self.base_dir,
-            'test_save_mp4_{name}_{start_time:%Y%m%d_%H}_{end_time:%Y%m%d_%H}.mp4')
+            "test_save_mp4_{name}_{start_time:%Y%m%d_%H}_{end_time:%Y%m%d_%H}.mp4")
         writer_mock = mock.MagicMock()
         client_mock = mock.MagicMock()
         client_mock.compute.side_effect = lambda x: tuple(v.compute() for v in x)
         client_mock.gather.side_effect = lambda x: x
-        with mock.patch('satpy.multiscene._multiscene.imageio.get_writer') as get_writer, \
-                mock.patch('satpy.multiscene._multiscene.get_client', None):
+        with mock.patch("satpy.multiscene._multiscene.imageio.get_writer") as get_writer, \
+                mock.patch("satpy.multiscene._multiscene.get_client", None):
             get_writer.return_value = writer_mock
             # force order of datasets by specifying them
-            mscn.save_animation(fn, datasets=['ds1', 'ds2', 'ds3'])
+            mscn.save_animation(fn, datasets=["ds1", "ds2", "ds3"])
 
         # 2 saves for the first scene + 1 black frame
         # 3 for the second scene
-        self.assertEqual(writer_mock.append_data.call_count, 3 + 3)
+        assert writer_mock.append_data.call_count == 3 + 3
         filenames = [os.path.basename(args[0][0]) for args in get_writer.call_args_list]
-        self.assertEqual(filenames[0], 'test_save_mp4_ds1_20180101_00_20180102_12.mp4')
-        self.assertEqual(filenames[1], 'test_save_mp4_ds2_20180101_00_20180102_12.mp4')
-        self.assertEqual(filenames[2], 'test_save_mp4_ds3_20180102_00_20180102_12.mp4')
+        assert filenames[0] == "test_save_mp4_ds1_20180101_00_20180102_12.mp4"
+        assert filenames[1] == "test_save_mp4_ds2_20180101_00_20180102_12.mp4"
+        assert filenames[2] == "test_save_mp4_ds3_20180102_00_20180102_12.mp4"
 
-    @mock.patch('satpy.multiscene._multiscene.get_enhanced_image', _fake_get_enhanced_image)
+    @mock.patch("satpy.multiscene._multiscene.get_enhanced_image", _fake_get_enhanced_image)
     def test_save_datasets_simple(self):
         """Save a series of fake scenes to an PNG images."""
         from satpy import MultiScene
@@ -160,30 +162,30 @@ class TestMultiSceneSave(unittest.TestCase):
         scenes = _create_test_scenes(area=area)
 
         # Add a dataset to only one of the Scenes
-        scenes[1]['ds3'] = _create_test_dataset('ds3')
+        scenes[1]["ds3"] = _create_test_dataset("ds3")
         # Add a start and end time
-        for ds_id in ['ds1', 'ds2', 'ds3']:
-            scenes[1][ds_id].attrs['start_time'] = datetime(2018, 1, 2)
-            scenes[1][ds_id].attrs['end_time'] = datetime(2018, 1, 2, 12)
-            if ds_id == 'ds3':
+        for ds_id in ["ds1", "ds2", "ds3"]:
+            scenes[1][ds_id].attrs["start_time"] = datetime(2018, 1, 2)
+            scenes[1][ds_id].attrs["end_time"] = datetime(2018, 1, 2, 12)
+            if ds_id == "ds3":
                 continue
-            scenes[0][ds_id].attrs['start_time'] = datetime(2018, 1, 1)
-            scenes[0][ds_id].attrs['end_time'] = datetime(2018, 1, 1, 12)
+            scenes[0][ds_id].attrs["start_time"] = datetime(2018, 1, 1)
+            scenes[0][ds_id].attrs["end_time"] = datetime(2018, 1, 1, 12)
 
         mscn = MultiScene(scenes)
         client_mock = mock.MagicMock()
         client_mock.compute.side_effect = lambda x: tuple(v for v in x)
         client_mock.gather.side_effect = lambda x: x
-        with mock.patch('satpy.multiscene._multiscene.Scene.save_datasets') as save_datasets:
+        with mock.patch("satpy.multiscene._multiscene.Scene.save_datasets") as save_datasets:
             save_datasets.return_value = [True]  # some arbitrary return value
             # force order of datasets by specifying them
-            mscn.save_datasets(base_dir=self.base_dir, client=False, datasets=['ds1', 'ds2', 'ds3'],
-                               writer='simple_image')
+            mscn.save_datasets(base_dir=self.base_dir, client=False, datasets=["ds1", "ds2", "ds3"],
+                               writer="simple_image")
 
         # 2 for each scene
-        self.assertEqual(save_datasets.call_count, 2)
+        assert save_datasets.call_count == 2
 
-    @mock.patch('satpy.multiscene._multiscene.get_enhanced_image', _fake_get_enhanced_image)
+    @mock.patch("satpy.multiscene._multiscene.get_enhanced_image", _fake_get_enhanced_image)
     def test_save_datasets_distributed_delayed(self):
         """Test distributed save for writers returning delayed obejcts e.g. simple_image."""
         from dask.delayed import Delayed
@@ -193,15 +195,15 @@ class TestMultiSceneSave(unittest.TestCase):
         scenes = _create_test_scenes(area=area)
 
         # Add a dataset to only one of the Scenes
-        scenes[1]['ds3'] = _create_test_dataset('ds3')
+        scenes[1]["ds3"] = _create_test_dataset("ds3")
         # Add a start and end time
-        for ds_id in ['ds1', 'ds2', 'ds3']:
-            scenes[1][ds_id].attrs['start_time'] = datetime(2018, 1, 2)
-            scenes[1][ds_id].attrs['end_time'] = datetime(2018, 1, 2, 12)
-            if ds_id == 'ds3':
+        for ds_id in ["ds1", "ds2", "ds3"]:
+            scenes[1][ds_id].attrs["start_time"] = datetime(2018, 1, 2)
+            scenes[1][ds_id].attrs["end_time"] = datetime(2018, 1, 2, 12)
+            if ds_id == "ds3":
                 continue
-            scenes[0][ds_id].attrs['start_time'] = datetime(2018, 1, 1)
-            scenes[0][ds_id].attrs['end_time'] = datetime(2018, 1, 1, 12)
+            scenes[0][ds_id].attrs["start_time"] = datetime(2018, 1, 1)
+            scenes[0][ds_id].attrs["end_time"] = datetime(2018, 1, 1, 12)
 
         mscn = MultiScene(scenes)
         client_mock = mock.MagicMock()
@@ -209,16 +211,16 @@ class TestMultiSceneSave(unittest.TestCase):
         client_mock.gather.side_effect = lambda x: x
         future_mock = mock.MagicMock()
         future_mock.__class__ = Delayed
-        with mock.patch('satpy.multiscene._multiscene.Scene.save_datasets') as save_datasets:
+        with mock.patch("satpy.multiscene._multiscene.Scene.save_datasets") as save_datasets:
             save_datasets.return_value = [future_mock]  # some arbitrary return value
             # force order of datasets by specifying them
-            mscn.save_datasets(base_dir=self.base_dir, client=client_mock, datasets=['ds1', 'ds2', 'ds3'],
-                               writer='simple_image')
+            mscn.save_datasets(base_dir=self.base_dir, client=client_mock, datasets=["ds1", "ds2", "ds3"],
+                               writer="simple_image")
 
         # 2 for each scene
-        self.assertEqual(save_datasets.call_count, 2)
+        assert save_datasets.call_count == 2
 
-    @mock.patch('satpy.multiscene._multiscene.get_enhanced_image', _fake_get_enhanced_image)
+    @mock.patch("satpy.multiscene._multiscene.get_enhanced_image", _fake_get_enhanced_image)
     def test_save_datasets_distributed_source_target(self):
         """Test distributed save for writers returning sources and targets e.g. geotiff writer."""
         import dask.array as da
@@ -228,15 +230,15 @@ class TestMultiSceneSave(unittest.TestCase):
         scenes = _create_test_scenes(area=area)
 
         # Add a dataset to only one of the Scenes
-        scenes[1]['ds3'] = _create_test_dataset('ds3')
+        scenes[1]["ds3"] = _create_test_dataset("ds3")
         # Add a start and end time
-        for ds_id in ['ds1', 'ds2', 'ds3']:
-            scenes[1][ds_id].attrs['start_time'] = datetime(2018, 1, 2)
-            scenes[1][ds_id].attrs['end_time'] = datetime(2018, 1, 2, 12)
-            if ds_id == 'ds3':
+        for ds_id in ["ds1", "ds2", "ds3"]:
+            scenes[1][ds_id].attrs["start_time"] = datetime(2018, 1, 2)
+            scenes[1][ds_id].attrs["end_time"] = datetime(2018, 1, 2, 12)
+            if ds_id == "ds3":
                 continue
-            scenes[0][ds_id].attrs['start_time'] = datetime(2018, 1, 1)
-            scenes[0][ds_id].attrs['end_time'] = datetime(2018, 1, 1, 12)
+            scenes[0][ds_id].attrs["start_time"] = datetime(2018, 1, 1)
+            scenes[0][ds_id].attrs["end_time"] = datetime(2018, 1, 1, 12)
 
         mscn = MultiScene(scenes)
         client_mock = mock.MagicMock()
@@ -245,12 +247,12 @@ class TestMultiSceneSave(unittest.TestCase):
         source_mock = mock.MagicMock()
         source_mock.__class__ = da.Array
         target_mock = mock.MagicMock()
-        with mock.patch('satpy.multiscene._multiscene.Scene.save_datasets') as save_datasets:
+        with mock.patch("satpy.multiscene._multiscene.Scene.save_datasets") as save_datasets:
             save_datasets.return_value = [(source_mock, target_mock)]  # some arbitrary return value
             # force order of datasets by specifying them
-            with self.assertRaises(NotImplementedError):
-                mscn.save_datasets(base_dir=self.base_dir, client=client_mock, datasets=['ds1', 'ds2', 'ds3'],
-                                   writer='geotiff')
+            with pytest.raises(NotImplementedError):
+                mscn.save_datasets(base_dir=self.base_dir, client=client_mock, datasets=["ds1", "ds2", "ds3"],
+                                   writer="geotiff")
 
     def test_crop(self):
         """Test the crop method."""
@@ -262,44 +264,44 @@ class TestMultiSceneSave(unittest.TestCase):
         scene1 = Scene()
         area_extent = (-5570248.477339745, -5561247.267842293, 5567248.074173927,
                        5570248.477339745)
-        proj_dict = {'a': 6378169.0, 'b': 6356583.8, 'h': 35785831.0,
-                     'lon_0': 0.0, 'proj': 'geos', 'units': 'm'}
+        proj_dict = {"a": 6378169.0, "b": 6356583.8, "h": 35785831.0,
+                     "lon_0": 0.0, "proj": "geos", "units": "m"}
         x_size = 3712
         y_size = 3712
         area_def = AreaDefinition(
-            'test', 'test', 'test',
+            "test", "test", "test",
             proj_dict,
             x_size,
             y_size,
             area_extent,
         )
         area_def2 = AreaDefinition(
-            'test2', 'test2', 'test2', proj_dict,
+            "test2", "test2", "test2", proj_dict,
             x_size // 2,
             y_size // 2,
             area_extent,
         )
         scene1["1"] = DataArray(np.zeros((y_size, x_size)))
-        scene1["2"] = DataArray(np.zeros((y_size, x_size)), dims=('y', 'x'))
-        scene1["3"] = DataArray(np.zeros((y_size, x_size)), dims=('y', 'x'),
-                                attrs={'area': area_def})
-        scene1["4"] = DataArray(np.zeros((y_size // 2, x_size // 2)), dims=('y', 'x'),
-                                attrs={'area': area_def2})
+        scene1["2"] = DataArray(np.zeros((y_size, x_size)), dims=("y", "x"))
+        scene1["3"] = DataArray(np.zeros((y_size, x_size)), dims=("y", "x"),
+                                attrs={"area": area_def})
+        scene1["4"] = DataArray(np.zeros((y_size // 2, x_size // 2)), dims=("y", "x"),
+                                attrs={"area": area_def2})
         mscn = MultiScene([scene1])
 
         # by lon/lat bbox
         new_mscn = mscn.crop(ll_bbox=(-20., -5., 0, 0))
         new_scn1 = list(new_mscn.scenes)[0]
-        self.assertIn('1', new_scn1)
-        self.assertIn('2', new_scn1)
-        self.assertIn('3', new_scn1)
-        self.assertTupleEqual(new_scn1['1'].shape, (y_size, x_size))
-        self.assertTupleEqual(new_scn1['2'].shape, (y_size, x_size))
-        self.assertTupleEqual(new_scn1['3'].shape, (184, 714))
-        self.assertTupleEqual(new_scn1['4'].shape, (92, 357))
+        assert "1" in new_scn1
+        assert "2" in new_scn1
+        assert "3" in new_scn1
+        assert new_scn1["1"].shape == (y_size, x_size)
+        assert new_scn1["2"].shape == (y_size, x_size)
+        assert new_scn1["3"].shape == (184, 714)
+        assert new_scn1["4"].shape == (92, 357)
 
 
-@mock.patch('satpy.multiscene._multiscene.get_enhanced_image')
+@mock.patch("satpy.multiscene._multiscene.get_enhanced_image")
 def test_save_mp4(smg, tmp_path):
     """Save a series of fake scenes to an mp4 video."""
     from satpy import MultiScene
@@ -308,38 +310,38 @@ def test_save_mp4(smg, tmp_path):
     smg.side_effect = _fake_get_enhanced_image
 
     # Add a dataset to only one of the Scenes
-    scenes[1]['ds3'] = _create_test_dataset('ds3')
+    scenes[1]["ds3"] = _create_test_dataset("ds3")
     # Add a start and end time
-    for ds_id in ['ds1', 'ds2', 'ds3']:
-        scenes[1][ds_id].attrs['start_time'] = datetime(2018, 1, 2)
-        scenes[1][ds_id].attrs['end_time'] = datetime(2018, 1, 2, 12)
-        if ds_id == 'ds3':
+    for ds_id in ["ds1", "ds2", "ds3"]:
+        scenes[1][ds_id].attrs["start_time"] = datetime(2018, 1, 2)
+        scenes[1][ds_id].attrs["end_time"] = datetime(2018, 1, 2, 12)
+        if ds_id == "ds3":
             continue
-        scenes[0][ds_id].attrs['start_time'] = datetime(2018, 1, 1)
-        scenes[0][ds_id].attrs['end_time'] = datetime(2018, 1, 1, 12)
+        scenes[0][ds_id].attrs["start_time"] = datetime(2018, 1, 1)
+        scenes[0][ds_id].attrs["end_time"] = datetime(2018, 1, 1, 12)
 
     mscn = MultiScene(scenes)
     fn = str(tmp_path /
-             'test_save_mp4_{name}_{start_time:%Y%m%d_%H}_{end_time:%Y%m%d_%H}.mp4')
+             "test_save_mp4_{name}_{start_time:%Y%m%d_%H}_{end_time:%Y%m%d_%H}.mp4")
     writer_mock = mock.MagicMock()
-    with mock.patch('satpy.multiscene._multiscene.imageio.get_writer') as get_writer:
+    with mock.patch("satpy.multiscene._multiscene.imageio.get_writer") as get_writer:
         get_writer.return_value = writer_mock
         # force order of datasets by specifying them
-        mscn.save_animation(fn, datasets=['ds1', 'ds2', 'ds3'], client=False)
+        mscn.save_animation(fn, datasets=["ds1", "ds2", "ds3"], client=False)
 
     # 2 saves for the first scene + 1 black frame
     # 3 for the second scene
     assert writer_mock.append_data.call_count == 3 + 3
     filenames = [os.path.basename(args[0][0]) for args in get_writer.call_args_list]
-    assert filenames[0] == 'test_save_mp4_ds1_20180101_00_20180102_12.mp4'
-    assert filenames[1] == 'test_save_mp4_ds2_20180101_00_20180102_12.mp4'
-    assert filenames[2] == 'test_save_mp4_ds3_20180102_00_20180102_12.mp4'
+    assert filenames[0] == "test_save_mp4_ds1_20180101_00_20180102_12.mp4"
+    assert filenames[1] == "test_save_mp4_ds2_20180101_00_20180102_12.mp4"
+    assert filenames[2] == "test_save_mp4_ds3_20180102_00_20180102_12.mp4"
 
     # make sure that not specifying datasets still saves all of them
     fn = str(tmp_path /
-             'test_save_mp4_{name}_{start_time:%Y%m%d_%H}_{end_time:%Y%m%d_%H}.mp4')
+             "test_save_mp4_{name}_{start_time:%Y%m%d_%H}_{end_time:%Y%m%d_%H}.mp4")
     writer_mock = mock.MagicMock()
-    with mock.patch('satpy.multiscene._multiscene.imageio.get_writer') as get_writer:
+    with mock.patch("satpy.multiscene._multiscene.imageio.get_writer") as get_writer:
         get_writer.return_value = writer_mock
         # force order of datasets by specifying them
         mscn.save_animation(fn, client=False)
@@ -353,9 +355,9 @@ def test_save_mp4(smg, tmp_path):
     # test decorating and enhancing
 
     fn = str(tmp_path /
-             'test-{name}_{start_time:%Y%m%d_%H}_{end_time:%Y%m%d_%H}-rich.mp4')
+             "test-{name}_{start_time:%Y%m%d_%H}_{end_time:%Y%m%d_%H}-rich.mp4")
     writer_mock = mock.MagicMock()
-    with mock.patch('satpy.multiscene._multiscene.imageio.get_writer') as get_writer:
+    with mock.patch("satpy.multiscene._multiscene.imageio.get_writer") as get_writer:
         get_writer.return_value = writer_mock
         mscn.save_animation(
             fn, client=False,
