@@ -32,12 +32,12 @@ from pyhdf.SD import SD, SDC
 # Level 1 Fixtures
 
 AVAILABLE_1KM_VIS_PRODUCT_NAMES = [str(x) for x in range(8, 13)]
-AVAILABLE_1KM_VIS_PRODUCT_NAMES += ['13lo', '13hi', '14lo', '14hi']
+AVAILABLE_1KM_VIS_PRODUCT_NAMES += ["13lo", "13hi", "14lo", "14hi"]
 AVAILABLE_1KM_VIS_PRODUCT_NAMES += [str(x) for x in range(15, 20)]
 AVAILABLE_1KM_IR_PRODUCT_NAMES = [str(x) for x in range(20, 37)]
 AVAILABLE_1KM_PRODUCT_NAMES = AVAILABLE_1KM_VIS_PRODUCT_NAMES + AVAILABLE_1KM_IR_PRODUCT_NAMES
 AVAILABLE_HKM_PRODUCT_NAMES = [str(x) for x in range(3, 8)]
-AVAILABLE_QKM_PRODUCT_NAMES = ['1', '2']
+AVAILABLE_QKM_PRODUCT_NAMES = ["1", "2"]
 SCAN_LEN_5KM = 6  # 3 scans of 5km data
 SCAN_WIDTH_5KM = 270
 SCALE_FACTOR = 0.5
@@ -101,14 +101,14 @@ def _generate_visible_uncertainty_data(shape: tuple) -> np.ndarray:
 def _get_lonlat_variable_info(resolution: int) -> dict:
     lon_5km, lat_5km = _generate_lonlat_data(resolution)
     return {
-        'Latitude': {'data': lat_5km,
-                     'type': SDC.FLOAT32,
-                     'fill_value': -999,
-                     'attrs': {'dim_labels': ['Cell_Along_Swath_5km:mod35', 'Cell_Across_Swath_5km:mod35']}},
-        'Longitude': {'data': lon_5km,
-                      'type': SDC.FLOAT32,
-                      'fill_value': -999,
-                      'attrs': {'dim_labels': ['Cell_Along_Swath_5km:mod35', 'Cell_Across_Swath_5km:mod35']}},
+        "Latitude": {"data": lat_5km,
+                     "type": SDC.FLOAT32,
+                     "fill_value": -999,
+                     "attrs": {"dim_labels": ["Cell_Along_Swath_5km:mod35", "Cell_Across_Swath_5km:mod35"]}},
+        "Longitude": {"data": lon_5km,
+                      "type": SDC.FLOAT32,
+                      "fill_value": -999,
+                      "attrs": {"dim_labels": ["Cell_Along_Swath_5km:mod35", "Cell_Across_Swath_5km:mod35"]}},
     }
 
 
@@ -116,19 +116,19 @@ def _get_angles_variable_info(resolution: int) -> dict:
     angle_data = _generate_angle_data(resolution)
     dim_factor = RES_TO_REPEAT_FACTOR[resolution] * 2
     angle_info = {
-        'data': angle_data,
-        'type': SDC.INT16,
-        'fill_value': -32767,
-        'attrs': {
-            'dim_labels': [
-                f'{dim_factor}*nscans:MODIS_SWATH_Type_L1B',
-                '1KM_geo_dim:MODIS_SWATH_Type_L1B'],
-            'scale_factor': 0.01,
-            'add_offset': -0.01,
+        "data": angle_data,
+        "type": SDC.INT16,
+        "fill_value": -32767,
+        "attrs": {
+            "dim_labels": [
+                f"{dim_factor}*nscans:MODIS_SWATH_Type_L1B",
+                "1KM_geo_dim:MODIS_SWATH_Type_L1B"],
+            "scale_factor": 0.01,
+            "add_offset": -0.01,
         },
     }
     angles_info = {}
-    for var_name in ('SensorAzimuth', 'SensorZenith', 'SolarAzimuth', 'SolarZenith'):
+    for var_name in ("SensorAzimuth", "SensorZenith", "SolarAzimuth", "SolarZenith"):
         angles_info[var_name] = angle_info
     return angles_info
 
@@ -139,30 +139,30 @@ def _get_visible_variable_info(var_name: str, resolution: int, bands: list[str])
     uncertainty = _generate_visible_uncertainty_data(data.shape)
     dim_factor = RES_TO_REPEAT_FACTOR[resolution] * 2
     band_dim_name = f"Band_{resolution}_{num_bands}_RefSB:MODIS_SWATH_Type_L1B"
-    row_dim_name = f'{dim_factor}*nscans:MODIS_SWATH_Type_L1B'
-    col_dim_name = 'Max_EV_frames:MODIS_SWATH_Type_L1B'
+    row_dim_name = f"{dim_factor}*nscans:MODIS_SWATH_Type_L1B"
+    col_dim_name = "Max_EV_frames:MODIS_SWATH_Type_L1B"
     return {
         var_name: {
-            'data': data,
-            'type': SDC.UINT16,
-            'fill_value': 0,
-            'attrs': {
+            "data": data,
+            "type": SDC.UINT16,
+            "fill_value": 0,
+            "attrs": {
                 # dim_labels are just unique dimension names, may not match exactly with real world files
-                'dim_labels': [band_dim_name,
+                "dim_labels": [band_dim_name,
                                row_dim_name,
                                col_dim_name],
-                'valid_range': (0, 32767),
-                'reflectance_scales': (2.0,) * num_bands,
-                'reflectance_offsets': (-0.5,) * num_bands,
-                'band_names': ",".join(bands),
+                "valid_range": (0, 32767),
+                "reflectance_scales": (2.0,) * num_bands,
+                "reflectance_offsets": (-0.5,) * num_bands,
+                "band_names": ",".join(bands),
             },
         },
-        var_name + '_Uncert_Indexes': {
-            'data': uncertainty,
-            'type': SDC.UINT8,
-            'fill_value': 255,
-            'attrs': {
-                'dim_labels': [band_dim_name,
+        var_name + "_Uncert_Indexes": {
+            "data": uncertainty,
+            "type": SDC.UINT8,
+            "fill_value": 255,
+            "attrs": {
+                "dim_labels": [band_dim_name,
                                row_dim_name,
                                col_dim_name],
             },
@@ -175,27 +175,27 @@ def _get_emissive_variable_info(var_name: str, resolution: int, bands: list[str]
     data = _generate_visible_data(resolution, len(bands))
     dim_factor = RES_TO_REPEAT_FACTOR[resolution] * 2
     band_dim_name = f"Band_{resolution}_{num_bands}_Emissive:MODIS_SWATH_Type_L1B"
-    row_dim_name = f'{dim_factor}*nscans:MODIS_SWATH_Type_L1B'
-    col_dim_name = 'Max_EV_frames:MODIS_SWATH_Type_L1B'
+    row_dim_name = f"{dim_factor}*nscans:MODIS_SWATH_Type_L1B"
+    col_dim_name = "Max_EV_frames:MODIS_SWATH_Type_L1B"
     return {
         var_name: {
-            'data': data,
-            'type': SDC.UINT16,
-            'fill_value': 0,
-            'attrs': {
-                'dim_labels': [band_dim_name,
+            "data": data,
+            "type": SDC.UINT16,
+            "fill_value": 0,
+            "attrs": {
+                "dim_labels": [band_dim_name,
                                row_dim_name,
                                col_dim_name],
-                'valid_range': (0, 32767),
-                'band_names': ",".join(bands),
+                "valid_range": (0, 32767),
+                "band_names": ",".join(bands),
             },
         },
-        var_name + '_Uncert_Indexes': {
-            'data': np.zeros(data.shape, dtype=np.uint8),
-            'type': SDC.UINT8,
-            'fill_value': 255,
-            'attrs': {
-                'dim_labels': [band_dim_name,
+        var_name + "_Uncert_Indexes": {
+            "data": np.zeros(data.shape, dtype=np.uint8),
+            "type": SDC.UINT8,
+            "fill_value": 255,
+            "attrs": {
+                "dim_labels": [band_dim_name,
                                row_dim_name,
                                col_dim_name],
             },
@@ -217,43 +217,40 @@ def _get_l1b_geo_variable_info(filename: str,
 def generate_nasa_l1b_filename(prefix):
     """Generate a filename that follows NASA MODIS L1b convention."""
     now = datetime.now()
-    return f'{prefix}_A{now:%y%j_%H%M%S}_{now:%Y%j%H%M%S}.hdf'
+    return f"{prefix}_A{now:%y%j_%H%M%S}_{now:%Y%j%H%M%S}.hdf"
 
 
 def generate_imapp_filename(suffix):
     """Generate a filename that follows IMAPP MODIS L1b convention."""
     now = datetime.now()
-    return f't1.{now:%y%j.%H%M}.{suffix}.hdf'
+    return f"t1.{now:%y%j.%H%M}.{suffix}.hdf"
 
 
 def create_hdfeos_test_file(filename: str,
                             variable_infos: dict,
-                            geo_resolution: Optional[int] = None,
-                            file_shortname: Optional[str] = None,
-                            include_metadata: bool = True):
+                            struct_meta: Optional[str] = None,
+                            core_meta: Optional[str] = None,
+                            archive_meta: Optional[str] = None,
+                            ) -> None:
     """Create a fake MODIS L1b HDF4 file with headers.
 
     Args:
         filename: Full path of filename to be created.
         variable_infos: Dictionary mapping HDF4 variable names to dictionary
             of variable information (see ``_add_variable_to_file``).
-        geo_resolution: Resolution of geolocation datasets to be stored in the
-            metadata strings stored in the global metadata attributes. Only
-            used if ``include_metadata`` is ``True`` (default).
-        file_shortname: Short name of the file to be stored in global metadata
-            attributes. Only used if ``include_metadata`` is ``True``
-            (default).
-        include_metadata: Include global metadata attributes (default: True).
+        struct_meta: Contents of the 'StructMetadata.0' header.
+        core_meta: Contents of the 'CoreMetadata.0' header.
+        archive_meta:Contents of the 'ArchiveMetadata.0' header.
 
     """
     h = SD(filename, SDC.WRITE | SDC.CREATE)
 
-    if include_metadata:
-        if geo_resolution is None or file_shortname is None:
-            raise ValueError("'geo_resolution' and 'file_shortname' are required when including metadata.")
-        setattr(h, 'CoreMetadata.0', _create_core_metadata(file_shortname))  # noqa
-        setattr(h, 'StructMetadata.0', _create_struct_metadata(geo_resolution))  # noqa
-        setattr(h, 'ArchiveMetadata.0', _create_header_metadata())  # noqa
+    if struct_meta:
+        setattr(h, "StructMetadata.0", struct_meta)
+    if core_meta:
+        setattr(h, "CoreMetadata.0", core_meta)
+    if archive_meta:
+        setattr(h, "ArchiveMetadata.0", archive_meta)
 
     for var_name, var_info in variable_infos.items():
         _add_variable_to_file(h, var_name, var_info)
@@ -262,17 +259,17 @@ def create_hdfeos_test_file(filename: str,
 
 
 def _add_variable_to_file(h, var_name, var_info):
-    v = h.create(var_name, var_info['type'], var_info['data'].shape)
-    v[:] = var_info['data']
+    v = h.create(var_name, var_info["type"], var_info["data"].shape)
+    v[:] = var_info["data"]
     dim_count = 0
-    for dimension_name in var_info['attrs']['dim_labels']:
+    for dimension_name in var_info["attrs"]["dim_labels"]:
         v.dim(dim_count).setname(dimension_name)
         dim_count += 1
-    v.setfillvalue(var_info['fill_value'])
-    v.scale_factor = var_info['attrs'].get('scale_factor', SCALE_FACTOR)
-    v.add_offset = var_info['attrs'].get('add_offset', ADD_OFFSET)
-    for attr_key, attr_val in var_info['attrs'].items():
-        if attr_key == 'dim_labels':
+    v.setfillvalue(var_info["fill_value"])
+    v.scale_factor = var_info["attrs"].get("scale_factor", SCALE_FACTOR)
+    v.add_offset = var_info["attrs"].get("add_offset", ADD_OFFSET)
+    for attr_key, attr_val in var_info["attrs"].items():
+        if attr_key == "dim_labels":
             continue
         setattr(v, attr_key, attr_val)
 
@@ -281,12 +278,12 @@ def _create_core_metadata(file_shortname: str) -> str:
     beginning_date = datetime.now()
     ending_date = beginning_date + timedelta(minutes=5)
     core_metadata_header = "GROUP = INVENTORYMETADATA\nGROUPTYPE = MASTERGROUP\n\n" \
-                           "GROUP = RANGEDATETIME\n\nOBJECT = RANGEBEGINNINGDATE\nNUM_VAL = 1\nVALUE = \"{}\"\n" \
+                           'GROUP = RANGEDATETIME\n\nOBJECT = RANGEBEGINNINGDATE\nNUM_VAL = 1\nVALUE = "{}"\n' \
                            "END_OBJECT = RANGEBEGINNINGDATE\n\nOBJECT = RANGEBEGINNINGTIME\n" \
-                           "NUM_VAL = 1\nVALUE = \"{}\"\n" \
+                           'NUM_VAL = 1\nVALUE = "{}"\n' \
                            "END_OBJECT = RANGEBEGINNINGTIME\n\nOBJECT = RANGEENDINGDATE\n" \
-                           "NUM_VAL = 1\nVALUE = \"{}\"\n" \
-                           "END_OBJECT = RANGEENDINGDATE\n\nOBJECT = RANGEENDINGTIME\nNUM_VAL = 1\nVALUE = \"{}\"\n" \
+                           'NUM_VAL = 1\nVALUE = "{}"\n' \
+                           'END_OBJECT = RANGEENDINGDATE\n\nOBJECT = RANGEENDINGTIME\nNUM_VAL = 1\nVALUE = "{}"\n' \
                            "END_OBJECT = RANGEENDINGTIME\nEND_GROUP = RANGEDATETIME"
     core_metadata_header = core_metadata_header.format(
         beginning_date.strftime("%Y-%m-%d"),
@@ -295,13 +292,13 @@ def _create_core_metadata(file_shortname: str) -> str:
         ending_date.strftime("%H:%M:%S.%f")
     )
     inst_metadata = "GROUP = ASSOCIATEDPLATFORMINSTRUMENTSENSOR\n\n" \
-                    "OBJECT = ASSOCIATEDPLATFORMINSTRUMENTSENSORCONTAINER\nCLASS = \"1\"\n\n" \
-                    "OBJECT = ASSOCIATEDSENSORSHORTNAME\nCLASS = \"1\"\nNUM_VAL = 1\n" \
-                    "VALUE = \"MODIS\"\nEND_OBJECT = ASSOCIATEDSENSORSHORTNAME\n\n" \
-                    "OBJECT = ASSOCIATEDPLATFORMSHORTNAME\nCLASS = \"1\"\nNUM_VAL = 1\n" \
-                    "VALUE = \"Terra\"\nEND_OBJECT = ASSOCIATEDPLATFORMSHORTNAME\n\n" \
-                    "OBJECT = ASSOCIATEDINSTRUMENTSHORTNAME\nCLASS = \"1\"\nNUM_VAL = 1\n" \
-                    "VALUE = \"MODIS\"\nEND_OBJECT = ASSOCIATEDINSTRUMENTSHORTNAME\n\n" \
+                    'OBJECT = ASSOCIATEDPLATFORMINSTRUMENTSENSORCONTAINER\nCLASS = "1"\n\n' \
+                    'OBJECT = ASSOCIATEDSENSORSHORTNAME\nCLASS = "1"\nNUM_VAL = 1\n' \
+                    'VALUE = "MODIS"\nEND_OBJECT = ASSOCIATEDSENSORSHORTNAME\n\n' \
+                    'OBJECT = ASSOCIATEDPLATFORMSHORTNAME\nCLASS = "1"\nNUM_VAL = 1\n' \
+                    'VALUE = "Terra"\nEND_OBJECT = ASSOCIATEDPLATFORMSHORTNAME\n\n' \
+                    'OBJECT = ASSOCIATEDINSTRUMENTSHORTNAME\nCLASS = "1"\nNUM_VAL = 1\n' \
+                    'VALUE = "MODIS"\nEND_OBJECT = ASSOCIATEDINSTRUMENTSHORTNAME\n\n' \
                     "END_OBJECT = ASSOCIATEDPLATFORMINSTRUMENTSENSORCONTAINER\n\n" \
                     "END_GROUP              = ASSOCIATEDPLATFORMINSTRUMENTSENSOR\n\n"
     collection_metadata = "GROUP = COLLECTIONDESCRIPTIONCLASS\n\nOBJECT = SHORTNAME\nNUM_VAL = 1\n" \
@@ -318,7 +315,7 @@ def _create_struct_metadata(geo_resolution: int) -> str:
                              "GROUP=SWATH_1\n" \
                              "GROUP=DimensionMap\n" \
                              "OBJECT=DimensionMap_2\n" \
-                             f"GeoDimension=\"{geo_dim_factor}*nscans\"\n" \
+                             f'GeoDimension="{geo_dim_factor}*nscans"\n' \
                              "END_OBJECT=DimensionMap_2\n" \
                              "END_GROUP=DimensionMap\n" \
                              "END_GROUP=SWATH_1\n" \
@@ -326,8 +323,36 @@ def _create_struct_metadata(geo_resolution: int) -> str:
     return struct_metadata_header
 
 
+def _create_struct_metadata_cmg(ftype: str) -> str:
+    # Case of a MOD09 file
+    if ftype == "MOD09":
+        gridline = 'GridName="MOD09CMG"\n'
+        upleft = "UpperLeftPointMtrs=(-180000000.000000,90000000.000000)\n"
+        upright = "LowerRightMtrs=(180000000.000000,-90000000.000000)\n"
+    # Case of a MCD43 file
+    else:
+        gridline = 'GridName="MCD_CMG_BRDF_0.05Deg"\n'
+        upleft = "UpperLeftPointMtrs=(-180.000000,90.000000)\n"
+        upright = "LowerRightMtrs=(180.000000,-90.000000)\n"
+
+    struct_metadata_header = ("GROUP=SwathStructure\n"
+                              "END_GROUP=SwathStructure\n"
+                              "GROUP=GridStructure\n"
+                              "GROUP=GRID_1\n"
+                              f"{gridline}\n"
+                              "XDim=7200\n"
+                              "YDim=3600\n"
+                              f"{upleft}\n"
+                              f"{upright}\n"
+                              "END_GROUP=GRID_1\n"
+                              "END_GROUP=GridStructure\nEND")
+    return struct_metadata_header
+
+
 def _create_header_metadata() -> str:
-    archive_metadata_header = "GROUP = ARCHIVEDMETADATA\nEND_GROUP = ARCHIVEDMETADATA\nEND"
+    archive_metadata_header = ("GROUP = ARCHIVEDMETADATA\n"
+                               'TEST_URL = "http://modis.gsfc.nasa.gov/?some_val=100"\n'
+                               "END_GROUP = ARCHIVEDMETADATA\nEND")
     return archive_metadata_header
 
 
@@ -341,7 +366,11 @@ def modis_l1b_nasa_mod021km_file(tmpdir_factory) -> list[str]:
     variable_infos.update(_get_visible_variable_info("EV_500_Aggr1km_RefSB", 1000, AVAILABLE_HKM_PRODUCT_NAMES))
     variable_infos.update(_get_visible_variable_info("EV_250_Aggr1km_RefSB", 1000, AVAILABLE_QKM_PRODUCT_NAMES))
     variable_infos.update(_get_emissive_variable_info("EV_1KM_Emissive", 1000, AVAILABLE_1KM_IR_PRODUCT_NAMES))
-    create_hdfeos_test_file(full_path, variable_infos, geo_resolution=5000, file_shortname="MOD021KM")
+    create_hdfeos_test_file(full_path,
+                            variable_infos,
+                            _create_struct_metadata(5000),
+                            _create_core_metadata("MOD021KM"),
+                            _create_header_metadata())
     return [full_path]
 
 
@@ -355,7 +384,11 @@ def modis_l1b_imapp_1000m_file(tmpdir_factory) -> list[str]:
     variable_infos.update(_get_visible_variable_info("EV_500_Aggr1km_RefSB", 1000, AVAILABLE_HKM_PRODUCT_NAMES))
     variable_infos.update(_get_visible_variable_info("EV_250_Aggr1km_RefSB", 1000, AVAILABLE_QKM_PRODUCT_NAMES))
     variable_infos.update(_get_emissive_variable_info("EV_1KM_Emissive", 1000, AVAILABLE_1KM_IR_PRODUCT_NAMES))
-    create_hdfeos_test_file(full_path, variable_infos, geo_resolution=5000, file_shortname="MOD021KM")
+    create_hdfeos_test_file(full_path,
+                            variable_infos,
+                            _create_struct_metadata(5000),
+                            _create_core_metadata("MOD021KM"),
+                            _create_header_metadata())
     return [full_path]
 
 
@@ -366,18 +399,26 @@ def modis_l1b_nasa_mod02hkm_file(tmpdir_factory) -> list[str]:
     full_path = str(tmpdir_factory.mktemp("modis_l1b").join(filename))
     variable_infos = _get_l1b_geo_variable_info(filename, 1000, include_angles=False)
     variable_infos.update(_get_visible_variable_info("EV_500_RefSB", 250, AVAILABLE_QKM_PRODUCT_NAMES))
-    create_hdfeos_test_file(full_path, variable_infos, geo_resolution=1000, file_shortname="MOD02HKM")
+    create_hdfeos_test_file(full_path,
+                            variable_infos,
+                            _create_struct_metadata(1000),
+                            _create_core_metadata("MOD02HKM"),
+                            _create_header_metadata())
     return [full_path]
 
 
-@pytest.fixture
+@pytest.fixture()
 def modis_l1b_nasa_mod02qkm_file(tmpdir_factory) -> list[str]:
     """Create a single MOD02QKM file following standard NASA file scheme."""
     filename = generate_nasa_l1b_filename("MOD02Qkm")
     full_path = str(tmpdir_factory.mktemp("modis_l1b").join(filename))
     variable_infos = _get_l1b_geo_variable_info(filename, 1000, include_angles=False)
     variable_infos.update(_get_visible_variable_info("EV_250_RefSB", 250, AVAILABLE_QKM_PRODUCT_NAMES))
-    create_hdfeos_test_file(full_path, variable_infos, geo_resolution=1000, file_shortname="MOD02QKM")
+    create_hdfeos_test_file(full_path,
+                            variable_infos,
+                            _create_struct_metadata(1000),
+                            _create_core_metadata("MOD02QKM"),
+                            _create_header_metadata())
     return [full_path]
 
 
@@ -387,7 +428,11 @@ def modis_l1b_nasa_mod03_file(tmpdir_factory) -> list[str]:
     filename = generate_nasa_l1b_filename("MOD03")
     full_path = str(tmpdir_factory.mktemp("modis_l1b").join(filename))
     variable_infos = _get_l1b_geo_variable_info(filename, 1000, include_angles=True)
-    create_hdfeos_test_file(full_path, variable_infos, geo_resolution=1000, file_shortname="MOD03")
+    create_hdfeos_test_file(full_path,
+                            variable_infos,
+                            _create_struct_metadata(1000),
+                            _create_core_metadata("MOD03"),
+                            _create_header_metadata())
     return [full_path]
 
 
@@ -397,7 +442,11 @@ def modis_l1b_imapp_geo_file(tmpdir_factory) -> list[str]:
     filename = generate_imapp_filename("geo")
     full_path = str(tmpdir_factory.mktemp("modis_l1b").join(filename))
     variable_infos = _get_l1b_geo_variable_info(filename, 1000, include_angles=True)
-    create_hdfeos_test_file(full_path, variable_infos, geo_resolution=1000, file_shortname="MOD03")
+    create_hdfeos_test_file(full_path,
+                            variable_infos,
+                            _create_struct_metadata(1000),
+                            _create_core_metadata("MOD03"),
+                            _create_header_metadata())
     return [full_path]
 
 
@@ -413,20 +462,20 @@ def modis_l1b_nasa_1km_mod03_files(modis_l1b_nasa_mod021km_file, modis_l1b_nasa_
 def _get_basic_variable_info(var_name: str, resolution: int) -> dict:
     shape = _shape_for_resolution(resolution)
     data = np.ones((shape[0], shape[1]), dtype=np.uint16)
-    row_dim_name = f'Cell_Along_Swath_{resolution}m:modl2'
-    col_dim_name = f'Cell_Across_Swath_{resolution}m:modl2'
+    row_dim_name = f"Cell_Along_Swath_{resolution}m:modl2"
+    col_dim_name = f"Cell_Across_Swath_{resolution}m:modl2"
     return {
         var_name: {
-            'data': data,
-            'type': SDC.UINT16,
-            'fill_value': 0,
-            'attrs': {
+            "data": data,
+            "type": SDC.UINT16,
+            "fill_value": 0,
+            "attrs": {
                 # dim_labels are just unique dimension names, may not match exactly with real world files
-                'dim_labels': [row_dim_name,
+                "dim_labels": [row_dim_name,
                                col_dim_name],
-                'valid_range': (0, 32767),
-                'scale_factor': 2.0,
-                'add_offset': -1.0,
+                "valid_range": (0, 32767),
+                "scale_factor": 2.0,
+                "add_offset": -1.0,
             },
         },
     }
@@ -437,35 +486,57 @@ def _get_cloud_mask_variable_info(var_name: str, resolution: int) -> dict:
     shape = _shape_for_resolution(resolution)
     data = np.zeros((num_bytes, shape[0], shape[1]), dtype=np.int8)
     byte_dim_name = "Byte_Segment:mod35"
-    row_dim_name = 'Cell_Along_Swath_1km:mod35'
-    col_dim_name = 'Cell_Across_Swath_1km:mod35'
+    row_dim_name = "Cell_Along_Swath_1km:mod35"
+    col_dim_name = "Cell_Across_Swath_1km:mod35"
     return {
         var_name: {
-            'data': data,
-            'type': SDC.INT8,
-            'fill_value': 0,
-            'attrs': {
+            "data": data,
+            "type": SDC.INT8,
+            "fill_value": 0,
+            "attrs": {
                 # dim_labels are just unique dimension names, may not match exactly with real world files
-                'dim_labels': [byte_dim_name,
+                "dim_labels": [byte_dim_name,
                                row_dim_name,
                                col_dim_name],
-                'valid_range': (0, -1),
-                'scale_factor': 1.,
-                'add_offset': 0.,
+                "valid_range": (0, -1),
+                "scale_factor": 1.,
+                "add_offset": 0.,
             },
         },
-        'Quality_Assurance': {
-            'data': np.ones((shape[0], shape[1], 10), dtype=np.int8),
-            'type': SDC.INT8,
-            'fill_value': 0,
-            'attrs': {
+        "Quality_Assurance": {
+            "data": np.ones((shape[0], shape[1], 10), dtype=np.int8),
+            "type": SDC.INT8,
+            "fill_value": 0,
+            "attrs": {
                 # dim_labels are just unique dimension names, may not match exactly with real world files
-                'dim_labels': [row_dim_name,
+                "dim_labels": [row_dim_name,
                                col_dim_name,
-                               'Quality_Dimension:mod35'],
-                'valid_range': (0, -1),
-                'scale_factor': 2.,
-                'add_offset': -0.5,
+                               "Quality_Dimension:mod35"],
+                "valid_range": (0, -1),
+                "scale_factor": 2.,
+                "add_offset": -0.5,
+            },
+        },
+    }
+
+
+def _get_l3_refl_variable_info(var_name: str) -> dict:
+    shape = (3600, 7200)
+    data = np.zeros((shape[0], shape[1]), dtype=np.int16)
+    row_dim_name = "XDim"
+    col_dim_name = "YDim"
+    return {
+        var_name: {
+            "data": data,
+            "type": SDC.INT16,
+            "fill_value": -28672,
+            "attrs": {
+                # dim_labels are just unique dimension names, may not match exactly with real world files
+                "dim_labels": [row_dim_name,
+                               col_dim_name],
+                "valid_range": (-100, 16000),
+                "scale_factor": 1e-4,
+                "add_offset": 0.,
             },
         },
     }
@@ -474,47 +545,47 @@ def _get_cloud_mask_variable_info(var_name: str, resolution: int) -> dict:
 def _get_mask_byte1_variable_info() -> dict:
     shape = _shape_for_resolution(1000)
     data = np.zeros((shape[0], shape[1]), dtype=np.uint16)
-    row_dim_name = 'Cell_Along_Swath_1km:mod35'
-    col_dim_name = 'Cell_Across_Swath_1km:mod35'
+    row_dim_name = "Cell_Along_Swath_1km:mod35"
+    col_dim_name = "Cell_Across_Swath_1km:mod35"
     return {
         "MODIS_Cloud_Mask": {
-            'data': data,
-            'type': SDC.UINT16,
-            'fill_value': 9999,
-            'attrs': {
+            "data": data,
+            "type": SDC.UINT16,
+            "fill_value": 9999,
+            "attrs": {
                 # dim_labels are just unique dimension names, may not match exactly with real world files
-                'dim_labels': [row_dim_name,
+                "dim_labels": [row_dim_name,
                                col_dim_name],
-                'valid_range': (0, 4),
-                'scale_factor': 2,
-                'add_offset': -1,
+                "valid_range": (0, 4),
+                "scale_factor": 2,
+                "add_offset": -1,
             },
 
         },
         "MODIS_Simple_LandSea_Mask": {
-            'data': data,
-            'type': SDC.UINT16,
-            'fill_value': 9999,
-            'attrs': {
+            "data": data,
+            "type": SDC.UINT16,
+            "fill_value": 9999,
+            "attrs": {
                 # dim_labels are just unique dimension names, may not match exactly with real world files
-                'dim_labels': [row_dim_name,
+                "dim_labels": [row_dim_name,
                                col_dim_name],
-                'valid_range': (0, 4),
-                'scale_factor': 2,
-                'add_offset': -1,
+                "valid_range": (0, 4),
+                "scale_factor": 2,
+                "add_offset": -1,
             },
         },
         "MODIS_Snow_Ice_Flag": {
-            'data': data,
-            'type': SDC.UINT16,
-            'fill_value': 9999,
-            'attrs': {
+            "data": data,
+            "type": SDC.UINT16,
+            "fill_value": 9999,
+            "attrs": {
                 # dim_labels are just unique dimension names, may not match exactly with real world files
-                'dim_labels': [row_dim_name,
+                "dim_labels": [row_dim_name,
                                col_dim_name],
-                'valid_range': (0, 2),
-                'scale_factor': 2,
-                'add_offset': -1,
+                "valid_range": (0, 2),
+                "scale_factor": 2,
+                "add_offset": -1,
             },
         },
     }
@@ -523,7 +594,7 @@ def _get_mask_byte1_variable_info() -> dict:
 def generate_nasa_l2_filename(prefix: str) -> str:
     """Generate a file name that follows MODIS 35 L2 convention in a temporary directory."""
     now = datetime.now()
-    return f'{prefix}_L2.A{now:%Y%j.%H%M}.061.{now:%Y%j%H%M%S}.hdf'
+    return f"{prefix}_L2.A{now:%Y%j.%H%M}.061.{now:%Y%j%H%M%S}.hdf"
 
 
 @pytest.fixture(scope="session")
@@ -533,10 +604,51 @@ def modis_l2_nasa_mod35_file(tmpdir_factory) -> list[str]:
     full_path = str(tmpdir_factory.mktemp("modis_l2").join(filename))
     variable_infos = _get_l1b_geo_variable_info(filename, 5000, include_angles=True)
     variable_infos.update(_get_cloud_mask_variable_info("Cloud_Mask", 1000))
-    create_hdfeos_test_file(full_path, variable_infos, geo_resolution=5000, file_shortname="MOD35")
+    create_hdfeos_test_file(full_path,
+                            variable_infos,
+                            _create_struct_metadata(5000),
+                            _create_core_metadata("MOD35"),
+                            _create_header_metadata())
     return [full_path]
 
 
+def generate_nasa_l3_filename(prefix: str) -> str:
+    """Generate a file name that follows MODIS 09 L3 convention in a temporary directory."""
+    now = datetime.now()
+    return f"{prefix}.A{now:%Y%j}.061.{now:%Y%j%H%M%S}.hdf"
+
+
+def modis_l3_file(tmpdir_factory, f_prefix, var_name, f_short):
+    """Create a MODIS L3 file of the desired type."""
+    filename = generate_nasa_l3_filename(f_prefix)
+    full_path = str(tmpdir_factory.mktemp("modis_l3").join(filename))
+    variable_infos = _get_l3_refl_variable_info(var_name)
+    create_hdfeos_test_file(full_path,
+                            variable_infos,
+                            _create_struct_metadata_cmg(f_short),
+                            _create_core_metadata(f_short),
+                            _create_header_metadata())
+    return [full_path]
+
+
+@pytest.fixture(scope="session")
+def modis_l3_nasa_mod09_file(tmpdir_factory) -> list[str]:
+    """Create a single MOD09 L3 HDF4 file with headers."""
+    return modis_l3_file(tmpdir_factory,
+                         "MOD09CMG",
+                         "Coarse_Resolution_Surface_Reflectance_Band_2",
+                         "MOD09")
+
+
+@pytest.fixture(scope="session")
+def modis_l3_nasa_mod43_file(tmpdir_factory) -> list[str]:
+    """Create a single MVCD43 L3 HDF4 file with headers."""
+    return modis_l3_file(tmpdir_factory,
+                         "MCD43C1",
+                         "BRDF_Albedo_Parameter1_Band2",
+                         "MCD43C1")
+
+
 @pytest.fixture(scope="session")
 def modis_l2_nasa_mod35_mod03_files(modis_l2_nasa_mod35_file, modis_l1b_nasa_mod03_file) -> list[str]:
     """Create a MOD35 L2 HDF4 file and MOD03 L1b geolocation file."""
@@ -550,7 +662,11 @@ def modis_l2_nasa_mod06_file(tmpdir_factory) -> list[str]:
     full_path = str(tmpdir_factory.mktemp("modis_l2").join(filename))
     variable_infos = _get_l1b_geo_variable_info(filename, 5000, include_angles=True)
     variable_infos.update(_get_basic_variable_info("Surface_Pressure", 5000))
-    create_hdfeos_test_file(full_path, variable_infos, geo_resolution=5000, file_shortname="MOD06")
+    create_hdfeos_test_file(full_path,
+                            variable_infos,
+                            _create_struct_metadata(5000),
+                            _create_core_metadata("MOD06"),
+                            _create_header_metadata())
     return [full_path]
 
 
@@ -561,7 +677,7 @@ def modis_l2_imapp_snowmask_file(tmpdir_factory) -> list[str]:
     full_path = str(tmpdir_factory.mktemp("modis_l2").join(filename))
     variable_infos = _get_l1b_geo_variable_info(filename, 5000, include_angles=False)
     variable_infos.update(_get_basic_variable_info("Snow_Mask", 1000))
-    create_hdfeos_test_file(full_path, variable_infos, include_metadata=False)
+    create_hdfeos_test_file(full_path, variable_infos)
     return [full_path]
 
 
@@ -578,7 +694,7 @@ def modis_l2_imapp_mask_byte1_file(tmpdir_factory) -> list[str]:
     full_path = str(tmpdir_factory.mktemp("modis_l2").join(filename))
     variable_infos = _get_l1b_geo_variable_info(filename, 5000, include_angles=False)
     variable_infos.update(_get_mask_byte1_variable_info())
-    create_hdfeos_test_file(full_path, variable_infos, include_metadata=False)
+    create_hdfeos_test_file(full_path, variable_infos)
     return [full_path]
 
 
