@@ -17,7 +17,7 @@
 # satpy.  If not, see <http://www.gnu.org/licenses/>.
 """Setup and configuration for all reader tests."""
 
-from ._modis_fixtures import (
+from ._modis_fixtures import (  # noqa: F401, I001
     modis_l1b_imapp_1000m_file,
     modis_l1b_imapp_geo_file,
     modis_l1b_nasa_1km_mod03_files,
@@ -32,4 +32,6 @@ from ._modis_fixtures import (
     modis_l2_nasa_mod06_file,
     modis_l2_nasa_mod35_file,
     modis_l2_nasa_mod35_mod03_files,
+    modis_l3_nasa_mod09_file,
+    modis_l3_nasa_mod43_file,
 )
