@@ -27,7 +27,7 @@ from satpy.readers.atms_l1b_nc import AtmsL1bNCFileHandler
 # - tmp_path
 
 
-@pytest.fixture
+@pytest.fixture()
 def reader(l1b_file):
     """Return reader of ATMS level1b data."""
     return AtmsL1bNCFileHandler(
@@ -37,15 +37,15 @@ def reader(l1b_file):
     )
 
 
-@pytest.fixture
+@pytest.fixture()
 def l1b_file(tmp_path, atms_fake_dataset):
     """Return file path to level1b file."""
     l1b_file_path = tmp_path / "test_file_atms_l1b.nc"
     atms_fake_dataset.to_netcdf(l1b_file_path)
-    yield l1b_file_path
+    return l1b_file_path
 
 
-@pytest.fixture
+@pytest.fixture()
 def atms_fake_dataset():
     """Return fake ATMS dataset."""
     atrack = 2
@@ -99,20 +99,20 @@ class TestAtsmsL1bNCFileHandler:
             atms_fake_dataset.antenna_temp.values,
         )
 
-    @pytest.mark.parametrize("param,expect", (
+    @pytest.mark.parametrize(("param", "expect"), [
         ("start_time", datetime(2000, 1, 2, 3, 4, 5)),
         ("end_time", datetime(2000, 1, 2, 4, 5, 6)),
         ("platform_name", "JPSS-1"),
         ("sensor", "ATMS"),
-    ))
+    ])
     def test_attrs(self, reader, param, expect):
         """Test attributes."""
         assert reader.attrs[param] == expect
 
-    @pytest.mark.parametrize("dims", (
+    @pytest.mark.parametrize("dims", [
         ("xtrack", "atrack"),
         ("x", "y"),
-    ))
+    ])
     def test_standardize_dims(self, reader, dims):
         """Test standardize dims."""
         data = xr.DataArray(
@@ -134,7 +134,7 @@ class TestAtsmsL1bNCFileHandler:
         data = reader._drop_coords(data)
         assert coords not in data.coords
 
-    @pytest.mark.parametrize("param,expect", (
+    @pytest.mark.parametrize(("param", "expect"), [
         ("start_time", datetime(2000, 1, 2, 3, 4, 5)),
         ("end_time", datetime(2000, 1, 2, 4, 5, 6)),
         ("platform_name", "JPSS-1"),
@@ -142,7 +142,7 @@ class TestAtsmsL1bNCFileHandler:
         ("creation_time", datetime(2020, 1, 2, 3, 4, 5)),
         ("type", "test_data"),
         ("name", "test"),
-    ))
+    ])
     def test_merge_attributes(self, reader, param, expect):
         """Test merge attributes."""
         data = xr.DataArray(
@@ -154,10 +154,10 @@ class TestAtsmsL1bNCFileHandler:
         data = reader._merge_attributes(data, dataset_info)
         assert data.attrs[param] == expect
 
-    @pytest.mark.parametrize("param,expect", (
+    @pytest.mark.parametrize(("param", "expect"), [
         ("1", 100.),
         ("sat_azi", 3.),
-    ))
+    ])
     def test_select_dataset(self, reader, param, expect):
         """Test select dataset."""
         np.testing.assert_array_equal(
