@@ -17,7 +17,7 @@
 # satpy.  If not, see <http://www.gnu.org/licenses/>.
 """Tests for the 'cmsaf-claas2_l2_nc' reader."""
 
-import datetime
+import datetime  # noqa: I001
 import os
 
 import numpy as np
@@ -41,7 +41,7 @@ def start_time(request):
     return request.param
 
 
-@pytest.fixture
+@pytest.fixture()
 def start_time_str(start_time):
     """Get string representation of the start time."""
     return start_time.strftime("%Y-%m-%dT%H:%M:%SZ")
@@ -81,7 +81,7 @@ def fake_dataset(start_time_str):
     )
 
 
-@pytest.fixture
+@pytest.fixture()
 def encoding():
     """Dataset encoding."""
     return {
@@ -89,15 +89,15 @@ def encoding():
     }
 
 
-@pytest.fixture
+@pytest.fixture()
 def fake_file(fake_dataset, encoding, tmp_path):
     """Write a fake dataset to file."""
     filename = tmp_path / "CPPin20140101001500305SVMSG01MD.nc"
     fake_dataset.to_netcdf(filename, encoding=encoding)
-    yield filename
+    return filename
 
 
-@pytest.fixture
+@pytest.fixture()
 def fake_files(fake_dataset, encoding, tmp_path):
     """Write the same fake dataset into two different files."""
     filenames = [
@@ -106,10 +106,10 @@ def fake_files(fake_dataset, encoding, tmp_path):
     ]
     for filename in filenames:
         fake_dataset.to_netcdf(filename, encoding=encoding)
-    yield filenames
+    return filenames
 
 
-@pytest.fixture
+@pytest.fixture()
 def reader():
     """Return reader for CMSAF CLAAS-2."""
     from satpy._config import config_search_paths
@@ -137,14 +137,14 @@ def test_file_pattern(reader):
 class TestCLAAS2MultiFile:
     """Test reading multiple CLAAS-2 files."""
 
-    @pytest.fixture
+    @pytest.fixture()
     def multi_file_reader(self, reader, fake_files):
         """Create a multi-file reader."""
         loadables = reader.select_files_from_pathnames(fake_files)
         reader.create_filehandlers(loadables)
         return reader
 
-    @pytest.fixture
+    @pytest.fixture()
     def multi_file_dataset(self, multi_file_reader):
         """Load datasets from multiple files."""
         ds_ids = [make_dataid(name=name) for name in ["cph", "ctt"]]
@@ -157,7 +157,7 @@ class TestCLAAS2MultiFile:
         assert multi_file_reader.end_time == datetime.datetime(2085, 8, 13, 13, 15)
 
     @pytest.mark.parametrize(
-        "ds_name,expected",
+        ("ds_name", "expected"),
         [
             ("cph", [[0, 1], [2, 0], [0, 1], [2, 0]]),
             ("ctt", [[280, 290], [300, 310], [280, 290], [300, 310]]),
@@ -177,20 +177,20 @@ class TestCLAAS2MultiFile:
 class TestCLAAS2SingleFile:
     """Test reading a single CLAAS2 file."""
 
-    @pytest.fixture
+    @pytest.fixture()
     def file_handler(self, fake_file):
         """Return a CLAAS-2 file handler."""
         from satpy.readers.cmsaf_claas2 import CLAAS2
         return CLAAS2(fake_file, {}, {})
 
-    @pytest.fixture
+    @pytest.fixture()
     def area_extent_exp(self, start_time):
         """Get expected area extent."""
         if start_time < datetime.datetime(2017, 12, 6):
             return (-5454733.160460291, -5454733.160460292, 5454733.160460292, 5454733.160460291)
         return (-5456233.362099582, -5453232.958821001, 5453232.958821001, 5456233.362099582)
 
-    @pytest.fixture
+    @pytest.fixture()
     def area_exp(self, area_extent_exp):
         """Get expected area definition."""
         proj_dict = {
@@ -217,10 +217,10 @@ class TestCLAAS2SingleFile:
         assert area == area_exp
 
     @pytest.mark.parametrize(
-        "ds_name,expected",
+        ("ds_name", "expected"),
         [
-            ("ctt", xr.DataArray([[280, 290], [300, 310]], dims=('y', 'x'))),
-            ("cph", xr.DataArray([[0, 1], [2, 0]], dims=('y', 'x'))),
+            ("ctt", xr.DataArray([[280, 290], [300, 310]], dims=("y", "x"))),
+            ("cph", xr.DataArray([[0, 1], [2, 0]], dims=("y", "x"))),
         ]
     )
     def test_get_dataset(self, file_handler, ds_name, expected):
