@@ -23,6 +23,7 @@ from datetime import datetime
 from unittest import mock
 
 import numpy as np
+from pytest import approx  # noqa: PT013
 
 from satpy.tests.utils import make_dataid
 
@@ -36,8 +37,8 @@ class FakeMessage(object):
         self.attrs = attrs
         self.values = values
         if proj_params is None:
-            proj_params = {'a': 6378140.0, 'b': 6356755.0, 'lat_0': 0.0,
-                           'lon_0': 0.0, 'proj': 'geos', 'h': 35785830.098}
+            proj_params = {"a": 6378140.0, "b": 6356755.0, "lat_0": 0.0,
+                           "lon_0": 0.0, "proj": "geos", "h": 35785830.098}
         self.projparams = proj_params
         self._latlons = latlons
 
@@ -66,15 +67,15 @@ class FakeGRIB(object):
             self._messages = [
                 FakeMessage(
                     values=np.arange(25.).reshape((5, 5)),
-                    name='Instantaneous rain rate',
-                    shortName='irrate',
-                    cfName='unknown',
-                    units='kg m**-2 s**-1',
+                    name="Instantaneous rain rate",
+                    shortName="irrate",
+                    cfName="unknown",
+                    units="kg m**-2 s**-1",
                     dataDate=20190603,
                     dataTime=1645,
                     missingValue=9999,
-                    modelName='unknown',
-                    centreDescription='Rome',
+                    modelName="unknown",
+                    centreDescription="Rome",
                     minimum=0.0,
                     maximum=0.01475,
                     Nx=3712,
@@ -121,51 +122,51 @@ class TestHSAFFileHandler(unittest.TestCase):
         except ImportError:
             pygrib = None
         self.orig_pygrib = pygrib
-        sys.modules['pygrib'] = mock.MagicMock()
+        sys.modules["pygrib"] = mock.MagicMock()
 
     def tearDown(self):
         """Re-enable pygrib import."""
-        sys.modules['pygrib'] = self.orig_pygrib
+        sys.modules["pygrib"] = self.orig_pygrib
 
-    @mock.patch('satpy.readers.hsaf_grib.pygrib.open', return_value=FakeGRIB())
+    @mock.patch("satpy.readers.hsaf_grib.pygrib.open", return_value=FakeGRIB())
     def test_init(self, pg):
         """Test the init function, ensure that the correct dates and metadata are returned."""
         pg.open.return_value = FakeGRIB()
         correct_dt = datetime(2019, 6, 3, 16, 45, 0)
         from satpy.readers.hsaf_grib import HSAFFileHandler
-        fh = HSAFFileHandler('filename', mock.MagicMock(), mock.MagicMock())
-        self.assertEqual(fh._analysis_time, correct_dt)
-        self.assertEqual(fh.metadata['projparams']['lat_0'], 0.0)
-        self.assertEqual(fh.metadata['shortName'], 'irrate')
-        self.assertEqual(fh.metadata['nx'], 3712)
+        fh = HSAFFileHandler("filename", mock.MagicMock(), mock.MagicMock())
+        assert fh._analysis_time == correct_dt
+        assert fh.metadata["projparams"]["lat_0"] == 0.0
+        assert fh.metadata["shortName"] == "irrate"
+        assert fh.metadata["nx"] == 3712
 
-    @mock.patch('satpy.readers.hsaf_grib.pygrib.open', return_value=FakeGRIB())
+    @mock.patch("satpy.readers.hsaf_grib.pygrib.open", return_value=FakeGRIB())
     def test_get_area_def(self, pg):
         """Test the area definition setup, checks the size and extent."""
         pg.open.return_value = FakeGRIB()
         from satpy.readers.hsaf_grib import HSAFFileHandler
-        fh = HSAFFileHandler('filename', mock.MagicMock(), mock.MagicMock())
-        area_def = HSAFFileHandler.get_area_def(fh, 'H03B')
-        self.assertEqual(area_def.width, 3712)
-        self.assertAlmostEqual(area_def.area_extent[0], -5569209.3026, places=3)
-        self.assertAlmostEqual(area_def.area_extent[3], 5587721.9097, places=3)
+        fh = HSAFFileHandler("filename", mock.MagicMock(), mock.MagicMock())
+        area_def = HSAFFileHandler.get_area_def(fh, "H03B")
+        assert area_def.width == 3712
+        assert area_def.area_extent[0] == approx(-5569209.3026, abs=1e-3)
+        assert area_def.area_extent[3] == approx(5587721.9097, abs=1e-3)
 
-    @mock.patch('satpy.readers.hsaf_grib.pygrib.open', return_value=FakeGRIB())
+    @mock.patch("satpy.readers.hsaf_grib.pygrib.open", return_value=FakeGRIB())
     def test_get_dataset(self, pg):
         """Test reading the actual datasets from a grib file."""
         pg.open.return_value = FakeGRIB()
         from satpy.readers.hsaf_grib import HSAFFileHandler
 
         # Instantaneous precipitation
-        fh = HSAFFileHandler('filename', mock.MagicMock(), mock.MagicMock())
+        fh = HSAFFileHandler("filename", mock.MagicMock(), mock.MagicMock())
         fh.filename = "H03B"
-        ds_id = make_dataid(name='H03B')
+        ds_id = make_dataid(name="H03B")
         data = fh.get_dataset(ds_id, mock.Mock())
         np.testing.assert_array_equal(data.values, np.arange(25.).reshape((5, 5)))
 
         # Accumulated precipitation
-        fh = HSAFFileHandler('filename', mock.MagicMock(), mock.MagicMock())
+        fh = HSAFFileHandler("filename", mock.MagicMock(), mock.MagicMock())
         fh.filename = "H05B"
-        ds_id = make_dataid(name='H05B')
+        ds_id = make_dataid(name="H05B")
         data = fh.get_dataset(ds_id, mock.Mock())
         np.testing.assert_array_equal(data.values, np.arange(25.).reshape((5, 5)))
