@@ -74,6 +74,7 @@ calibrated_units = {"": "1",
 
 start_time = datetime(2009, 6, 9, 9, 0)
 end_time = datetime(2009, 6, 9, 9, 30)
+subsatellite_longitude = 82
 
 time_pattern = "%d-%b-%YT%H:%M:%S"
 
@@ -81,7 +82,7 @@ global_attrs = {"Observed_Altitude(km)": 35778.490219,
                 "Field_of_View(degrees)": 17.973925,
                 "Acquisition_Start_Time": start_time.strftime(time_pattern),
                 "Acquisition_End_Time": end_time.strftime(time_pattern),
-                "Nominal_Central_Point_Coordinates(degrees)_Latitude_Longitude": [0.0, 82.0],
+                "Nominal_Central_Point_Coordinates(degrees)_Latitude_Longitude": [0.0, subsatellite_longitude],
                 "Nominal_Altitude(km)": 36000.0,
                 }
 
@@ -138,7 +139,7 @@ def test_insat3d_backend_has_1km_channels(insat_filename):
     assert res["IMG_SWIR"].shape == shape_1km
 
 
-@pytest.mark.parametrize("resolution,name,shape,expected_values,expected_name,expected_units",
+@pytest.mark.parametrize(("resolution", "name", "shape", "expected_values", "expected_name", "expected_units"),
                          [(1000, "IMG_VIS_RADIANCE", shape_1km, mask_array(values_1km * 2),
                            "Visible Radiance", rad_units),
                           (1000, "IMG_VIS_ALBEDO", shape_1km, mask_array(values_1km * 3),
@@ -173,7 +174,7 @@ def test_insat3d_has_dask_arrays(insat_filename):
 
 def test_insat3d_only_has_3_resolutions(insat_filename):
     """Test that we only accept 1000, 4000, 8000."""
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError, match="Resolution 1024 not available. Available resolutions: 1000, 4000, 8000"):
         _ = open_dataset(insat_filename, resolution=1024)
 
 
@@ -208,7 +209,7 @@ def test_insat3d_datatree_has_global_attributes(insat_filename):
     assert res.attrs.keys() >= global_attrs.keys()
 
 
-@pytest.mark.parametrize("calibration,expected_values",
+@pytest.mark.parametrize(("calibration", "expected_values"),
                          [("counts", values_1km),
                           ("radiance", mask_array(values_1km * 2)),
                           ("reflectance", mask_array(values_1km * 3))])
@@ -228,7 +229,7 @@ def test_filehandler_returns_masked_data_in_space(insat_filehandler):
     fh = insat_filehandler
     ds_info = None
 
-    ds_id = make_dataid(name="VIS", resolution=1000, calibration='reflectance')
+    ds_id = make_dataid(name="VIS", resolution=1000, calibration="reflectance")
     darr = fh.get_dataset(ds_id, ds_info)
     assert np.isnan(darr[0, 0])
 
@@ -238,11 +239,12 @@ def test_insat3d_has_orbital_parameters(insat_filehandler):
     fh = insat_filehandler
     ds_info = None
 
-    ds_id = make_dataid(name="VIS", resolution=1000, calibration='reflectance')
+    ds_id = make_dataid(name="VIS", resolution=1000, calibration="reflectance")
     darr = fh.get_dataset(ds_id, ds_info)
 
     assert "orbital_parameters" in darr.attrs
     assert "satellite_nominal_longitude" in darr.attrs["orbital_parameters"]
+    assert darr.attrs["orbital_parameters"]["satellite_nominal_longitude"] == subsatellite_longitude
     assert "satellite_nominal_latitude" in darr.attrs["orbital_parameters"]
     assert "satellite_nominal_altitude" in darr.attrs["orbital_parameters"]
     assert "satellite_actual_altitude" in darr.attrs["orbital_parameters"]
@@ -276,6 +278,7 @@ def test_filehandler_returns_area(insat_filehandler):
     ds_id = make_dataid(name="MIR", resolution=4000, calibration="brightness_temperature")
     area_def = fh.get_area_def(ds_id)
     lons, lats = area_def.get_lonlats(chunks=1000)
+    assert "+lon_0=" + str(subsatellite_longitude) in area_def.crs.to_proj4()
 
 
 def test_filehandler_has_start_and_end_time(insat_filehandler):
