@@ -43,42 +43,42 @@ class FakeNetCDF4FileHandlerMimic(FakeNetCDF4FileHandler):
     def get_test_content(self, filename, filename_info, filetype_info):
         """Mimic reader input file content."""
         from xarray import DataArray
-        dt_s = filename_info.get('start_time', datetime(2019, 6, 19, 13, 0))
-        dt_e = filename_info.get('end_time', datetime(2019, 6, 19, 13, 0))
+        dt_s = filename_info.get("start_time", datetime(2019, 6, 19, 13, 0))
+        dt_e = filename_info.get("end_time", datetime(2019, 6, 19, 13, 0))
 
-        if filetype_info['file_type'] == 'mimicTPW2_comp':
+        if filetype_info["file_type"] == "mimicTPW2_comp":
             file_content = {
-                '/attr/start_time': dt_s.strftime('%Y%m%d.%H%M%S'),
-                '/attr/end_time': dt_e.strftime('%Y%m%d.%H%M%S'),
-                '/attr/platform_shortname': 'aggregated microwave',
-                '/attr/sensor': 'mimic',
+                "/attr/start_time": dt_s.strftime("%Y%m%d.%H%M%S"),
+                "/attr/end_time": dt_e.strftime("%Y%m%d.%H%M%S"),
+                "/attr/platform_shortname": "aggregated microwave",
+                "/attr/sensor": "mimic",
             }
-            file_content['latArr'] = DEFAULT_LAT
-            file_content['latArr/shape'] = (DEFAULT_FILE_SHAPE[0],)
-            file_content['latArr/attr/units'] = 'degress_north'
+            file_content["latArr"] = DEFAULT_LAT
+            file_content["latArr/shape"] = (DEFAULT_FILE_SHAPE[0],)
+            file_content["latArr/attr/units"] = "degress_north"
 
-            file_content['lonArr'] = DEFAULT_LON
-            file_content['lonArr/shape'] = (DEFAULT_FILE_SHAPE[1],)
-            file_content['lonArr/attr/units'] = 'degrees_east'
+            file_content["lonArr"] = DEFAULT_LON
+            file_content["lonArr/shape"] = (DEFAULT_FILE_SHAPE[1],)
+            file_content["lonArr/attr/units"] = "degrees_east"
 
-            file_content['tpwGrid'] = DEFAULT_FILE_DATA
-            file_content['tpwGrid/shape'] = DEFAULT_FILE_SHAPE
-            file_content_units['tpwGrid'] = 'mm'
+            file_content["tpwGrid"] = DEFAULT_FILE_DATA
+            file_content["tpwGrid/shape"] = DEFAULT_FILE_SHAPE
+            file_content_units["tpwGrid"] = "mm"
 
-            file_content['/dimension/lat'] = DEFAULT_FILE_SHAPE[0]
-            file_content['/dimension/lon'] = DEFAULT_FILE_SHAPE[1]
+            file_content["/dimension/lat"] = DEFAULT_FILE_SHAPE[0]
+            file_content["/dimension/lon"] = DEFAULT_FILE_SHAPE[1]
 
             # convert to xarrays
             for key, val in file_content.items():
-                if key == 'lonArr' or key == 'latArr':
+                if key == "lonArr" or key == "latArr":
                     file_content[key] = DataArray(val)
                 elif isinstance(val, np.ndarray):
                     if val.ndim > 1:
-                        file_content[key] = DataArray(val, dims=('y', 'x'), attrs={"units": file_content_units[key]})
+                        file_content[key] = DataArray(val, dims=("y", "x"), attrs={"units": file_content_units[key]})
                     else:
                         file_content[key] = DataArray(val)
         else:
-            msg = 'Wrong Test Reader for file_type {}'.format(filetype_info['file_type'])
+            msg = "Wrong Test Reader for file_type {}".format(filetype_info["file_type"])
             raise AssertionError(msg)
 
         return file_content
@@ -93,9 +93,9 @@ class TestMimicTPW2Reader(unittest.TestCase):
         """Wrap NetCDF4 file handler with our own fake handler."""
         from satpy._config import config_search_paths
         from satpy.readers.mimic_TPW2_nc import MimicTPW2FileHandler
-        self.reader_configs = config_search_paths(os.path.join('readers', self.yaml_file))
+        self.reader_configs = config_search_paths(os.path.join("readers", self.yaml_file))
         # http://stackoverflow.com/questions/12219967/how-to-mock-a-base-class-with-python-mock-library
-        self.p = mock.patch.object(MimicTPW2FileHandler, '__bases__', (FakeNetCDF4FileHandlerMimic,))
+        self.p = mock.patch.object(MimicTPW2FileHandler, "__bases__", (FakeNetCDF4FileHandlerMimic,))
         self.fake_handler = self.p.start()
         self.p.is_local = True
 
@@ -108,27 +108,27 @@ class TestMimicTPW2Reader(unittest.TestCase):
         from satpy.readers import load_reader
         r = load_reader(self.reader_configs)
         loadables = r.select_files_from_pathnames([
-            'comp20190619.130000.nc',
+            "comp20190619.130000.nc",
         ])
-        self.assertEqual(len(loadables), 1)
+        assert len(loadables) == 1
         r.create_filehandlers(loadables)
         # make sure we have some files
-        self.assertTrue(r.file_handlers)
+        assert r.file_handlers
 
     def test_load_mimic(self):
         """Load Mimic data."""
         from satpy.readers import load_reader
         r = load_reader(self.reader_configs)
-        with mock.patch('satpy.readers.mimic_TPW2_nc.netCDF4.Variable', xr.DataArray):
+        with mock.patch("satpy.readers.mimic_TPW2_nc.netCDF4.Variable", xr.DataArray):
             loadables = r.select_files_from_pathnames([
-                'comp20190619.130000.nc',
+                "comp20190619.130000.nc",
             ])
             r.create_filehandlers(loadables)
-        ds = r.load(['tpwGrid'])
-        self.assertEqual(len(ds), 1)
+        ds = r.load(["tpwGrid"])
+        assert len(ds) == 1
         for d in ds.values():
-            self.assertEqual(d.attrs['platform_shortname'], 'aggregated microwave')
-            self.assertEqual(d.attrs['sensor'], 'mimic')
-            self.assertIn('area', d.attrs)
-            self.assertIn('units', d.attrs)
-            self.assertIsNotNone(d.attrs['area'])
+            assert d.attrs["platform_shortname"] == "aggregated microwave"
+            assert d.attrs["sensor"] == "mimic"
+            assert "area" in d.attrs
+            assert "units" in d.attrs
+            assert d.attrs["area"] is not None
