@@ -43,40 +43,40 @@ N_FOVS_CAL = 5
 N_PRTS = 6
 
 
-@pytest.fixture
+@pytest.fixture()
 def reader(fake_file):
     """Return reader of mws level-1b data."""
     return MWSL1BFile(
         filename=fake_file,
         filename_info={
-            'start_time': (
-                datetime.fromisoformat('2000-01-01T01:00:00')
+            "start_time": (
+                datetime.fromisoformat("2000-01-01T01:00:00")
             ),
-            'end_time': (
-                datetime.fromisoformat('2000-01-01T02:00:00')
+            "end_time": (
+                datetime.fromisoformat("2000-01-01T02:00:00")
             ),
-            'creation_time': (
-                datetime.fromisoformat('2000-01-01T03:00:00')
+            "creation_time": (
+                datetime.fromisoformat("2000-01-01T03:00:00")
             ),
         },
         filetype_info={
-            'longitude': 'data/navigation_data/mws_lon',
-            'latitude': 'data/navigation_data/mws_lat',
-            'solar_azimuth': 'data/navigation/mws_solar_azimuth_angle',
-            'solar_zenith': 'data/navigation/mws_solar_zenith_angle',
-            'satellite_azimuth': 'data/navigation/mws_satellite_azimuth_angle',
-            'satellite_zenith': 'data/navigation/mws_satellite_zenith_angle',
+            "longitude": "data/navigation_data/mws_lon",
+            "latitude": "data/navigation_data/mws_lat",
+            "solar_azimuth": "data/navigation/mws_solar_azimuth_angle",
+            "solar_zenith": "data/navigation/mws_solar_zenith_angle",
+            "satellite_azimuth": "data/navigation/mws_satellite_azimuth_angle",
+            "satellite_zenith": "data/navigation/mws_satellite_zenith_angle",
         }
     )
 
 
-@pytest.fixture
+@pytest.fixture()
 def fake_file(tmp_path):
     """Return file path to level-1b file."""
-    file_path = tmp_path / 'test_file_mws_l1b.nc'
+    file_path = tmp_path / "test_file_mws_l1b.nc"
     writer = MWSL1BFakeFileWriter(file_path)
     writer.write()
-    yield file_path
+    return file_path
 
 
 class MWSL1BFakeFileWriter:
@@ -88,11 +88,11 @@ class MWSL1BFakeFileWriter:
 
     def write(self):
         """Write fake data to file."""
-        with Dataset(self.file_path, 'w') as dataset:
+        with Dataset(self.file_path, "w") as dataset:
             self._write_attributes(dataset)
             self._write_status_group(dataset)
             self._write_quality_group(dataset)
-            data_group = dataset.createGroup('data')
+            data_group = dataset.createGroup("data")
             self._create_scan_dimensions(data_group)
             self._write_navigation_data_group(data_group)
             self._write_calibration_data_group(data_group)
@@ -109,45 +109,45 @@ class MWSL1BFakeFileWriter:
     @staticmethod
     def _write_status_group(dataset):
         """Write the status group."""
-        group = dataset.createGroup('/status/satellite')
+        group = dataset.createGroup("/status/satellite")
         subsat_latitude_start = group.createVariable(
-            'subsat_latitude_start', "f4"
+            "subsat_latitude_start", "f4"
         )
         subsat_latitude_start[:] = 52.19
 
         subsat_longitude_start = group.createVariable(
-            'subsat_longitude_start', "f4"
+            "subsat_longitude_start", "f4"
         )
         subsat_longitude_start[:] = 23.26
 
         subsat_latitude_end = group.createVariable(
-            'subsat_latitude_end', "f4"
+            "subsat_latitude_end", "f4"
         )
         subsat_latitude_end[:] = 60.00
 
         subsat_longitude_end = group.createVariable(
-            'subsat_longitude_end', "f4"
+            "subsat_longitude_end", "f4"
         )
         subsat_longitude_end[:] = 2.47
 
     @staticmethod
     def _write_quality_group(dataset):
         """Write the quality group."""
-        group = dataset.createGroup('quality')
+        group = dataset.createGroup("quality")
         group.overall_quality_flag = 0
         duration_of_product = group.createVariable(
-            'duration_of_product', "f4"
+            "duration_of_product", "f4"
         )
         duration_of_product[:] = 5944.
 
     @staticmethod
     def _write_navigation_data_group(dataset):
         """Write the navigation data group."""
-        group = dataset.createGroup('navigation')
-        dimensions = ('n_scans', 'n_fovs')
+        group = dataset.createGroup("navigation")
+        dimensions = ("n_scans", "n_fovs")
         shape = (N_SCANS, N_FOVS)
         longitude = group.createVariable(
-            'mws_lon',
+            "mws_lon",
             np.int32,
             dimensions=dimensions,
         )
@@ -157,14 +157,14 @@ class MWSL1BFakeFileWriter:
         longitude[:] = 35.7535 * np.ones(shape)
 
         latitude = group.createVariable(
-            'mws_lat',
+            "mws_lat",
             np.float32,
             dimensions=dimensions,
         )
         latitude[:] = 2. * np.ones(shape)
 
         azimuth = group.createVariable(
-            'mws_solar_azimuth_angle',
+            "mws_solar_azimuth_angle",
             np.float32,
             dimensions=dimensions,
         )
@@ -173,19 +173,19 @@ class MWSL1BFakeFileWriter:
     @staticmethod
     def _create_scan_dimensions(dataset):
         """Create the scan/fovs dimensions."""
-        dataset.createDimension('n_channels', N_CHANNELS)
-        dataset.createDimension('n_channels_os', N_CHANNELS_OS)
-        dataset.createDimension('n_scans', N_SCANS)
-        dataset.createDimension('n_fovs', N_FOVS)
-        dataset.createDimension('n_prts', N_PRTS)
-        dataset.createDimension('n_fovs_cal', N_FOVS_CAL)
+        dataset.createDimension("n_channels", N_CHANNELS)
+        dataset.createDimension("n_channels_os", N_CHANNELS_OS)
+        dataset.createDimension("n_scans", N_SCANS)
+        dataset.createDimension("n_fovs", N_FOVS)
+        dataset.createDimension("n_prts", N_PRTS)
+        dataset.createDimension("n_fovs_cal", N_FOVS_CAL)
 
     @staticmethod
     def _write_calibration_data_group(dataset):
         """Write the calibration data group."""
-        group = dataset.createGroup('calibration')
+        group = dataset.createGroup("calibration")
         toa_bt = group.createVariable(
-            'mws_toa_brightness_temperature', np.float32, dimensions=('n_scans', 'n_fovs', 'n_channels',)
+            "mws_toa_brightness_temperature", np.float32, dimensions=("n_scans", "n_fovs", "n_channels",)
         )
         toa_bt.scale_factor = 1.0  # 1.0E-8
         toa_bt.add_offset = 0.0
@@ -195,9 +195,9 @@ class MWSL1BFakeFileWriter:
     @staticmethod
     def _write_measurement_data_group(dataset):
         """Write the measurement data group."""
-        group = dataset.createGroup('measurement')
+        group = dataset.createGroup("measurement")
         counts = group.createVariable(
-            'mws_earth_view_counts', np.int32, dimensions=('n_scans', 'n_fovs', 'n_channels',)
+            "mws_earth_view_counts", np.int32, dimensions=("n_scans", "n_fovs", "n_channels",)
         )
         counts[:] = 24100 * np.ones((N_SCANS, N_FOVS, N_CHANNELS), dtype=np.int32)
 
@@ -239,9 +239,9 @@ class TestMwsL1bNCFileHandler:
 
     def test_get_dataset_get_channeldata_counts(self, reader):
         """Test getting channel data."""
-        dataset_id = {'name': '1', 'units': None,
-                      'calibration': 'counts'}
-        dataset_info = {'file_key': 'data/measurement/mws_earth_view_counts'}
+        dataset_id = {"name": "1", "units": None,
+                      "calibration": "counts"}
+        dataset_info = {"file_key": "data/measurement/mws_earth_view_counts"}
 
         dataset = reader.get_dataset(dataset_id, dataset_info)
         expected_bt = np.array([[24100, 24100],
@@ -251,9 +251,9 @@ class TestMwsL1bNCFileHandler:
 
     def test_get_dataset_get_channeldata_bts(self, reader):
         """Test getting channel data."""
-        dataset_id = {'name': '1', 'units': 'K',
-                      'calibration': 'brightness_temperature'}
-        dataset_info = {'file_key': 'data/calibration/mws_toa_brightness_temperature'}
+        dataset_id = {"name": "1", "units": "K",
+                      "calibration": "brightness_temperature"}
+        dataset_info = {"file_key": "data/calibration/mws_toa_brightness_temperature"}
 
         dataset = reader.get_dataset(dataset_id, dataset_info)
 
@@ -268,15 +268,15 @@ class TestMwsL1bNCFileHandler:
 
     def test_get_dataset_return_none_if_data_not_exist(self, reader):
         """Test get dataset return none if data does not exist."""
-        dataset_id = {'name': 'unknown'}
-        dataset_info = {'file_key': 'non/existing/data'}
+        dataset_id = {"name": "unknown"}
+        dataset_info = {"file_key": "non/existing/data"}
         dataset = reader.get_dataset(dataset_id, dataset_info)
         assert dataset is None
 
     def test_get_navigation_longitudes(self, caplog, fake_file, reader):
         """Test get the longitudes."""
-        dataset_id = {'name': 'mws_lon'}
-        dataset_info = {'file_key': 'data/navigation_data/mws_lon'}
+        dataset_id = {"name": "mws_lon"}
+        dataset_info = {"file_key": "data/navigation_data/mws_lon"}
 
         dataset = reader.get_dataset(dataset_id, dataset_info)
 
@@ -291,8 +291,8 @@ class TestMwsL1bNCFileHandler:
 
     def test_get_dataset_logs_debug_message(self, caplog, fake_file, reader):
         """Test get dataset return none if data does not exist."""
-        dataset_id = {'name': 'mws_lon'}
-        dataset_info = {'file_key': 'data/navigation_data/mws_lon'}
+        dataset_id = {"name": "mws_lon"}
+        dataset_info = {"file_key": "data/navigation_data/mws_lon"}
 
         with caplog.at_level(logging.DEBUG):
             _ = reader.get_dataset(dataset_id, dataset_info)
@@ -302,8 +302,8 @@ class TestMwsL1bNCFileHandler:
 
     def test_get_dataset_aux_data_not_supported(self, reader):
         """Test get auxillary dataset not supported."""
-        dataset_id = {'name': 'scantime_utc'}
-        dataset_info = {'file_key': 'non/existing'}
+        dataset_id = {"name": "scantime_utc"}
+        dataset_info = {"file_key": "non/existing"}
 
         with pytest.raises(NotImplementedError) as exec_info:
             _ = reader.get_dataset(dataset_id, dataset_info)
@@ -312,8 +312,8 @@ class TestMwsL1bNCFileHandler:
 
     def test_get_dataset_aux_data_expected_data_missing(self, caplog, reader):
         """Test get auxillary dataset which is not present but supposed to be in file."""
-        dataset_id = {'name': 'surface_type'}
-        dataset_info = {'file_key': 'non/existing'}
+        dataset_id = {"name": "surface_type"}
+        dataset_info = {"file_key": "non/existing"}
 
         with caplog.at_level(logging.ERROR):
             with pytest.raises(KeyError) as exec_info:
@@ -325,10 +325,10 @@ class TestMwsL1bNCFileHandler:
                       " no valid Dataset created")
         assert log_output in caplog.text
 
-    @pytest.mark.parametrize('dims', (
-        ('n_scans', 'n_fovs'),
-        ('x', 'y'),
-    ))
+    @pytest.mark.parametrize("dims", [
+        ("n_scans", "n_fovs"),
+        ("x", "y"),
+    ])
     def test_standardize_dims(self, reader, dims):
         """Test standardize dims."""
         variable = xr.DataArray(
@@ -336,7 +336,7 @@ class TestMwsL1bNCFileHandler:
             dims=dims,
         )
         standardized = reader._standardize_dims(variable)
-        assert standardized.dims == ('y', 'x')
+        assert standardized.dims == ("y", "x")
 
     @staticmethod
     def test_drop_coords(reader):
@@ -344,7 +344,7 @@ class TestMwsL1bNCFileHandler:
         coords = "dummy"
         data = xr.DataArray(
             np.ones(10),
-            dims=('y'),
+            dims=("y"),
             coords={coords: 0},
         )
         assert coords in data.coords
@@ -355,22 +355,22 @@ class TestMwsL1bNCFileHandler:
         """Test get global attributes."""
         attributes = reader._get_global_attributes()
         assert attributes == {
-            'filename': reader.filename,
-            'start_time': datetime(2000, 1, 2, 3, 4, 5),
-            'end_time': datetime(2000, 1, 2, 4, 5, 6),
-            'spacecraft_name': 'Metop-SG-A1',
-            'sensor': 'MWS',
-            'filename_start_time': datetime(2000, 1, 1, 1, 0),
-            'filename_end_time': datetime(2000, 1, 1, 2, 0),
-            'platform_name': 'Metop-SG-A1',
-            'quality_group': {
-                'duration_of_product': np.array(5944., dtype=np.float32),
-                'overall_quality_flag': 0,
+            "filename": reader.filename,
+            "start_time": datetime(2000, 1, 2, 3, 4, 5),
+            "end_time": datetime(2000, 1, 2, 4, 5, 6),
+            "spacecraft_name": "Metop-SG-A1",
+            "sensor": "MWS",
+            "filename_start_time": datetime(2000, 1, 1, 1, 0),
+            "filename_end_time": datetime(2000, 1, 1, 2, 0),
+            "platform_name": "Metop-SG-A1",
+            "quality_group": {
+                "duration_of_product": np.array(5944., dtype=np.float32),
+                "overall_quality_flag": 0,
             }
         }
 
     @patch(
-        'satpy.readers.mws_l1b.MWSL1BFile._get_global_attributes',
+        "satpy.readers.mws_l1b.MWSL1BFile._get_global_attributes",
         return_value={"mocked_global_attributes": True},
     )
     def test_manage_attributes(self, mock, reader):
@@ -379,17 +379,17 @@ class TestMwsL1bNCFileHandler:
             np.ones(N_SCANS),
             attrs={"season": "summer"},
         )
-        dataset_info = {'name': '1', 'units': 'K'}
+        dataset_info = {"name": "1", "units": "K"}
         variable = reader._manage_attributes(variable, dataset_info)
         assert variable.attrs == {
-            'season': 'summer',
-            'units': 'K',
-            'name': '1',
-            'mocked_global_attributes': True,
+            "season": "summer",
+            "units": "K",
+            "name": "1",
+            "mocked_global_attributes": True,
         }
 
 
-@pytest.mark.parametrize("name, index", [('1', 0), ('2', 1), ('24', 23)])
+@pytest.mark.parametrize(("name", "index"), [("1", 0), ("2", 1), ("24", 23)])
 def test_get_channel_index_from_name(name, index):
     """Test getting the MWS channel index from the channel name."""
     ch_idx = get_channel_index_from_name(name)
@@ -398,8 +398,5 @@ def test_get_channel_index_from_name(name, index):
 
 def test_get_channel_index_from_name_throw_exception():
     """Test that an excpetion is thrown when getting the MWS channel index from an unsupported name."""
-    with pytest.raises(Exception) as excinfo:
-        _ = get_channel_index_from_name('channel 1')
-
-    assert str(excinfo.value) == "Channel name 'channel 1' not supported"
-    assert excinfo.type == AttributeError
+    with pytest.raises(AttributeError, match="Channel name 'channel 1' not supported"):
+        _ = get_channel_index_from_name("channel 1")
