@@ -23,19 +23,19 @@ import xarray as xr
 
 from satpy.readers.nwcsaf_nc import NcNWCSAF, read_nwcsaf_time
 
-PROJ_KM = {'gdal_projection': '+proj=geos +a=6378.137000 +b=6356.752300 +lon_0=0.000000 +h=35785.863000',
-           'gdal_xgeo_up_left': -5569500.0,
-           'gdal_ygeo_up_left': 5437500.0,
-           'gdal_xgeo_low_right': 5566500.0,
-           'gdal_ygeo_low_right': 2653500.0}
+PROJ_KM = {"gdal_projection": "+proj=geos +a=6378.137000 +b=6356.752300 +lon_0=0.000000 +h=35785.863000",
+           "gdal_xgeo_up_left": -5569500.0,
+           "gdal_ygeo_up_left": 5437500.0,
+           "gdal_xgeo_low_right": 5566500.0,
+           "gdal_ygeo_low_right": 2653500.0}
 
 NOMINAL_ALTITUDE = 35785863.0
 
-PROJ = {'gdal_projection': f'+proj=geos +a=6378137.000 +b=6356752.300 +lon_0=0.000000 +h={NOMINAL_ALTITUDE:.3f}',
-        'gdal_xgeo_up_left': -5569500.0,
-        'gdal_ygeo_up_left': 5437500.0,
-        'gdal_xgeo_low_right': 5566500.0,
-        'gdal_ygeo_low_right': 2653500.0}
+PROJ = {"gdal_projection": f"+proj=geos +a=6378137.000 +b=6356752.300 +lon_0=0.000000 +h={NOMINAL_ALTITUDE:.3f}",
+        "gdal_xgeo_up_left": -5569500.0,
+        "gdal_ygeo_up_left": 5437500.0,
+        "gdal_xgeo_low_right": 5566500.0,
+        "gdal_ygeo_low_right": 2653500.0}
 
 
 dimensions = {"nx": 1530,
@@ -44,6 +44,7 @@ dimensions = {"nx": 1530,
               "pal_rgb": 3}
 
 NOMINAL_LONGITUDE = 0.0
+NOMINAL_TIME = "2023-01-18T10:30:00Z"
 START_TIME = "2023-01-18T10:39:17Z"
 END_TIME = "2023-01-18T10:42:22Z"
 START_TIME_PPS = "20230118T103917000Z"
@@ -57,6 +58,9 @@ global_attrs = {"source": "NWC/GEO version v2021.1",
 
 global_attrs.update(PROJ)
 
+global_attrs_geo = global_attrs.copy()
+global_attrs_geo["nominal_product_time"] = NOMINAL_TIME
+
 CTTH_PALETTE_MEANINGS = ("0 500 1000 1500")
 
 COT_PALETTE_MEANINGS = ("0 2 5 8 10 13 16 19 23 26 29 33 36 40 43 47 51 55 59 63 68 72 77 81 86 91 96"
@@ -90,7 +94,7 @@ def nwcsaf_geo_ct_filename(tmp_path_factory):
     return create_nwcsaf_geo_ct_file(tmp_path_factory.mktemp("data"))
 
 
-def create_nwcsaf_geo_ct_file(directory, attrs=global_attrs):
+def create_nwcsaf_geo_ct_file(directory, attrs=global_attrs_geo):
     """Create a CT file."""
     filename = directory / "S_NWC_CT_MSG4_MSG-N-VISIR_20230118T103000Z_PLAX.nc"
     with h5netcdf.File(filename, mode="w") as nc_file:
@@ -105,7 +109,7 @@ def create_nwcsaf_geo_ct_file(directory, attrs=global_attrs):
     return filename
 
 
-@pytest.fixture
+@pytest.fixture()
 def nwcsaf_geo_ct_filehandler(nwcsaf_geo_ct_filename):
     """Create a CT filehandler."""
     return NcNWCSAF(nwcsaf_geo_ct_filename, {}, {})
@@ -156,13 +160,13 @@ def create_ctth_file(path, attrs=global_attrs):
     return filename
 
 
-@pytest.fixture
+@pytest.fixture()
 def nwcsaf_pps_cmic_filehandler(nwcsaf_pps_cmic_filename):
     """Create a CMIC filehandler."""
     return NcNWCSAF(nwcsaf_pps_cmic_filename, {}, {"file_key_prefix": "cmic_"})
 
 
-@pytest.fixture
+@pytest.fixture()
 def nwcsaf_pps_ctth_filehandler(nwcsaf_pps_ctth_filename):
     """Create a CMIC filehandler."""
     return NcNWCSAF(nwcsaf_pps_ctth_filename, {}, {})
@@ -218,7 +222,7 @@ def create_ctth_alti_pal_variable_with_fill_value_color(nc_file, var_name):
     var.attrs["_FillValue"] = 65535
 
 
-@pytest.fixture
+@pytest.fixture()
 def nwcsaf_pps_cpp_filehandler(nwcsaf_pps_cpp_filename):
     """Create a CPP filehandler."""
     return NcNWCSAF(nwcsaf_pps_cpp_filename, {}, {"file_key_prefix": "cpp_"})
@@ -227,13 +231,13 @@ def nwcsaf_pps_cpp_filehandler(nwcsaf_pps_cpp_filename):
 @pytest.fixture(scope="session")
 def nwcsaf_old_geo_ct_filename(tmp_path_factory):
     """Create a CT file and return the filename."""
-    attrs = global_attrs.copy()
+    attrs = global_attrs_geo.copy()
     attrs.update(PROJ_KM)
     attrs["time_coverage_start"] = np.array(["2023-01-18T10:39:17Z"], dtype="S20")
     return create_nwcsaf_geo_ct_file(tmp_path_factory.mktemp("data-old"), attrs=attrs)
 
 
-@pytest.fixture
+@pytest.fixture()
 def nwcsaf_old_geo_ct_filehandler(nwcsaf_old_geo_ct_filename):
     """Create a CT filehandler."""
     return NcNWCSAF(nwcsaf_old_geo_ct_filename, {}, {})
@@ -242,19 +246,19 @@ def nwcsaf_old_geo_ct_filehandler(nwcsaf_old_geo_ct_filename):
 class TestNcNWCSAFGeo:
     """Test the NcNWCSAF reader for Geo products."""
 
-    @pytest.mark.parametrize("platform, instrument", [("Metop-B", "avhrr-3"),
-                                                      ("NOAA-20", "viirs"),
-                                                      ("Himawari-8", "ahi"),
-                                                      ("GOES-17", "abi"),
-                                                      ("Meteosat-11", "seviri")])
+    @pytest.mark.parametrize(("platform", "instrument"), [("Metop-B", "avhrr-3"),
+                                                          ("NOAA-20", "viirs"),
+                                                          ("Himawari-8", "ahi"),
+                                                          ("GOES-17", "abi"),
+                                                          ("Meteosat-11", "seviri")])
     def test_sensor_name_platform(self, nwcsaf_geo_ct_filehandler, platform, instrument):
         """Test that the correct sensor name is being set."""
         nwcsaf_geo_ct_filehandler.set_platform_and_sensor(platform_name=platform)
         assert nwcsaf_geo_ct_filehandler.sensor == set([instrument])
         assert nwcsaf_geo_ct_filehandler.sensor_names == set([instrument])
 
-    @pytest.mark.parametrize("platform, instrument", [("GOES16", "abi"),
-                                                      ("MSG4", "seviri")])
+    @pytest.mark.parametrize(("platform", "instrument"), [("GOES16", "abi"),
+                                                          ("MSG4", "seviri")])
     def test_sensor_name_sat_id(self, nwcsaf_geo_ct_filehandler, platform, instrument):
         """Test that the correct sensor name is being set."""
         nwcsaf_geo_ct_filehandler.set_platform_and_sensor(sat_id=platform)
@@ -263,13 +267,13 @@ class TestNcNWCSAFGeo:
 
     def test_get_area_def(self, nwcsaf_geo_ct_filehandler):
         """Test that get_area_def() returns proper area."""
-        dsid = {'name': 'ct'}
+        dsid = {"name": "ct"}
 
         _check_area_def(nwcsaf_geo_ct_filehandler.get_area_def(dsid))
 
     def test_get_area_def_km(self, nwcsaf_old_geo_ct_filehandler):
         """Test that get_area_def() returns proper area when the projection is in km."""
-        dsid = {'name': 'ct'}
+        dsid = {"name": "ct"}
         _check_area_def(nwcsaf_old_geo_ct_filehandler.get_area_def(dsid))
 
     def test_scale_dataset_attr_removal(self, nwcsaf_geo_ct_filehandler):
@@ -277,58 +281,58 @@ class TestNcNWCSAFGeo:
         import numpy as np
         import xarray as xr
 
-        attrs = {'scale_factor': np.array(10),
-                 'add_offset': np.array(20)}
+        attrs = {"scale_factor": np.array(10),
+                 "add_offset": np.array(20)}
         var = xr.DataArray([1, 2, 3], attrs=attrs)
 
-        var = nwcsaf_geo_ct_filehandler.scale_dataset(var, 'dummy')
+        var = nwcsaf_geo_ct_filehandler.scale_dataset(var, "dummy")
         np.testing.assert_allclose(var, [30, 40, 50])
-        assert 'scale_factor' not in var.attrs
-        assert 'add_offset' not in var.attrs
+        assert "scale_factor" not in var.attrs
+        assert "add_offset" not in var.attrs
 
-    @pytest.mark.parametrize("attrs, expected", [({'scale_factor': np.array(1.5),
-                                                   'add_offset': np.array(2.5),
-                                                   '_FillValue': 1},
-                                                  [np.nan, 5.5, 7]),
-                                                 ({'scale_factor': np.array(1.5),
-                                                   'add_offset': np.array(2.5),
-                                                   'valid_min': 1.1},
-                                                  [np.nan, 5.5, 7]),
-                                                 ({'scale_factor': np.array(1.5),
-                                                   'add_offset': np.array(2.5),
-                                                   'valid_max': 2.1},
-                                                  [4, 5.5, np.nan]),
-                                                 ({'scale_factor': np.array(1.5),
-                                                   'add_offset': np.array(2.5),
-                                                   'valid_range': (1.1, 2.1)},
-                                                  [np.nan, 5.5, np.nan])])
+    @pytest.mark.parametrize(("attrs", "expected"), [({"scale_factor": np.array(1.5),
+                                                       "add_offset": np.array(2.5),
+                                                       "_FillValue": 1},
+                                                      [np.nan, 5.5, 7]),
+                                                     ({"scale_factor": np.array(1.5),
+                                                       "add_offset": np.array(2.5),
+                                                       "valid_min": 1.1},
+                                                      [np.nan, 5.5, 7]),
+                                                     ({"scale_factor": np.array(1.5),
+                                                       "add_offset": np.array(2.5),
+                                                       "valid_max": 2.1},
+                                                      [4, 5.5, np.nan]),
+                                                     ({"scale_factor": np.array(1.5),
+                                                       "add_offset": np.array(2.5),
+                                                       "valid_range": (1.1, 2.1)},
+                                                      [np.nan, 5.5, np.nan])])
     def test_scale_dataset_floating(self, nwcsaf_geo_ct_filehandler, attrs, expected):
         """Test the scaling of the dataset with floating point values."""
         var = xr.DataArray([1, 2, 3], attrs=attrs)
-        var = nwcsaf_geo_ct_filehandler.scale_dataset(var, 'dummy')
+        var = nwcsaf_geo_ct_filehandler.scale_dataset(var, "dummy")
         np.testing.assert_allclose(var, expected)
-        assert 'scale_factor' not in var.attrs
-        assert 'add_offset' not in var.attrs
+        assert "scale_factor" not in var.attrs
+        assert "add_offset" not in var.attrs
 
     def test_scale_dataset_floating_nwcsaf_geo_ctth(self, nwcsaf_geo_ct_filehandler):
         """Test the scaling of the dataset with floating point values for CTTH NWCSAF/Geo v2016/v2018."""
-        attrs = {'scale_factor': np.array(1.),
-                 'add_offset': np.array(-2000.),
-                 'valid_range': (0., 27000.)}
+        attrs = {"scale_factor": np.array(1.),
+                 "add_offset": np.array(-2000.),
+                 "valid_range": (0., 27000.)}
         var = xr.DataArray([1, 2, 3], attrs=attrs)
-        var = nwcsaf_geo_ct_filehandler.scale_dataset(var, 'dummy')
+        var = nwcsaf_geo_ct_filehandler.scale_dataset(var, "dummy")
         np.testing.assert_allclose(var, [-1999., -1998., -1997.])
-        assert 'scale_factor' not in var.attrs
-        assert 'add_offset' not in var.attrs
-        np.testing.assert_equal(var.attrs['valid_range'], (-2000., 25000.))
+        assert "scale_factor" not in var.attrs
+        assert "add_offset" not in var.attrs
+        np.testing.assert_equal(var.attrs["valid_range"], (-2000., 25000.))
 
     def test_orbital_parameters_are_correct(self, nwcsaf_geo_ct_filehandler):
         """Test that orbital parameters are present in the dataset attributes."""
-        dsid = {'name': 'ct'}
+        dsid = {"name": "ct"}
         var = nwcsaf_geo_ct_filehandler.get_dataset(dsid, {})
         assert "orbital_parameters" in var.attrs
-        for param in var.attrs['orbital_parameters']:
-            assert isinstance(var.attrs['orbital_parameters'][param], (float, int))
+        for param in var.attrs["orbital_parameters"]:
+            assert isinstance(var.attrs["orbital_parameters"][param], (float, int))
 
         assert var.attrs["orbital_parameters"]["satellite_nominal_altitude"] == NOMINAL_ALTITUDE
         assert var.attrs["orbital_parameters"]["satellite_nominal_longitude"] == NOMINAL_LONGITUDE
@@ -336,14 +340,14 @@ class TestNcNWCSAFGeo:
 
     def test_times_are_in_dataset_attributes(self, nwcsaf_geo_ct_filehandler):
         """Check that start/end times are in the attributes of datasets."""
-        dsid = {'name': 'ct'}
+        dsid = {"name": "ct"}
         var = nwcsaf_geo_ct_filehandler.get_dataset(dsid, {})
         assert "start_time" in var.attrs
         assert "end_time" in var.attrs
 
     def test_start_time(self, nwcsaf_geo_ct_filehandler):
         """Test the start time property."""
-        assert nwcsaf_geo_ct_filehandler.start_time == read_nwcsaf_time(START_TIME)
+        assert nwcsaf_geo_ct_filehandler.start_time == read_nwcsaf_time(NOMINAL_TIME)
 
     def test_end_time(self, nwcsaf_geo_ct_filehandler):
         """Test the end time property."""
@@ -363,29 +367,29 @@ class TestNcNWCSAFPPS:
 
     def test_drop_xycoords(self, nwcsaf_pps_cmic_filehandler):
         """Test the drop of x and y coords."""
-        y_line = xr.DataArray(list(range(5)), dims=('y'), attrs={"long_name": "scan line number"})
-        x_pixel = xr.DataArray(list(range(10)), dims=('x'), attrs={"long_name": "pixel number"})
+        y_line = xr.DataArray(list(range(5)), dims=("y"), attrs={"long_name": "scan line number"})
+        x_pixel = xr.DataArray(list(range(10)), dims=("x"), attrs={"long_name": "pixel number"})
         lat = xr.DataArray(np.ones((5, 10)),
-                           dims=('y', 'x'),
-                           coords={'y': y_line, 'x': x_pixel},
-                           attrs={'name': 'lat',
-                                  'standard_name': 'latitude'})
+                           dims=("y", "x"),
+                           coords={"y": y_line, "x": x_pixel},
+                           attrs={"name": "lat",
+                                  "standard_name": "latitude"})
         lon = xr.DataArray(np.ones((5, 10)),
-                           dims=('y', 'x'),
-                           coords={'y': y_line, 'x': x_pixel},
-                           attrs={'name': 'lon',
-                                  'standard_name': 'longitude'})
+                           dims=("y", "x"),
+                           coords={"y": y_line, "x": x_pixel},
+                           attrs={"name": "lon",
+                                  "standard_name": "longitude"})
         data_array_in = xr.DataArray(np.ones((5, 10)),
                                      attrs={"scale_factor": np.array(0, dtype=float),
                                             "add_offset": np.array(1, dtype=float)},
-                                     dims=('y', 'x'),
-                                     coords={'lon': lon, 'lat': lat, 'y': y_line, 'x': x_pixel})
+                                     dims=("y", "x"),
+                                     coords={"lon": lon, "lat": lat, "y": y_line, "x": x_pixel})
         data_array_out = nwcsaf_pps_cmic_filehandler.drop_xycoords(data_array_in)
-        assert 'y' not in data_array_out.coords
+        assert "y" not in data_array_out.coords
 
     def test_get_dataset_scales_and_offsets(self, nwcsaf_pps_cpp_filehandler):
         """Test that get_dataset() returns scaled and offseted data."""
-        dsid = {'name': 'cpp_cot'}
+        dsid = {"name": "cpp_cot"}
 
         info = dict(name="cpp_cot",
                     file_type="nc_nwcsaf_cpp")
@@ -395,7 +399,7 @@ class TestNcNWCSAFPPS:
 
     def test_get_dataset_scales_and_offsets_palette_meanings_using_other_dataset(self, nwcsaf_pps_cpp_filehandler):
         """Test that get_dataset() returns scaled palette_meanings with another dataset as scaling source."""
-        dsid = {'name': 'cpp_cot_pal'}
+        dsid = {"name": "cpp_cot_pal"}
 
         info = dict(name="cpp_cot_pal",
                     file_type="nc_nwcsaf_cpp",
@@ -407,7 +411,7 @@ class TestNcNWCSAFPPS:
 
     def test_get_palette_fill_value_color_added(self, nwcsaf_pps_ctth_filehandler):
         """Test that get_dataset() returns scaled palette_meanings with fill_value_color added."""
-        dsid = {'name': 'ctth_alti_pal'}
+        dsid = {"name": "ctth_alti_pal"}
 
         info = dict(name="ctth_alti_pal",
                     file_type="nc_nwcsaf_ctth",
@@ -420,7 +424,7 @@ class TestNcNWCSAFPPS:
 
     def test_get_dataset_raises_when_dataset_missing(self, nwcsaf_pps_cpp_filehandler):
         """Test that get_dataset() raises an error when the requested dataset is missing."""
-        dsid = {'name': 'cpp_phase'}
+        dsid = {"name": "cpp_phase"}
         info = dict(name="cpp_phase",
                     file_type="nc_nwcsaf_cpp")
         with pytest.raises(KeyError):
@@ -428,8 +432,8 @@ class TestNcNWCSAFPPS:
 
     def test_get_dataset_uses_file_key_if_present(self, nwcsaf_pps_cmic_filehandler, nwcsaf_pps_cpp_filehandler):
         """Test that get_dataset() uses a file_key if present."""
-        dsid_cpp = {'name': 'cpp_cot'}
-        dsid_cmic = {'name': 'cmic_cot'}
+        dsid_cpp = {"name": "cpp_cot"}
+        dsid_cmic = {"name": "cmic_cot"}
 
         file_key = "cmic_cot"
 
@@ -449,17 +453,17 @@ class TestNcNWCSAFPPS:
 
     def test_get_dataset_can_handle_file_key_list(self, nwcsaf_pps_cmic_filehandler, nwcsaf_pps_cpp_filehandler):
         """Test that get_dataset() can handle a list of file_keys."""
-        dsid_cpp = {'name': 'cpp_reff'}
-        dsid_cmic = {'name': 'cmic_cre'}
+        dsid_cpp = {"name": "cpp_reff"}
+        dsid_cmic = {"name": "cmic_cre"}
 
         info_cpp = dict(name="cmic_reff",
-                        file_key=['reff', 'cre'],
+                        file_key=["reff", "cre"],
                         file_type="nc_nwcsaf_cpp")
 
         res_cpp = nwcsaf_pps_cpp_filehandler.get_dataset(dsid_cpp, info_cpp)
 
         info_cmic = dict(name="cmic_reff",
-                         file_key=['reff', 'cre'],
+                         file_key=["reff", "cre"],
                          file_type="nc_nwcsaf_cpp")
 
         res_cmic = nwcsaf_pps_cmic_filehandler.get_dataset(dsid_cmic, info_cmic)
@@ -471,8 +475,8 @@ class TestNcNWCSAFFileKeyPrefix:
 
     def test_get_dataset_uses_file_key_prefix(self, nwcsaf_pps_cmic_filehandler):
         """Test that get_dataset() uses a file_key_prefix."""
-        dsid_cpp = {'name': 'cpp_cot'}
-        dsid_cmic = {'name': 'cmic_cot'}
+        dsid_cpp = {"name": "cpp_cot"}
+        dsid_cmic = {"name": "cmic_cot"}
 
         file_key = "cot"
 
@@ -490,7 +494,7 @@ class TestNcNWCSAFFileKeyPrefix:
 
     def test_get_dataset_scales_and_offsets_palette_meanings_using_other_dataset(self, nwcsaf_pps_cmic_filehandler):
         """Test that get_dataset() returns scaled palette_meanings using another dataset as scaling source."""
-        dsid = {'name': 'cpp_cot_pal'}
+        dsid = {"name": "cpp_cot_pal"}
 
         info = dict(name="cpp_cot_pal",
                     file_key="cot_pal",
@@ -503,11 +507,11 @@ class TestNcNWCSAFFileKeyPrefix:
 
 
 def _check_area_def(area_definition):
-    correct_h = float(PROJ['gdal_projection'].split('+h=')[-1])
-    correct_a = float(PROJ['gdal_projection'].split('+a=')[-1].split()[0])
-    assert area_definition.proj_dict['h'] == correct_h
-    assert area_definition.proj_dict['a'] == correct_a
-    assert area_definition.proj_dict['units'] == 'm'
+    correct_h = float(PROJ["gdal_projection"].split("+h=")[-1])
+    correct_a = float(PROJ["gdal_projection"].split("+a=")[-1].split()[0])
+    assert area_definition.proj_dict["h"] == correct_h
+    assert area_definition.proj_dict["a"] == correct_a
+    assert area_definition.proj_dict["units"] == "m"
     correct_extent = (PROJ["gdal_xgeo_up_left"],
                       PROJ["gdal_ygeo_low_right"],
                       PROJ["gdal_xgeo_low_right"],
