@@ -24,7 +24,7 @@ import unittest.mock as mock
 class TestOLCIReader(unittest.TestCase):
     """Test various olci_nc filehandlers."""
 
-    @mock.patch('xarray.open_dataset')
+    @mock.patch("xarray.open_dataset")
     def test_instantiate(self, mocked_dataset):
         """Test initialization of file handlers."""
         import xarray as xr
@@ -34,66 +34,66 @@ class TestOLCIReader(unittest.TestCase):
 
         cal_data = xr.Dataset(
             {
-                'solar_flux': (('bands'), [0, 1, 2]),
-                'detector_index': (('bands'), [0, 1, 2]),
+                "solar_flux": (("bands"), [0, 1, 2]),
+                "detector_index": (("bands"), [0, 1, 2]),
             },
-            {'bands': [0, 1, 2], },
+            {"bands": [0, 1, 2], },
         )
 
-        ds_id = make_dataid(name='Oa01', calibration='reflectance')
-        ds_id2 = make_dataid(name='wsqf', calibration='reflectance')
-        filename_info = {'mission_id': 'S3A', 'dataset_name': 'Oa01', 'start_time': 0, 'end_time': 0}
+        ds_id = make_dataid(name="Oa01", calibration="reflectance")
+        ds_id2 = make_dataid(name="wsqf", calibration="reflectance")
+        filename_info = {"mission_id": "S3A", "dataset_name": "Oa01", "start_time": 0, "end_time": 0}
 
-        test = NCOLCIBase('somedir/somefile.nc', filename_info, 'c')
+        test = NCOLCIBase("somedir/somefile.nc", filename_info, "c")
         test.get_dataset(ds_id, filename_info)
         mocked_dataset.assert_called()
         mocked_dataset.reset_mock()
 
-        test = NCOLCICal('somedir/somefile.nc', filename_info, 'c')
+        test = NCOLCICal("somedir/somefile.nc", filename_info, "c")
         test.get_dataset(ds_id, filename_info)
         mocked_dataset.assert_called()
         mocked_dataset.reset_mock()
 
-        test = NCOLCIGeo('somedir/somefile.nc', filename_info, 'c')
+        test = NCOLCIGeo("somedir/somefile.nc", filename_info, "c")
         test.get_dataset(ds_id, filename_info)
         mocked_dataset.assert_called()
         mocked_dataset.reset_mock()
 
-        test = NCOLCIChannelBase('somedir/somefile.nc', filename_info, 'c')
+        test = NCOLCIChannelBase("somedir/somefile.nc", filename_info, "c")
         test.get_dataset(ds_id, filename_info)
         mocked_dataset.assert_called()
         mocked_dataset.reset_mock()
 
         cal = mock.Mock()
         cal.nc = cal_data
-        test = NCOLCI1B('somedir/somefile.nc', filename_info, 'c', cal)
+        test = NCOLCI1B("somedir/somefile.nc", filename_info, "c", cal)
         test.get_dataset(ds_id, filename_info)
         mocked_dataset.assert_called()
         mocked_dataset.reset_mock()
 
-        test = NCOLCI2('somedir/somefile.nc', filename_info, 'c')
-        test.get_dataset(ds_id, {'nc_key': 'the_key'})
-        test.get_dataset(ds_id2, {'nc_key': 'the_key'})
+        test = NCOLCI2("somedir/somefile.nc", filename_info, "c")
+        test.get_dataset(ds_id, {"nc_key": "the_key"})
+        test.get_dataset(ds_id2, {"nc_key": "the_key"})
         mocked_dataset.assert_called()
         mocked_dataset.reset_mock()
 
-    @mock.patch('xarray.open_dataset')
+    @mock.patch("xarray.open_dataset")
     def test_open_file_objects(self, mocked_open_dataset):
         """Test initialization of file handlers."""
         from satpy.readers.olci_nc import NCOLCIBase
-        filename_info = {'mission_id': 'S3A', 'dataset_name': 'Oa01', 'start_time': 0, 'end_time': 0}
+        filename_info = {"mission_id": "S3A", "dataset_name": "Oa01", "start_time": 0, "end_time": 0}
 
         open_file = mock.MagicMock()
 
-        file_handler = NCOLCIBase(open_file, filename_info, 'c')
+        file_handler = NCOLCIBase(open_file, filename_info, "c")
         #  deepcode ignore W0104: This is a property that is actually a function call.
         file_handler.nc  # pylint: disable=W0104
         mocked_open_dataset.assert_called()
         open_file.open.assert_called()
         assert (open_file.open.return_value in mocked_open_dataset.call_args[0] or
-                open_file.open.return_value == mocked_open_dataset.call_args[1].get('filename_or_obj'))
+                open_file.open.return_value == mocked_open_dataset.call_args[1].get("filename_or_obj"))
 
-    @mock.patch('xarray.open_dataset')
+    @mock.patch("xarray.open_dataset")
     def test_get_mask(self, mocked_dataset):
         """Test reading datasets."""
         import numpy as np
@@ -101,15 +101,15 @@ class TestOLCIReader(unittest.TestCase):
 
         from satpy.readers.olci_nc import NCOLCI2
         from satpy.tests.utils import make_dataid
-        mocked_dataset.return_value = xr.Dataset({'mask': (['rows', 'columns'],
+        mocked_dataset.return_value = xr.Dataset({"mask": (["rows", "columns"],
                                                            np.array([1 << x for x in range(30)]).reshape(5, 6))},
-                                                 coords={'rows': np.arange(5),
-                                                         'columns': np.arange(6)})
-        ds_id = make_dataid(name='mask')
-        filename_info = {'mission_id': 'S3A', 'dataset_name': 'mask', 'start_time': 0, 'end_time': 0}
-        test = NCOLCI2('somedir/somefile.nc', filename_info, 'c')
-        res = test.get_dataset(ds_id, {'nc_key': 'mask'})
-        self.assertEqual(res.dtype, np.dtype('bool'))
+                                                 coords={"rows": np.arange(5),
+                                                         "columns": np.arange(6)})
+        ds_id = make_dataid(name="mask")
+        filename_info = {"mission_id": "S3A", "dataset_name": "mask", "start_time": 0, "end_time": 0}
+        test = NCOLCI2("somedir/somefile.nc", filename_info, "c")
+        res = test.get_dataset(ds_id, {"nc_key": "mask"})
+        assert res.dtype == np.dtype("bool")
         expected = np.array([[True, False, True, True, True, True],
                              [False, False, True, True, False, False],
                              [False, False, False, False, False, True],
@@ -117,7 +117,7 @@ class TestOLCIReader(unittest.TestCase):
                              [True, False, False, True, False, False]])
         np.testing.assert_array_equal(res.values, expected)
 
-    @mock.patch('xarray.open_dataset')
+    @mock.patch("xarray.open_dataset")
     def test_get_mask_with_alternative_items(self, mocked_dataset):
         """Test reading datasets."""
         import numpy as np
@@ -125,19 +125,19 @@ class TestOLCIReader(unittest.TestCase):
 
         from satpy.readers.olci_nc import NCOLCI2
         from satpy.tests.utils import make_dataid
-        mocked_dataset.return_value = xr.Dataset({'mask': (['rows', 'columns'],
+        mocked_dataset.return_value = xr.Dataset({"mask": (["rows", "columns"],
                                                            np.array([1 << x for x in range(30)]).reshape(5, 6))},
-                                                 coords={'rows': np.arange(5),
-                                                         'columns': np.arange(6)})
-        ds_id = make_dataid(name='mask')
-        filename_info = {'mission_id': 'S3A', 'dataset_name': 'mask', 'start_time': 0, 'end_time': 0}
-        test = NCOLCI2('somedir/somefile.nc', filename_info, 'c', mask_items=["INVALID"])
-        res = test.get_dataset(ds_id, {'nc_key': 'mask'})
-        self.assertEqual(res.dtype, np.dtype('bool'))
+                                                 coords={"rows": np.arange(5),
+                                                         "columns": np.arange(6)})
+        ds_id = make_dataid(name="mask")
+        filename_info = {"mission_id": "S3A", "dataset_name": "mask", "start_time": 0, "end_time": 0}
+        test = NCOLCI2("somedir/somefile.nc", filename_info, "c", mask_items=["INVALID"])
+        res = test.get_dataset(ds_id, {"nc_key": "mask"})
+        assert res.dtype == np.dtype("bool")
         expected = np.array([True] + [False] * 29).reshape(5, 6)
         np.testing.assert_array_equal(res.values, expected)
 
-    @mock.patch('xarray.open_dataset')
+    @mock.patch("xarray.open_dataset")
     def test_olci_angles(self, mocked_dataset):
         """Test reading datasets."""
         import numpy as np
@@ -146,31 +146,31 @@ class TestOLCIReader(unittest.TestCase):
         from satpy.readers.olci_nc import NCOLCIAngles
         from satpy.tests.utils import make_dataid
         attr_dict = {
-            'ac_subsampling_factor': 1,
-            'al_subsampling_factor': 2,
+            "ac_subsampling_factor": 1,
+            "al_subsampling_factor": 2,
         }
-        mocked_dataset.return_value = xr.Dataset({'SAA': (['tie_rows', 'tie_columns'],
+        mocked_dataset.return_value = xr.Dataset({"SAA": (["tie_rows", "tie_columns"],
                                                           np.array([1 << x for x in range(30)]).reshape(5, 6)),
-                                                  'SZA': (['tie_rows', 'tie_columns'],
+                                                  "SZA": (["tie_rows", "tie_columns"],
                                                           np.array([1 << x for x in range(30)]).reshape(5, 6)),
-                                                  'OAA': (['tie_rows', 'tie_columns'],
+                                                  "OAA": (["tie_rows", "tie_columns"],
                                                           np.array([1 << x for x in range(30)]).reshape(5, 6)),
-                                                  'OZA': (['tie_rows', 'tie_columns'],
+                                                  "OZA": (["tie_rows", "tie_columns"],
                                                           np.array([1 << x for x in range(30)]).reshape(5, 6))},
-                                                 coords={'rows': np.arange(5),
-                                                         'columns': np.arange(6)},
+                                                 coords={"rows": np.arange(5),
+                                                         "columns": np.arange(6)},
                                                  attrs=attr_dict)
-        filename_info = {'mission_id': 'S3A', 'dataset_name': 'Oa01', 'start_time': 0, 'end_time': 0}
+        filename_info = {"mission_id": "S3A", "dataset_name": "Oa01", "start_time": 0, "end_time": 0}
 
-        ds_id = make_dataid(name='solar_azimuth_angle')
-        ds_id2 = make_dataid(name='satellite_zenith_angle')
-        test = NCOLCIAngles('somedir/somefile.nc', filename_info, 'c')
+        ds_id = make_dataid(name="solar_azimuth_angle")
+        ds_id2 = make_dataid(name="satellite_zenith_angle")
+        test = NCOLCIAngles("somedir/somefile.nc", filename_info, "c")
         test.get_dataset(ds_id, filename_info)
         test.get_dataset(ds_id2, filename_info)
         mocked_dataset.assert_called()
         mocked_dataset.reset_mock()
 
-    @mock.patch('xarray.open_dataset')
+    @mock.patch("xarray.open_dataset")
     def test_olci_meteo(self, mocked_dataset):
         """Test reading datasets."""
         import numpy as np
@@ -179,26 +179,26 @@ class TestOLCIReader(unittest.TestCase):
         from satpy.readers.olci_nc import NCOLCIMeteo
         from satpy.tests.utils import make_dataid
         attr_dict = {
-            'ac_subsampling_factor': 1,
-            'al_subsampling_factor': 2,
+            "ac_subsampling_factor": 1,
+            "al_subsampling_factor": 2,
         }
-        data = {'humidity': (['tie_rows', 'tie_columns'],
+        data = {"humidity": (["tie_rows", "tie_columns"],
                              np.array([1 << x for x in range(30)]).reshape(5, 6)),
-                'total_ozone': (['tie_rows', 'tie_columns'],
+                "total_ozone": (["tie_rows", "tie_columns"],
                                 np.array([1 << x for x in range(30)]).reshape(5, 6)),
-                'sea_level_pressure': (['tie_rows', 'tie_columns'],
+                "sea_level_pressure": (["tie_rows", "tie_columns"],
                                        np.array([1 << x for x in range(30)]).reshape(5, 6)),
-                'total_columnar_water_vapour': (['tie_rows', 'tie_columns'],
+                "total_columnar_water_vapour": (["tie_rows", "tie_columns"],
                                                 np.array([1 << x for x in range(30)]).reshape(5, 6))}
         mocked_dataset.return_value = xr.Dataset(data,
-                                                 coords={'rows': np.arange(5),
-                                                         'columns': np.arange(6)},
+                                                 coords={"rows": np.arange(5),
+                                                         "columns": np.arange(6)},
                                                  attrs=attr_dict)
-        filename_info = {'mission_id': 'S3A', 'dataset_name': 'humidity', 'start_time': 0, 'end_time': 0}
+        filename_info = {"mission_id": "S3A", "dataset_name": "humidity", "start_time": 0, "end_time": 0}
 
-        ds_id = make_dataid(name='humidity')
-        ds_id2 = make_dataid(name='total_ozone')
-        test = NCOLCIMeteo('somedir/somefile.nc', filename_info, 'c')
+        ds_id = make_dataid(name="humidity")
+        ds_id2 = make_dataid(name="total_ozone")
+        test = NCOLCIMeteo("somedir/somefile.nc", filename_info, "c")
         test.get_dataset(ds_id, filename_info)
         test.get_dataset(ds_id2, filename_info)
         mocked_dataset.assert_called()
@@ -213,28 +213,28 @@ class TestOLCIReader(unittest.TestCase):
         from satpy.readers.olci_nc import NCOLCI2
         from satpy.tests.utils import make_dataid
         attr_dict = {
-            'ac_subsampling_factor': 64,
-            'al_subsampling_factor': 1,
+            "ac_subsampling_factor": 64,
+            "al_subsampling_factor": 1,
         }
-        data = {'CHL_NN': (['rows', 'columns'],
+        data = {"CHL_NN": (["rows", "columns"],
                            np.arange(30).reshape(5, 6).astype(float),
                            {"units": "lg(re mg.m-3)"})}
         mocked_dataset.return_value = xr.Dataset(data,
-                                                 coords={'rows': np.arange(5),
-                                                         'columns': np.arange(6)},
+                                                 coords={"rows": np.arange(5),
+                                                         "columns": np.arange(6)},
                                                  attrs=attr_dict)
-        ds_info = {'name': 'chl_nn', 'sensor': 'olci', 'resolution': 300,
-                   'standard_name': 'algal_pigment_concentration', 'units': 'lg(re mg.m-3)',
-                   'coordinates': ('longitude', 'latitude'), 'file_type': 'esa_l2_chl_nn', 'nc_key': 'CHL_NN',
-                   'modifiers': ()}
-        filename_info = {'mission_id': 'S3A', 'datatype_id': 'WFR',
-                         'start_time': datetime.datetime(2019, 9, 24, 9, 29, 39),
-                         'end_time': datetime.datetime(2019, 9, 24, 9, 32, 39),
-                         'creation_time': datetime.datetime(2019, 9, 24, 11, 40, 26), 'duration': 179, 'cycle': 49,
-                         'relative_orbit': 307, 'frame': 1800, 'centre': 'MAR', 'mode': 'O', 'timeliness': 'NR',
-                         'collection': '002'}
-        ds_id = make_dataid(name='chl_nn')
-        file_handler = NCOLCI2('somedir/somefile.nc', filename_info, None, unlog=True)
+        ds_info = {"name": "chl_nn", "sensor": "olci", "resolution": 300,
+                   "standard_name": "algal_pigment_concentration", "units": "lg(re mg.m-3)",
+                   "coordinates": ("longitude", "latitude"), "file_type": "esa_l2_chl_nn", "nc_key": "CHL_NN",
+                   "modifiers": ()}
+        filename_info = {"mission_id": "S3A", "datatype_id": "WFR",
+                         "start_time": datetime.datetime(2019, 9, 24, 9, 29, 39),
+                         "end_time": datetime.datetime(2019, 9, 24, 9, 32, 39),
+                         "creation_time": datetime.datetime(2019, 9, 24, 11, 40, 26), "duration": 179, "cycle": 49,
+                         "relative_orbit": 307, "frame": 1800, "centre": "MAR", "mode": "O", "timeliness": "NR",
+                         "collection": "002"}
+        ds_id = make_dataid(name="chl_nn")
+        file_handler = NCOLCI2("somedir/somefile.nc", filename_info, None, unlog=True)
         res = file_handler.get_dataset(ds_id, ds_info)
 
         assert res.attrs["units"] == "mg.m-3"
@@ -251,13 +251,13 @@ class TestBitFlags(unittest.TestCase):
         import numpy as np
 
         from satpy.readers.olci_nc import BitFlags
-        flag_list = ['INVALID', 'WATER', 'LAND', 'CLOUD', 'SNOW_ICE',
-                     'INLAND_WATER', 'TIDAL', 'COSMETIC', 'SUSPECT', 'HISOLZEN',
-                     'SATURATED', 'MEGLINT', 'HIGHGLINT', 'WHITECAPS',
-                     'ADJAC', 'WV_FAIL', 'PAR_FAIL', 'AC_FAIL', 'OC4ME_FAIL',
-                     'OCNN_FAIL', 'Extra_1', 'KDM_FAIL', 'Extra_2',
-                     'CLOUD_AMBIGUOUS', 'CLOUD_MARGIN', 'BPAC_ON',
-                     'WHITE_SCATT', 'LOWRW', 'HIGHRW']
+        flag_list = ["INVALID", "WATER", "LAND", "CLOUD", "SNOW_ICE",
+                     "INLAND_WATER", "TIDAL", "COSMETIC", "SUSPECT", "HISOLZEN",
+                     "SATURATED", "MEGLINT", "HIGHGLINT", "WHITECAPS",
+                     "ADJAC", "WV_FAIL", "PAR_FAIL", "AC_FAIL", "OC4ME_FAIL",
+                     "OCNN_FAIL", "Extra_1", "KDM_FAIL", "Extra_2",
+                     "CLOUD_AMBIGUOUS", "CLOUD_MARGIN", "BPAC_ON",
+                     "WHITE_SCATT", "LOWRW", "HIGHRW"]
 
         bits = np.array([1 << x for x in range(len(flag_list))])
 
@@ -273,4 +273,4 @@ class TestBitFlags(unittest.TestCase):
                              False, False, False,  True, False,  True, False,
                              False, False,  True,  True, False, False, True,
                              False])
-        self.assertTrue(all(mask == expected))
+        assert all(mask == expected)
