@@ -112,13 +112,13 @@ def _create_seadas_chlor_a_hdf4_file(full_path, mission, sensor):
 
 
 def _add_variable_to_hdf4_file(h, var_name, var_info):
-    v = h.create(var_name, var_info['type'], var_info['data'].shape)
-    v[:] = var_info['data']
-    for dim_count, dimension_name in enumerate(var_info['dim_labels']):
+    v = h.create(var_name, var_info["type"], var_info["data"].shape)
+    v[:] = var_info["data"]
+    for dim_count, dimension_name in enumerate(var_info["dim_labels"]):
         v.dim(dim_count).setname(dimension_name)
-    if var_info.get('fill_value'):
-        v.setfillvalue(var_info['fill_value'])
-    for attr_key, attr_val in var_info['attrs'].items():
+    if var_info.get("fill_value"):
+        v.setfillvalue(var_info["fill_value"])
+    for attr_key, attr_val in var_info["attrs"].items():
         setattr(v, attr_key, attr_val)
 
 
@@ -196,8 +196,8 @@ def _create_seadas_chlor_a_netcdf_file(full_path, mission, sensor):
 def _add_variable_to_netcdf_file(nc, var_name, var_info):
     v = nc.createVariable(var_name, var_info["data"].dtype.str[1:], dimensions=var_info["dim_labels"],
                           fill_value=var_info.get("fill_value"))
-    v[:] = var_info['data']
-    for attr_key, attr_val in var_info['attrs'].items():
+    v[:] = var_info["data"]
+    for attr_key, attr_val in var_info["attrs"].items():
         setattr(v, attr_key, attr_val)
 
 
@@ -206,7 +206,7 @@ class TestSEADAS:
 
     def test_available_reader(self):
         """Test that SEADAS L2 reader is available."""
-        assert 'seadas_l2' in available_readers()
+        assert "seadas_l2" in available_readers()
 
     @pytest.mark.parametrize(
         "input_files",
@@ -217,10 +217,10 @@ class TestSEADAS:
         ])
     def test_scene_available_datasets(self, input_files):
         """Test that datasets are available."""
-        scene = Scene(reader='seadas_l2', filenames=input_files)
+        scene = Scene(reader="seadas_l2", filenames=input_files)
         available_datasets = scene.all_dataset_names()
         assert len(available_datasets) > 0
-        assert 'chlor_a' in available_datasets
+        assert "chlor_a" in available_datasets
 
     @pytest.mark.parametrize(
         ("input_files", "exp_plat", "exp_sensor", "exp_rps"),
@@ -234,13 +234,13 @@ class TestSEADAS:
     def test_load_chlor_a(self, input_files, exp_plat, exp_sensor, exp_rps, apply_quality_flags):
         """Test that we can load 'chlor_a'."""
         reader_kwargs = {"apply_quality_flags": apply_quality_flags}
-        scene = Scene(reader='seadas_l2', filenames=input_files, reader_kwargs=reader_kwargs)
-        scene.load(['chlor_a'])
-        data_arr = scene['chlor_a']
+        scene = Scene(reader="seadas_l2", filenames=input_files, reader_kwargs=reader_kwargs)
+        scene.load(["chlor_a"])
+        data_arr = scene["chlor_a"]
         assert data_arr.dims == ("y", "x")
-        assert data_arr.attrs['platform_name'] == exp_plat
-        assert data_arr.attrs['sensor'] == exp_sensor
-        assert data_arr.attrs['units'] == 'mg m^-3'
+        assert data_arr.attrs["platform_name"] == exp_plat
+        assert data_arr.attrs["sensor"] == exp_sensor
+        assert data_arr.attrs["units"] == "mg m^-3"
         assert data_arr.dtype.type == np.float32
         assert isinstance(data_arr.attrs["area"], SwathDefinition)
         assert data_arr.attrs["rows_per_scan"] == exp_rps
