@@ -33,7 +33,7 @@ class TestCreflUtils(unittest.TestCase):
             0.0043149700000000004, 0.0037296, 0.014107995000000002, 0.052349,
         )
         sphalb, rhoray, TtotraytH2O, tOG = atm_vars()
-        self.assertLess(abs(np.array(sphalb) - 0.045213532544630494), 1e-10)
-        self.assertLess(abs(rhoray - 2.2030281148621356), 1e-10)
-        self.assertLess(abs(TtotraytH2O - 0.30309880915889087), 1e-10)
-        self.assertLess(abs(tOG - 0.5969089524560548), 1e-10)
+        assert abs(np.array(sphalb) - 0.045213532544630494) < 1e-10
+        assert abs(rhoray - 2.2030281148621356) < 1e-10
+        assert abs(TtotraytH2O - 0.30309880915889087) < 1e-10
+        assert abs(tOG - 0.5969089524560548) < 1e-10
