@@ -30,43 +30,43 @@ from pytest_lazyfixture import lazy_fixture
 
 def _sunz_area_def():
     """Get fake area for testing sunz generation."""
-    area = AreaDefinition('test', 'test', 'test',
-                          {'proj': 'merc'}, 2, 2,
+    area = AreaDefinition("test", "test", "test",
+                          {"proj": "merc"}, 2, 2,
                           (-2000, -2000, 2000, 2000))
     return area
 
 
 def _sunz_bigger_area_def():
     """Get area that is twice the size of 'sunz_area_def'."""
-    bigger_area = AreaDefinition('test', 'test', 'test',
-                                 {'proj': 'merc'}, 4, 4,
+    bigger_area = AreaDefinition("test", "test", "test",
+                                 {"proj": "merc"}, 4, 4,
                                  (-2000, -2000, 2000, 2000))
     return bigger_area
 
 
 def _sunz_stacked_area_def():
     """Get fake stacked area for testing sunz generation."""
-    area1 = AreaDefinition('test', 'test', 'test',
-                           {'proj': 'merc'}, 2, 1,
+    area1 = AreaDefinition("test", "test", "test",
+                           {"proj": "merc"}, 2, 1,
                            (-2000, 0, 2000, 2000))
-    area2 = AreaDefinition('test', 'test', 'test',
-                           {'proj': 'merc'}, 2, 1,
+    area2 = AreaDefinition("test", "test", "test",
+                           {"proj": "merc"}, 2, 1,
                            (-2000, -2000, 2000, 0))
     return StackedAreaDefinition(area1, area2)
 
 
 def _shared_sunz_attrs(area_def):
-    attrs = {'area': area_def,
-             'start_time': datetime(2018, 1, 1, 18),
-             'modifiers': tuple(),
-             'name': 'test_vis'}
+    attrs = {"area": area_def,
+             "start_time": datetime(2018, 1, 1, 18),
+             "modifiers": tuple(),
+             "name": "test_vis"}
     return attrs
 
 
 def _get_ds1(attrs):
     ds1 = xr.DataArray(da.ones((2, 2), chunks=2, dtype=np.float64),
-                       attrs=attrs, dims=('y', 'x'),
-                       coords={'y': [0, 1], 'x': [0, 1]})
+                       attrs=attrs, dims=("y", "x"),
+                       coords={"y": [0, 1], "x": [0, 1]})
     return ds1
 
 
@@ -89,8 +89,8 @@ def sunz_ds2():
     """Generate larger fake dataset for sunz tests."""
     attrs = _shared_sunz_attrs(_sunz_bigger_area_def())
     ds2 = xr.DataArray(da.ones((4, 4), chunks=2, dtype=np.float64),
-                       attrs=attrs, dims=('y', 'x'),
-                       coords={'y': [0, 0.5, 1, 1.5], 'x': [0, 0.5, 1, 1.5]})
+                       attrs=attrs, dims=("y", "x"),
+                       coords={"y": [0, 0.5, 1, 1.5], "x": [0, 0.5, 1, 1.5]})
     return ds2
 
 
@@ -100,9 +100,9 @@ def sunz_sza():
     sza = xr.DataArray(
         np.rad2deg(np.arccos(da.from_array([[0.0149581333, 0.0146694376], [0.0150812684, 0.0147925727]],
                                            chunks=2))),
-        attrs={'area': _sunz_area_def()},
-        dims=('y', 'x'),
-        coords={'y': [0, 1], 'x': [0, 1]},
+        attrs={"area": _sunz_area_def()},
+        dims=("y", "x"),
+        coords={"y": [0, 1], "x": [0, 1]},
     )
     return sza
 
@@ -117,49 +117,51 @@ class TestSunZenithCorrector:
 
         if as_32bit:
             sunz_ds1 = sunz_ds1.astype(np.float32)
-        comp = SunZenithCorrector(name='sza_test', modifiers=tuple())
-        res = comp((sunz_ds1,), test_attr='test')
-        np.testing.assert_allclose(res.values, np.array([[22.401667, 22.31777], [22.437503, 22.353533]]))
-        assert 'y' in res.coords
-        assert 'x' in res.coords
-        ds1 = sunz_ds1.copy().drop_vars(('y', 'x'))
-        res = comp((ds1,), test_attr='test')
+        comp = SunZenithCorrector(name="sza_test", modifiers=tuple())
+        res = comp((sunz_ds1,), test_attr="test")
+        np.testing.assert_allclose(res.values, np.array([[22.401667, 22.31777], [22.437503, 22.353533]]),
+                                   rtol=1e-6)
+        assert "y" in res.coords
+        assert "x" in res.coords
+        ds1 = sunz_ds1.copy().drop_vars(("y", "x"))
+        res = comp((ds1,), test_attr="test")
         res_np = res.compute()
-        np.testing.assert_allclose(res_np.values, np.array([[22.401667, 22.31777], [22.437503, 22.353533]]))
+        np.testing.assert_allclose(res_np.values, np.array([[22.401667, 22.31777], [22.437503, 22.353533]]),
+                                   rtol=1e-6)
         assert res.dtype == res_np.dtype
-        assert 'y' not in res.coords
-        assert 'x' not in res.coords
+        assert "y" not in res.coords
+        assert "x" not in res.coords
 
     def test_basic_lims_not_provided(self, sunz_ds1):
         """Test custom limits when SZA isn't provided."""
         from satpy.modifiers.geometry import SunZenithCorrector
-        comp = SunZenithCorrector(name='sza_test', modifiers=tuple(), correction_limit=90)
-        res = comp((sunz_ds1,), test_attr='test')
+        comp = SunZenithCorrector(name="sza_test", modifiers=tuple(), correction_limit=90)
+        res = comp((sunz_ds1,), test_attr="test")
         np.testing.assert_allclose(res.values, np.array([[66.853262, 68.168939], [66.30742, 67.601493]]))
 
     @pytest.mark.parametrize("data_arr", [lazy_fixture("sunz_ds1"), lazy_fixture("sunz_ds1_stacked")])
     def test_basic_default_provided(self, data_arr, sunz_sza):
         """Test default limits when SZA is provided."""
         from satpy.modifiers.geometry import SunZenithCorrector
-        comp = SunZenithCorrector(name='sza_test', modifiers=tuple())
-        res = comp((data_arr, sunz_sza), test_attr='test')
+        comp = SunZenithCorrector(name="sza_test", modifiers=tuple())
+        res = comp((data_arr, sunz_sza), test_attr="test")
         np.testing.assert_allclose(res.values, np.array([[22.401667, 22.31777], [22.437503, 22.353533]]))
 
     @pytest.mark.parametrize("data_arr", [lazy_fixture("sunz_ds1"), lazy_fixture("sunz_ds1_stacked")])
     def test_basic_lims_provided(self, data_arr, sunz_sza):
         """Test custom limits when SZA is provided."""
         from satpy.modifiers.geometry import SunZenithCorrector
-        comp = SunZenithCorrector(name='sza_test', modifiers=tuple(), correction_limit=90)
-        res = comp((data_arr, sunz_sza), test_attr='test')
+        comp = SunZenithCorrector(name="sza_test", modifiers=tuple(), correction_limit=90)
+        res = comp((data_arr, sunz_sza), test_attr="test")
         np.testing.assert_allclose(res.values, np.array([[66.853262, 68.168939], [66.30742, 67.601493]]))
 
     def test_imcompatible_areas(self, sunz_ds2, sunz_sza):
         """Test sunz correction on incompatible areas."""
         from satpy.composites import IncompatibleAreas
         from satpy.modifiers.geometry import SunZenithCorrector
-        comp = SunZenithCorrector(name='sza_test', modifiers=tuple(), correction_limit=90)
+        comp = SunZenithCorrector(name="sza_test", modifiers=tuple(), correction_limit=90)
         with pytest.raises(IncompatibleAreas):
-            comp((sunz_ds2, sunz_sza), test_attr='test')
+            comp((sunz_ds2, sunz_sza), test_attr="test")
 
 
 class TestSunZenithReducer:
@@ -169,20 +171,20 @@ class TestSunZenithReducer:
     def setup_class(cls):
         """Initialze SunZenithReducer classes that shall be tested."""
         from satpy.modifiers.geometry import SunZenithReducer
-        cls.default = SunZenithReducer(name='sza_reduction_test_default', modifiers=tuple())
-        cls.custom = SunZenithReducer(name='sza_reduction_test_custom', modifiers=tuple(),
+        cls.default = SunZenithReducer(name="sza_reduction_test_default", modifiers=tuple())
+        cls.custom = SunZenithReducer(name="sza_reduction_test_custom", modifiers=tuple(),
                                       correction_limit=70, max_sza=95, strength=3.0)
 
     def test_default_settings(self, sunz_ds1, sunz_sza):
         """Test default settings with sza data available."""
-        res = self.default((sunz_ds1, sunz_sza), test_attr='test')
+        res = self.default((sunz_ds1, sunz_sza), test_attr="test")
         np.testing.assert_allclose(res.values,
-                                   np.array([[0.00242814, 0.00235669], [0.00245885, 0.00238707]]),
+                                   np.array([[0.02916261, 0.02839063], [0.02949383, 0.02871911]]),
                                    rtol=1e-5)
 
     def test_custom_settings(self, sunz_ds1, sunz_sza):
         """Test custom settings with sza data available."""
-        res = self.custom((sunz_ds1, sunz_sza), test_attr='test')
+        res = self.custom((sunz_ds1, sunz_sza), test_attr="test")
         np.testing.assert_allclose(res.values,
                                    np.array([[0.01041319, 0.01030033], [0.01046164, 0.01034834]]),
                                    rtol=1e-5)
@@ -190,8 +192,8 @@ class TestSunZenithReducer:
     def test_invalid_max_sza(self, sunz_ds1, sunz_sza):
         """Test invalid max_sza with sza data available."""
         from satpy.modifiers.geometry import SunZenithReducer
-        with pytest.raises(ValueError):
-            SunZenithReducer(name='sza_reduction_test_invalid', modifiers=tuple(), max_sza=None)
+        with pytest.raises(ValueError, match="`max_sza` must be defined when using the SunZenithReducer."):
+            SunZenithReducer(name="sza_reduction_test_invalid", modifiers=tuple(), max_sza=None)
 
 
 class TestNIRReflectance(unittest.TestCase):
@@ -205,24 +207,24 @@ class TestNIRReflectance(unittest.TestCase):
         area = mock.MagicMock(get_lonlats=self.get_lonlats)
 
         self.start_time = 1
-        self.metadata = {'platform_name': 'Meteosat-11',
-                         'sensor': 'seviri',
-                         'name': 'IR_039',
-                         'area': area,
-                         'start_time': self.start_time}
+        self.metadata = {"platform_name": "Meteosat-11",
+                         "sensor": "seviri",
+                         "name": "IR_039",
+                         "area": area,
+                         "start_time": self.start_time}
 
         nir_arr = np.random.random((2, 2))
-        self.nir = xr.DataArray(da.from_array(nir_arr), dims=['y', 'x'])
+        self.nir = xr.DataArray(da.from_array(nir_arr), dims=["y", "x"])
         self.nir.attrs.update(self.metadata)
 
         ir_arr = 100 * np.random.random((2, 2))
-        self.ir_ = xr.DataArray(da.from_array(ir_arr), dims=['y', 'x'])
-        self.ir_.attrs['area'] = area
+        self.ir_ = xr.DataArray(da.from_array(ir_arr), dims=["y", "x"])
+        self.ir_.attrs["area"] = area
 
         self.sunz_arr = 100 * np.random.random((2, 2))
-        self.sunz = xr.DataArray(da.from_array(self.sunz_arr), dims=['y', 'x'])
-        self.sunz.attrs['standard_name'] = 'solar_zenith_angle'
-        self.sunz.attrs['area'] = area
+        self.sunz = xr.DataArray(da.from_array(self.sunz_arr), dims=["y", "x"])
+        self.sunz.attrs["standard_name"] = "solar_zenith_angle"
+        self.sunz.attrs["area"] = area
         self.da_sunz = da.from_array(self.sunz_arr)
 
         refl_arr = np.random.random((2, 2))
@@ -238,9 +240,9 @@ class TestNIRReflectance(unittest.TestCase):
             return self.refl_with_co2
         return self.refl
 
-    @mock.patch('satpy.modifiers.spectral.sun_zenith_angle')
-    @mock.patch('satpy.modifiers.NIRReflectance.apply_modifier_info')
-    @mock.patch('satpy.modifiers.spectral.Calculator')
+    @mock.patch("satpy.modifiers.spectral.sun_zenith_angle")
+    @mock.patch("satpy.modifiers.NIRReflectance.apply_modifier_info")
+    @mock.patch("satpy.modifiers.spectral.Calculator")
     def test_provide_sunz_no_co2(self, calculator, apply_modifier_info, sza):
         """Test NIR reflectance compositor provided only sunz."""
         calculator.return_value = mock.MagicMock(
@@ -248,18 +250,18 @@ class TestNIRReflectance(unittest.TestCase):
         sza.return_value = self.da_sunz
         from satpy.modifiers.spectral import NIRReflectance
 
-        comp = NIRReflectance(name='test')
-        info = {'modifiers': None}
+        comp = NIRReflectance(name="test")
+        info = {"modifiers": None}
         res = comp([self.nir, self.ir_], optional_datasets=[self.sunz], **info)
 
         assert self.metadata.items() <= res.attrs.items()
-        assert res.attrs['units'] == '%'
-        assert res.attrs['sun_zenith_threshold'] is not None
+        assert res.attrs["units"] == "%"
+        assert res.attrs["sun_zenith_threshold"] is not None
         assert np.allclose(res.data, self.refl * 100).compute()
 
-    @mock.patch('satpy.modifiers.spectral.sun_zenith_angle')
-    @mock.patch('satpy.modifiers.NIRReflectance.apply_modifier_info')
-    @mock.patch('satpy.modifiers.spectral.Calculator')
+    @mock.patch("satpy.modifiers.spectral.sun_zenith_angle")
+    @mock.patch("satpy.modifiers.NIRReflectance.apply_modifier_info")
+    @mock.patch("satpy.modifiers.spectral.Calculator")
     def test_no_sunz_no_co2(self, calculator, apply_modifier_info, sza):
         """Test NIR reflectance compositor with minimal parameters."""
         calculator.return_value = mock.MagicMock(
@@ -267,20 +269,20 @@ class TestNIRReflectance(unittest.TestCase):
         sza.return_value = self.da_sunz
         from satpy.modifiers.spectral import NIRReflectance
 
-        comp = NIRReflectance(name='test')
-        info = {'modifiers': None}
+        comp = NIRReflectance(name="test")
+        info = {"modifiers": None}
         res = comp([self.nir, self.ir_], optional_datasets=[], **info)
 
         # due to copying of DataArrays, self.get_lonlats is not the same as the one that was called
         # we must used the area from the final result DataArray
-        res.attrs["area"].get_lonlats.assert_called()
+        res.attrs["area"].get_lonlats.assert_called_with(chunks=((2,), (2,)), dtype=self.nir.dtype)
         sza.assert_called_with(self.start_time, self.lons, self.lats)
         self.refl_from_tbs.assert_called_with(self.da_sunz, self.nir.data, self.ir_.data, tb_ir_co2=None)
         assert np.allclose(res.data, self.refl * 100).compute()
 
-    @mock.patch('satpy.modifiers.spectral.sun_zenith_angle')
-    @mock.patch('satpy.modifiers.NIRReflectance.apply_modifier_info')
-    @mock.patch('satpy.modifiers.spectral.Calculator')
+    @mock.patch("satpy.modifiers.spectral.sun_zenith_angle")
+    @mock.patch("satpy.modifiers.NIRReflectance.apply_modifier_info")
+    @mock.patch("satpy.modifiers.spectral.Calculator")
     def test_no_sunz_with_co2(self, calculator, apply_modifier_info, sza):
         """Test NIR reflectance compositor provided extra co2 info."""
         calculator.return_value = mock.MagicMock(
@@ -288,20 +290,20 @@ class TestNIRReflectance(unittest.TestCase):
         from satpy.modifiers.spectral import NIRReflectance
         sza.return_value = self.da_sunz
 
-        comp = NIRReflectance(name='test')
-        info = {'modifiers': None}
+        comp = NIRReflectance(name="test")
+        info = {"modifiers": None}
         co2_arr = np.random.random((2, 2))
-        co2 = xr.DataArray(da.from_array(co2_arr), dims=['y', 'x'])
-        co2.attrs['wavelength'] = [12.0, 13.0, 14.0]
-        co2.attrs['units'] = 'K'
+        co2 = xr.DataArray(da.from_array(co2_arr), dims=["y", "x"])
+        co2.attrs["wavelength"] = [12.0, 13.0, 14.0]
+        co2.attrs["units"] = "K"
         res = comp([self.nir, self.ir_], optional_datasets=[co2], **info)
 
         self.refl_from_tbs.assert_called_with(self.da_sunz, self.nir.data, self.ir_.data, tb_ir_co2=co2.data)
         assert np.allclose(res.data, self.refl_with_co2 * 100).compute()
 
-    @mock.patch('satpy.modifiers.spectral.sun_zenith_angle')
-    @mock.patch('satpy.modifiers.NIRReflectance.apply_modifier_info')
-    @mock.patch('satpy.modifiers.spectral.Calculator')
+    @mock.patch("satpy.modifiers.spectral.sun_zenith_angle")
+    @mock.patch("satpy.modifiers.NIRReflectance.apply_modifier_info")
+    @mock.patch("satpy.modifiers.spectral.Calculator")
     def test_provide_sunz_and_threshold(self, calculator, apply_modifier_info, sza):
         """Test NIR reflectance compositor provided sunz and a sunz threshold."""
         calculator.return_value = mock.MagicMock(
@@ -309,32 +311,32 @@ class TestNIRReflectance(unittest.TestCase):
         from satpy.modifiers.spectral import NIRReflectance
         sza.return_value = self.da_sunz
 
-        comp = NIRReflectance(name='test', sunz_threshold=84.0)
-        info = {'modifiers': None}
+        comp = NIRReflectance(name="test", sunz_threshold=84.0)
+        info = {"modifiers": None}
         res = comp([self.nir, self.ir_], optional_datasets=[self.sunz], **info)
 
-        self.assertEqual(res.attrs['sun_zenith_threshold'], 84.0)
-        calculator.assert_called_with('Meteosat-11', 'seviri', 'IR_039',
+        assert res.attrs["sun_zenith_threshold"] == 84.0
+        calculator.assert_called_with("Meteosat-11", "seviri", "IR_039",
                                       sunz_threshold=84.0, masking_limit=NIRReflectance.MASKING_LIMIT)
 
-    @mock.patch('satpy.modifiers.spectral.sun_zenith_angle')
-    @mock.patch('satpy.modifiers.NIRReflectance.apply_modifier_info')
-    @mock.patch('satpy.modifiers.spectral.Calculator')
+    @mock.patch("satpy.modifiers.spectral.sun_zenith_angle")
+    @mock.patch("satpy.modifiers.NIRReflectance.apply_modifier_info")
+    @mock.patch("satpy.modifiers.spectral.Calculator")
     def test_sunz_threshold_default_value_is_not_none(self, calculator, apply_modifier_info, sza):
         """Check that sun_zenith_threshold is not None."""
         from satpy.modifiers.spectral import NIRReflectance
 
-        comp = NIRReflectance(name='test')
-        info = {'modifiers': None}
+        comp = NIRReflectance(name="test")
+        info = {"modifiers": None}
         calculator.return_value = mock.MagicMock(
             reflectance_from_tbs=self.refl_from_tbs)
         comp([self.nir, self.ir_], optional_datasets=[self.sunz], **info)
 
         assert comp.sun_zenith_threshold is not None
 
-    @mock.patch('satpy.modifiers.spectral.sun_zenith_angle')
-    @mock.patch('satpy.modifiers.NIRReflectance.apply_modifier_info')
-    @mock.patch('satpy.modifiers.spectral.Calculator')
+    @mock.patch("satpy.modifiers.spectral.sun_zenith_angle")
+    @mock.patch("satpy.modifiers.NIRReflectance.apply_modifier_info")
+    @mock.patch("satpy.modifiers.spectral.Calculator")
     def test_provide_masking_limit(self, calculator, apply_modifier_info, sza):
         """Test NIR reflectance compositor provided sunz and a sunz threshold."""
         calculator.return_value = mock.MagicMock(
@@ -342,23 +344,23 @@ class TestNIRReflectance(unittest.TestCase):
         from satpy.modifiers.spectral import NIRReflectance
         sza.return_value = self.da_sunz
 
-        comp = NIRReflectance(name='test', masking_limit=None)
-        info = {'modifiers': None}
+        comp = NIRReflectance(name="test", masking_limit=None)
+        info = {"modifiers": None}
         res = comp([self.nir, self.ir_], optional_datasets=[self.sunz], **info)
 
-        self.assertIsNone(res.attrs['sun_zenith_masking_limit'])
-        calculator.assert_called_with('Meteosat-11', 'seviri', 'IR_039',
+        assert res.attrs["sun_zenith_masking_limit"] is None
+        calculator.assert_called_with("Meteosat-11", "seviri", "IR_039",
                                       sunz_threshold=NIRReflectance.TERMINATOR_LIMIT, masking_limit=None)
 
-    @mock.patch('satpy.modifiers.spectral.sun_zenith_angle')
-    @mock.patch('satpy.modifiers.NIRReflectance.apply_modifier_info')
-    @mock.patch('satpy.modifiers.spectral.Calculator')
+    @mock.patch("satpy.modifiers.spectral.sun_zenith_angle")
+    @mock.patch("satpy.modifiers.NIRReflectance.apply_modifier_info")
+    @mock.patch("satpy.modifiers.spectral.Calculator")
     def test_masking_limit_default_value_is_not_none(self, calculator, apply_modifier_info, sza):
         """Check that sun_zenith_threshold is not None."""
         from satpy.modifiers.spectral import NIRReflectance
 
-        comp = NIRReflectance(name='test')
-        info = {'modifiers': None}
+        comp = NIRReflectance(name="test")
+        info = {"modifiers": None}
         calculator.return_value = mock.MagicMock(
             reflectance_from_tbs=self.refl_from_tbs)
         comp([self.nir, self.ir_], optional_datasets=[self.sunz], **info)
@@ -369,9 +371,9 @@ class TestNIRReflectance(unittest.TestCase):
 class TestNIREmissivePartFromReflectance(unittest.TestCase):
     """Test the NIR Emissive part from reflectance compositor."""
 
-    @mock.patch('satpy.modifiers.spectral.sun_zenith_angle')
-    @mock.patch('satpy.modifiers.NIRReflectance.apply_modifier_info')
-    @mock.patch('satpy.modifiers.spectral.Calculator')
+    @mock.patch("satpy.modifiers.spectral.sun_zenith_angle")
+    @mock.patch("satpy.modifiers.NIRReflectance.apply_modifier_info")
+    @mock.patch("satpy.modifiers.spectral.Calculator")
     def test_compositor(self, calculator, apply_modifier_info, sza):
         """Test the NIR emissive part from reflectance compositor."""
         from satpy.modifiers.spectral import NIRReflectance
@@ -391,12 +393,12 @@ class TestNIREmissivePartFromReflectance(unittest.TestCase):
 
         from satpy.modifiers.spectral import NIREmissivePartFromReflectance
 
-        comp = NIREmissivePartFromReflectance(name='test', sunz_threshold=86.0)
-        info = {'modifiers': None}
+        comp = NIREmissivePartFromReflectance(name="test", sunz_threshold=86.0)
+        info = {"modifiers": None}
 
-        platform = 'NOAA-20'
-        sensor = 'viirs'
-        chan_name = 'M12'
+        platform = "NOAA-20"
+        sensor = "viirs"
+        chan_name = "M12"
 
         get_lonlats = mock.MagicMock()
         lons, lats = 1, 2
@@ -404,29 +406,29 @@ class TestNIREmissivePartFromReflectance(unittest.TestCase):
         area = mock.MagicMock(get_lonlats=get_lonlats)
 
         nir_arr = np.random.random((2, 2))
-        nir = xr.DataArray(da.from_array(nir_arr), dims=['y', 'x'])
-        nir.attrs['platform_name'] = platform
-        nir.attrs['sensor'] = sensor
-        nir.attrs['name'] = chan_name
-        nir.attrs['area'] = area
+        nir = xr.DataArray(da.from_array(nir_arr), dims=["y", "x"])
+        nir.attrs["platform_name"] = platform
+        nir.attrs["sensor"] = sensor
+        nir.attrs["name"] = chan_name
+        nir.attrs["area"] = area
         ir_arr = np.random.random((2, 2))
-        ir_ = xr.DataArray(da.from_array(ir_arr), dims=['y', 'x'])
-        ir_.attrs['area'] = area
+        ir_ = xr.DataArray(da.from_array(ir_arr), dims=["y", "x"])
+        ir_.attrs["area"] = area
 
         sunz_arr = 100 * np.random.random((2, 2))
-        sunz = xr.DataArray(da.from_array(sunz_arr), dims=['y', 'x'])
-        sunz.attrs['standard_name'] = 'solar_zenith_angle'
-        sunz.attrs['area'] = area
+        sunz = xr.DataArray(da.from_array(sunz_arr), dims=["y", "x"])
+        sunz.attrs["standard_name"] = "solar_zenith_angle"
+        sunz.attrs["area"] = area
         sunz2 = da.from_array(sunz_arr)
         sza.return_value = sunz2
 
         res = comp([nir, ir_], optional_datasets=[sunz], **info)
-        self.assertEqual(res.attrs['sun_zenith_threshold'], 86.0)
-        self.assertEqual(res.attrs['units'], 'K')
-        self.assertEqual(res.attrs['platform_name'], platform)
-        self.assertEqual(res.attrs['sensor'], sensor)
-        self.assertEqual(res.attrs['name'], chan_name)
-        calculator.assert_called_with('NOAA-20', 'viirs', 'M12', sunz_threshold=86.0,
+        assert res.attrs["sun_zenith_threshold"] == 86.0
+        assert res.attrs["units"] == "K"
+        assert res.attrs["platform_name"] == platform
+        assert res.attrs["sensor"] == sensor
+        assert res.attrs["name"] == chan_name
+        calculator.assert_called_with("NOAA-20", "viirs", "M12", sunz_threshold=86.0,
                                       masking_limit=NIRReflectance.MASKING_LIMIT)
 
 
@@ -438,9 +440,9 @@ class TestPSPRayleighReflectance:
         rows = 3
         cols = 5
         area = AreaDefinition(
-            'some_area_name', 'On-the-fly area', 'geosabii',
-            {'a': '6378137.0', 'b': '6356752.31414', 'h': '35786023.0', 'lon_0': '-89.5', 'proj': 'geos', 'sweep': 'x',
-             'units': 'm'},
+            "some_area_name", "On-the-fly area", "geosabii",
+            {"a": "6378137.0", "b": "6356752.31414", "h": "35786023.0", "lon_0": "-89.5", "proj": "geos", "sweep": "x",
+             "units": "m"},
             cols, rows,
             (-5434894.954752679, -5434894.964451744, 5434894.964451744, 5434894.954752679))
 
@@ -453,46 +455,46 @@ class TestPSPRayleighReflectance:
     def _create_test_data(self, name, wavelength, resolution):
         area, dnb = self._make_data_area()
         input_band = xr.DataArray(dnb,
-                                  dims=('y', 'x'),
+                                  dims=("y", "x"),
                                   attrs={
-                                      'platform_name': 'Himawari-8',
-                                      'calibration': 'reflectance', 'units': '%', 'wavelength': wavelength,
-                                      'name': name, 'resolution': resolution, 'sensor': 'ahi',
-                                      'start_time': '2017-09-20 17:30:40.800000',
-                                      'end_time': '2017-09-20 17:41:17.500000',
-                                      'area': area, 'ancillary_variables': [],
-                                      'orbital_parameters': {
-                                          'satellite_nominal_longitude': -89.5,
-                                          'satellite_nominal_latitude': 0.0,
-                                          'satellite_nominal_altitude': 35786023.4375,
+                                      "platform_name": "Himawari-8",
+                                      "calibration": "reflectance", "units": "%", "wavelength": wavelength,
+                                      "name": name, "resolution": resolution, "sensor": "ahi",
+                                      "start_time": "2017-09-20 17:30:40.800000",
+                                      "end_time": "2017-09-20 17:41:17.500000",
+                                      "area": area, "ancillary_variables": [],
+                                      "orbital_parameters": {
+                                          "satellite_nominal_longitude": -89.5,
+                                          "satellite_nominal_latitude": 0.0,
+                                          "satellite_nominal_altitude": 35786023.4375,
                                       },
                                   })
 
         red_band = xr.DataArray(dnb,
-                                dims=('y', 'x'),
+                                dims=("y", "x"),
                                 attrs={
-                                    'platform_name': 'Himawari-8',
-                                    'calibration': 'reflectance', 'units': '%', 'wavelength': (0.62, 0.64, 0.66),
-                                    'name': 'B03', 'resolution': 500, 'sensor': 'ahi',
-                                    'start_time': '2017-09-20 17:30:40.800000',
-                                    'end_time': '2017-09-20 17:41:17.500000',
-                                    'area': area, 'ancillary_variables': [],
-                                    'orbital_parameters': {
-                                        'satellite_nominal_longitude': -89.5,
-                                        'satellite_nominal_latitude': 0.0,
-                                        'satellite_nominal_altitude': 35786023.4375,
+                                    "platform_name": "Himawari-8",
+                                    "calibration": "reflectance", "units": "%", "wavelength": (0.62, 0.64, 0.66),
+                                    "name": "B03", "resolution": 500, "sensor": "ahi",
+                                    "start_time": "2017-09-20 17:30:40.800000",
+                                    "end_time": "2017-09-20 17:41:17.500000",
+                                    "area": area, "ancillary_variables": [],
+                                    "orbital_parameters": {
+                                        "satellite_nominal_longitude": -89.5,
+                                        "satellite_nominal_latitude": 0.0,
+                                        "satellite_nominal_altitude": 35786023.4375,
                                     },
                                 })
         fake_angle_data = da.ones_like(dnb, dtype=np.float32) * 90.0
         angle1 = xr.DataArray(fake_angle_data,
-                              dims=('y', 'x'),
+                              dims=("y", "x"),
                               attrs={
-                                  'platform_name': 'Himawari-8',
-                                  'calibration': 'reflectance', 'units': '%', 'wavelength': wavelength,
-                                  'name': "satellite_azimuth_angle", 'resolution': resolution, 'sensor': 'ahi',
-                                  'start_time': '2017-09-20 17:30:40.800000',
-                                  'end_time': '2017-09-20 17:41:17.500000',
-                                  'area': area, 'ancillary_variables': [],
+                                  "platform_name": "Himawari-8",
+                                  "calibration": "reflectance", "units": "%", "wavelength": wavelength,
+                                  "name": "satellite_azimuth_angle", "resolution": resolution, "sensor": "ahi",
+                                  "start_time": "2017-09-20 17:30:40.800000",
+                                  "end_time": "2017-09-20 17:41:17.500000",
+                                  "area": area, "ancillary_variables": [],
                               })
         return input_band, red_band, angle1, angle1, angle1, angle1
 
@@ -518,15 +520,15 @@ class TestPSPRayleighReflectance:
                                 reduce_strength, exp_mean, exp_unique):
         """Test PSPRayleighReflectance with fake data."""
         from satpy.modifiers.atmosphere import PSPRayleighReflectance
-        ray_cor = PSPRayleighReflectance(name=name, atmosphere='us-standard', aerosol_types=aerosol_type,
+        ray_cor = PSPRayleighReflectance(name=name, atmosphere="us-standard", aerosol_types=aerosol_type,
                                          reduce_lim_low=reduce_lim_low, reduce_lim_high=reduce_lim_high,
                                          reduce_strength=reduce_strength)
-        assert ray_cor.attrs['name'] == name
-        assert ray_cor.attrs['atmosphere'] == 'us-standard'
-        assert ray_cor.attrs['aerosol_types'] == aerosol_type
-        assert ray_cor.attrs['reduce_lim_low'] == reduce_lim_low
-        assert ray_cor.attrs['reduce_lim_high'] == reduce_lim_high
-        assert ray_cor.attrs['reduce_strength'] == reduce_strength
+        assert ray_cor.attrs["name"] == name
+        assert ray_cor.attrs["atmosphere"] == "us-standard"
+        assert ray_cor.attrs["aerosol_types"] == aerosol_type
+        assert ray_cor.attrs["reduce_lim_low"] == reduce_lim_low
+        assert ray_cor.attrs["reduce_lim_high"] == reduce_lim_high
+        assert ray_cor.attrs["reduce_strength"] == reduce_strength
 
         input_band, red_band, *_ = self._create_test_data(name, wavelength, resolution)
         res = ray_cor([input_band, red_band])
@@ -545,7 +547,7 @@ class TestPSPRayleighReflectance:
         """Test PSPRayleighReflectance with angles provided."""
         from satpy.modifiers.atmosphere import PSPRayleighReflectance
         aerosol_type = "rayleigh_only"
-        ray_cor = PSPRayleighReflectance(name="B01", atmosphere='us-standard', aerosol_types=aerosol_type)
+        ray_cor = PSPRayleighReflectance(name="B01", atmosphere="us-standard", aerosol_types=aerosol_type)
         prereqs, opt_prereqs = self._get_angles_prereqs_and_opts(as_optionals)
         with mock.patch("satpy.modifiers.atmosphere.get_angles") as get_angles:
             res = ray_cor(prereqs, opt_prereqs)
@@ -596,15 +598,15 @@ class TestPSPAtmosphericalCorrection(unittest.TestCase):
             "nadir_latitude": 0.0,
         }
         band = xr.DataArray(da.zeros((5, 5)),
-                            attrs={'area': area,
-                                   'start_time': stime,
-                                   'name': 'name',
-                                   'platform_name': 'platform',
-                                   'sensor': 'sensor',
-                                   'orbital_parameters': orb_params},
-                            dims=('y', 'x'))
+                            attrs={"area": area,
+                                   "start_time": stime,
+                                   "name": "name",
+                                   "platform_name": "platform",
+                                   "sensor": "sensor",
+                                   "orbital_parameters": orb_params},
+                            dims=("y", "x"))
 
         # Perform atmospherical correction
-        psp = PSPAtmosphericalCorrection(name='dummy')
+        psp = PSPAtmosphericalCorrection(name="dummy")
         res = psp(projectables=[band])
         res.compute()
